<?php

namespace App;

use Carbon\Carbon;
use App\ComparendoEntregaOficio as EntregaNotificaciones;
use App\ComparendoExpediente;
use App\ResolucionSimit;
use App\Festivos;
use App\FestivosBack;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Facades\DB;
use App\ComparendoNotificacion as NotiOfi;

class Comparendo extends Model
{
    protected $connection = 'mysql2';
    protected $table = "comparendos";

    function propietario()
    {
        return $this->belongsTo('App\Ciudadano', 'id_propietario');
    }

    function agente()
    {
        return $this->belongsTo('App\Agente', 'id_agente');
    }

    function vehiculo()
    {
        return $this->belongsTo('App\Vehiculo', 'vehiculo_placa', 'placa');
    }

    function vehiculoCiudadMatricula()
    {
        return $this->belongsTo('App\Ciudad', 'vehiculo_ciudad_matricula');
    }

    function vehiculoTipo()
    {
        return $this->belongsTo('App\Tipo', 'vehiculo_tipo_vehiculo');
    }

    function vehiculoTipoServicio()
    {
        return $this->belongsTo('App\Tipo', 'vehiculo_tipo_servicio');
    }

    function vehiculoRadioAccion()
    {
        return $this->belongsTo('App\Tipo', 'vehiculo_radio_accion');
    }

    function vehiculoModalidad()
    {
        return $this->belongsTo('App\Tipo', 'vehiculo_modalidad');
    }

    function infractor_licencia_divipo()
    {
        return $this->belongsTo('App\Ciudad', 'infractor_licencia_divipo');
    }

    function vehiculoTipoTransporte()
    {
        return $this->belongsTo('App\Tipo', 'vehiculo_tipo_transporte');
    }

    function infractorTipoDocumento()
    {
        return $this->belongsTo('App\Tipo', 'infractor_tipo_documento');
    }

    function infractorTipo()
    {
        return $this->belongsTo('App\Tipo', 'infractor_tipo');
    }


    function obtenerInfracciones()
    {
        $tmp = Infraccion::whereIn('codigo', explode(',', $this->infracciones))->get();
        $sw = 0;
        foreach ($tmp as $tm) {
            $sw = 1;
        }

        if ($sw == 0) {
            $tmp = Infraccion::where('codigo_old','<>', 0)->whereIn('codigo_old', explode(',', $this->infracciones))->get();
        }

        return $tmp;
    }

    function obtenerResolucion()
    {
        $tmp = ResolucionSimit::whereIn('COL7', explode(',', $this->numero))
            ->where(function ($query) {
                $query->where('COL5', '1')
                    ->orWhere('COL5', '270')->orWhere('COL5', '16')->orWhere('COL5', '6')->orWhere('COL5', '8');
            })->orderBy('id','desc')->get();


         $id = 0;
        $anot = "";
        $mest = "";
        $diat = "";
        $saldot = "";
        $nrt = "";
        foreach ($tmp as $tm) {
            
            $sw=0;
            $incumplimientos = ResolucionSimit::where('COL3', $tm->COL2)->Where('COL5', '9')->get();                
            foreach ($incumplimientos as $incumplimiento) {
                $sw=1;
            }
            $revocatorias = ResolucionSimit::where('COL3', $tm->COL2)->Where('COL5', '21')->get();              
            foreach ($revocatorias as $revocatoria) {
                $sw=1;
            }
            
            if($sw==0)
            {
            $fi = $tm->COL4;
            $saldo = $tm->COL23;
            $nr = $tm->id;
            $ano = substr($fi, 6, 4);
            $mes = substr($fi, 3, 2);
            $dia = substr($fi, 0, 2);

            if ($anot < $ano) {
                $anot = $ano;
                $mest = $mes;
                $diat = $dia;
                $saldot = $saldo;
                $nrt = $nr;
                $id = $tm->id;
            }

            if ($anot == $ano && $mest < $mes) {
                $anot = $ano;
                $mest = $mes;
                $diat = $dia;
                $saldot = $saldo;
                $nrt = $nr;
                $id = $tm->id;
            }

            if ($anot == $ano && $mest == $mes && $diat < $dia) {
                $anot = $ano;
                $mest = $mes;
                $diat = $dia;
                $saldot = $saldo;
                $nrt = $nr;
                $id = $tm->id;
            }
            if ($anot == $ano && $mest == $mes && $diat == $dia) {
                if ( $nrt < $nr) { //$saldot >= $saldo &&
                    $id = $tm->id;
                }
            }
            }//incumplimiento
        }
        $tmp = ResolucionSimit::where('id', $id)->get();
        return $tmp;
    }

    function descuento()
    {
        return $this->hasOne('App\Descuento', 'id_comparendo');
    }

    function resoluciones()
    {
        return $this->hasMany('App\ResolucionSimit', 'COL7', 'numero');
    }

    function calcularDescuento()
    {
        if (!$this->descuento) {
            return 0;
        }
        return round($this->descuento->total_descuento + $this->descuento->total_cia);
    }

    function expediente()
    {
        return $this->belongsTo('App\ComparendoExpediente', 'id_comparendo', 'id');
    }

    /**
     * @autor: David Bastidas
     * join con los codigos de infraccion en texto.
     */
    function infraccion()
    {
        return $this->belongsTo('App\Infraccion', 'infracciones', 'codigo');
    }

    /**
     * @autor: David Bastidas
     * comparendos que tienen direccion actualizada hasta hace 3 meses.
     */
    public static function habilitadosParaImprimir($orden = 'antiguo', $contar = false)
    {
        $comparendos = DB::table('comparendos')->select(
            DB::raw("c.id as final_comparendo"),
            DB::raw("c.vehiculo_placa as final_placa"),
            DB::raw("cu.direccion as final_infractor_direccion"),
            DB::raw("c.infractor_documento as final_documento"),
            DB::raw("c.infractor_apellido as final_apellido"),
            DB::raw("c.infractor_nombre as final_nombre"),
            DB::raw("DATE_FORMAT(c.infraccion_fecha, '%d/%m/%Y') as final_infraccion_fecha"),
            DB::raw("DATE_FORMAT(MAX(cu.fecha_actualizacion), '%d/%m/%Y') as final_ultima_direccion"),
            DB::raw("c.infraccion_fecha as final_infraccion_fecha_date")
        )
            ->from('comparendos as c')
            ->join('vehiculos as v', 'v.placa', '=', 'c.vehiculo_placa')
            ->join('ciudadanos_ubicacion as cu', 'cu.id_ciudadano', '=', 'v.id_ciudadano')
            ->where(
                'cu.fecha_actualizacion', '>', DB::raw('DATE_ADD(curdate(), INTERVAL -3 MONTH)')
            )
            ->where('c.es_fotomulta', DB::raw('1'))
            ->whereNull('c.id_tipo_evento')
            ->groupBy('c.id');
        //buscando comparendos por datos del runt
        $comparendosRunt = DB::table('comparendos')->select(
            DB::raw("c.id as final_comparendo"),
            DB::raw("c.vehiculo_placa as final_placa"),
            DB::raw("cu.direccion as final_infractor_direccion"),
            DB::raw("c.infractor_documento as final_documento"),
            DB::raw("c.infractor_apellido as final_apellido"),
            DB::raw("c.infractor_nombre as final_nombre"),
            DB::raw("DATE_FORMAT(c.infraccion_fecha, '%d/%m/%Y') as final_infraccion_fecha"),
            DB::raw("DATE_FORMAT(MAX(cu.fecha_actualizacion), '%d/%m/%Y') as final_ultima_direccion"),
            DB::raw("c.infraccion_fecha as final_infraccion_fecha_date")
        )
            ->from('comparendos as c')
            ->join('runt.vehiculos as v', 'v.placa', '=', 'c.vehiculo_placa')
            ->join('ciudadanos as ciu', 'ciu.numero_documento', '=', 'v.documento')
            ->join('ciudadanos_ubicacion as cu', 'cu.id_ciudadano', '=', 'ciu.id')
            ->where(
                'cu.fecha_actualizacion', '>', DB::raw('DATE_ADD(curdate(), INTERVAL -3 MONTH)')
            )
            ->where('c.es_fotomulta', DB::raw('1'))
            ->whereNull('c.id_tipo_evento')
            ->groupBy('c.id')
            ->union($comparendos);

        $consulta = $comparendosRunt;
        $querySql = $consulta->toSql();
        $queryFinal = DB::table(DB::raw("($querySql) as t"))->mergeBindings($consulta);

        if ($contar) {
            $queryFinal = $queryFinal->count();
        } else {
            if ($orden == 'antiguo') {
                $queryFinal = $queryFinal
                    ->orderBy('final_infraccion_fecha_date', 'asc');
            } elseif ($orden == 'reciente') {
                $queryFinal = $queryFinal
                    ->orderBy('final_infraccion_fecha_date', 'desc');
            }
        }
        return $queryFinal;
    }

    /**
     * @autor: David Bastidas
     * comparendos que tienen direccion hasta mas de 3 meses.
     */
    public static function verificarParaDireccion($orden = 'antiguo', $contar = false)
    {
        $queryFinal = DB::table('comparendos')->select(
            DB::raw("c.id as final_comparendo"),
            DB::raw("c.vehiculo_placa as final_placa"),
            DB::raw("cu.direccion as final_infractor_direccion"),
            DB::raw("c.infractor_documento as final_documento"),
            DB::raw("c.infractor_apellido as final_apellido"),
            DB::raw("c.infractor_nombre as final_nombre"),
            DB::raw("DATE_FORMAT(c.infraccion_fecha, '%d/%m/%Y') as final_infraccion_fecha"),
            DB::raw("DATE_FORMAT(MAX(cu.fecha_actualizacion), '%d/%m/%Y') as final_ultima_direccion"),
            DB::raw("c.infraccion_fecha as final_infraccion_fecha_date")
        )
            ->from('comparendos as c')
            ->join('vehiculos as v', 'v.placa', '=', 'c.vehiculo_placa')
            ->leftJoin('ciudadanos_ubicacion as cu', 'cu.id_ciudadano', '=', 'v.id_ciudadano')
            ->where(function ($query) {
                $query->where('cu.fecha_actualizacion', '<', DB::raw('DATE_ADD(curdate(), INTERVAL -3 MONTH)'))
                    ->orWhereNull('cu.fecha_actualizacion');
            })
            ->where('c.es_fotomulta', DB::raw('1'));

        if ($contar) {
            $queryFinal = $queryFinal->count();
        } else {
            $queryFinal = $queryFinal->groupBy('c.id');
            if ($orden == 'antiguo') {
                $queryFinal = $queryFinal
                    ->orderBy('final_infraccion_fecha_date', 'asc');
            } elseif ($orden == 'reciente') {
                $queryFinal = $queryFinal
                    ->orderBy('final_infraccion_fecha_date', 'desc');
            }
        }
        return $queryFinal;
    }

    /**
     * @autor: David Bastidas
     * comparendos que tienen direccion hasta mas de 3 meses y seran enviados a archivo para consultar RUNT.
     */
    public static function registrosParaRunt($arrayIdComparendos = null)
    {
        $comparendos = DB::table('comparendos')->select(
            DB::raw("c.vehiculo_placa as final_placa"),
            DB::raw("MAX(cu.fecha_actualizacion) as final_ultima_direccion")
        )
            ->from('comparendos as c')
            ->leftJoin('comparendos_expediente as ce', 'ce.id_comparendo', '=', 'c.id')
            ->join('vehiculos as v', 'v.placa', '=', 'c.vehiculo_placa')
            ->leftJoin('ciudadanos_ubicacion as cu', 'cu.id_ciudadano', '=', 'v.id_ciudadano')
            ->where(function ($query) {
                $query->where('cu.fecha_actualizacion', '<', DB::raw('DATE_ADD(curdate(), INTERVAL -3 MONTH)'))
                    ->orWhereNull('cu.fecha_actualizacion');
            })
            ->where('c.es_fotomulta', DB::raw('1'))
            ->whereNull('ce.id_comparendo');
        if ($arrayIdComparendos != null) {
            $comparendos = $comparendos->whereIn('c.id', $arrayIdComparendos)
                ->groupBy('c.id');
        } else {
            $comparendos = $comparendos->groupBy('c.id');
        }
        return $comparendos;
    }

    /**
     * @autor: David Bastidas
     * comparendos que tienen direccion actualizada hasta hace 3 meses elegidos para imprimir comparendo.
     */
    public static function imprimirParaNotificar($arrayIdComparendos = null, $totalComparendos = 0)
    {
        $comparendos = Comparendo::select(
            DB::raw("c.valor as valor"),
            DB::raw("c.infraccion_direccion as infraccion_direccion"),
            DB::raw("c.infraccion_fecha as infraccion_fecha"),
            DB::raw("c.infraccion_hora as infraccion_hora"),
            DB::raw("cu.telefono as infractor_telefono"),
            DB::raw("c.infracciones as infracciones"),
            DB::raw("c.id as final_comparendo"),
            DB::raw("c.vehiculo_placa as final_placa"),
            DB::raw("cu.direccion as final_infractor_direccion"),
            DB::raw("cu.ciudad as final_infractor_ciudad"),
            DB::raw("c.infractor_documento as final_documento"),
            DB::raw("c.infractor_apellido as final_apellido"),
            DB::raw("c.infractor_nombre as final_nombre"),
            DB::raw("DATE_FORMAT(c.infraccion_fecha, '%d/%m/%Y') as final_infraccion_fecha"),
            DB::raw("DATE_FORMAT(MAX(cu.fecha_actualizacion), '%d/%m/%Y') as final_ultima_direccion"),
            DB::raw("c.infraccion_fecha as final_infraccion_fecha_date"),
            DB::raw("c.numero as final_numero"),
            DB::raw("c.id_organismo as id_organismo")
        )
            ->from('comparendos as c')
            ->join('vehiculos as v', 'v.placa', '=', 'c.vehiculo_placa')
            ->join('ciudadanos_ubicacion as cu', 'cu.id_ciudadano', '=', 'v.id_ciudadano')
            ->where(
                'cu.fecha_actualizacion', '>', DB::raw('DATE_ADD(curdate(), INTERVAL -3 MONTH)')
            )
            ->where('c.es_fotomulta', DB::raw('1'))
            ->whereNull('c.id_tipo_evento');

        if ($arrayIdComparendos != null) {
            $comparendos = $comparendos->whereIn('c.id', $arrayIdComparendos)
                ->groupBy('c.id');
        } else {
            $comparendos = $comparendos->groupBy('c.id');
        }
        $comparendos = $comparendos->get();

        //buscando comparendos por datos del runt
        $comparendosRunt = Comparendo::select(
            DB::raw("c.valor as valor"),
            DB::raw("c.infraccion_direccion as infraccion_direccion"),
            DB::raw("c.infraccion_fecha as infraccion_fecha"),
            DB::raw("c.infraccion_hora as infraccion_hora"),
            DB::raw("cu.telefono as infractor_telefono"),
            DB::raw("c.infracciones as infracciones"),
            DB::raw("c.id as final_comparendo"),
            DB::raw("c.vehiculo_placa as final_placa"),
            DB::raw("cu.direccion as final_infractor_direccion"),
            DB::raw("cu.ciudad as final_infractor_ciudad"),
            DB::raw("c.infractor_documento as final_documento"),
            DB::raw("c.infractor_apellido as final_apellido"),
            DB::raw("c.infractor_nombre as final_nombre"),
            DB::raw("DATE_FORMAT(c.infraccion_fecha, '%d/%m/%Y') as final_infraccion_fecha"),
            DB::raw("DATE_FORMAT(MAX(cu.fecha_actualizacion), '%d/%m/%Y') as final_ultima_direccion"),
            DB::raw("c.infraccion_fecha as final_infraccion_fecha_date"),
            DB::raw("c.numero as final_numero"),
            DB::raw("c.id_organismo as id_organismo")
        )
            ->from('comparendos as c')
            ->join('runt.vehiculos as v', 'v.placa', '=', 'c.vehiculo_placa')
            ->join('ciudadanos as ciu', 'ciu.numero_documento', '=', 'v.documento')
            ->join('ciudadanos_ubicacion as cu', 'cu.id_ciudadano', '=', 'ciu.id')
            ->where(
                'cu.fecha_actualizacion', '>', DB::raw('DATE_ADD(curdate(), INTERVAL -3 MONTH)')
            )
            ->where('c.es_fotomulta', DB::raw('1'))
            ->whereNull('c.id_tipo_evento');
        if ($arrayIdComparendos != null) {
            //entra para elegir comparendos por seleccion
            $comparendosRunt = $comparendosRunt->whereIn('c.id', $arrayIdComparendos)
                ->groupBy('c.id')->get();

            $comparendos = $comparendos->union($comparendosRunt);
        } else {
            $comparendosRunt = $comparendosRunt->orderBy('final_infraccion_fecha_date', 'asc')
                ->groupBy('c.id')->get();

            $comparendos = $comparendos->union($comparendosRunt)->take($totalComparendos);
        }

        return $comparendos;
    }

    /**
     * @autor: David Bastidas
     * comparendos sancionados.
     */
    public static function sancionados($orden = 'antiguo', $contar = false)
    {
        $comparendos = Comparendo::from('comparendos as c')
            ->join(DB::raw("comparendos_expediente ce"), 'ce.id_comparendo', '=', 'c.id')
            ->where('ce.id_tipo_evento', '=', '4')
            ->orWhere('ce.id_tipo_evento', '=', '12');//sancion especial

        if ($contar) {
            $comparendos = $comparendos->count();
        } else {
            if ($orden == 'antiguo') {
                $comparendos = $comparendos
                    ->orderBy('ce.fecha_generacion', 'asc');
            } elseif ($orden == 'reciente') {
                $comparendos = $comparendos
                    ->orderBy('ce.fecha_generacion', 'desc');
            }
        }
        return $comparendos;
    }

    /**
     * @autor: David Bastidas
     * comparendos habilitados para sancion por no pago, dentro del tiempo limite a sancionar.
     * y con direccion reciente de 3 meses
     */
    public static function habilitadosParaSancionar($orden = 'antiguo', $contar = false)
    {
        $comparendos = Comparendo::select(
            DB::raw("(select infs.descripcion from infracciones_salarios infs where infs.codigo = SUBSTRING(c.infracciones, 1, 1) limit 1) as infraccion_salario"),
            DB::raw("(select infs.salarios_dias from infracciones_salarios infs where infs.codigo = SUBSTRING(c.infracciones, 1, 1) limit 1) as infraccion_salario_dias"),
            DB::raw("(select count(1) from resoluciones_simit as rs where rs.COL7 = c.numero and rs.COL5 = '1') as count_resolucion_sancion"),
            DB::raw("c.*"),
            DB::raw("vc.nombre as clase_vehiculo"),
            DB::raw("numero as final_numero"),
            DB::raw("in.infraccion as descripcion_infraccion"),
            DB::raw("DATE_FORMAT(MAX(cu.fecha_actualizacion), '%d/%m/%Y') as ultima_direccion"),
            DB::raw(
                "(
                              case when es_fotomulta=1 and fecha_notificacion is not null then
                                    case when fecha_notificacion <= DATE_ADD(curdate(), INTERVAL -15 DAY) then
                                        true
                                      else
                                        false
                                      end
                                   when es_fotomulta=0 and infraccion_fecha <= DATE_ADD(curdate(), INTERVAL -15 DAY) then
                                      true
                                   else
                                      false
                                   end
                              ) as is_sancionar"
            ),
            DB::raw(
                "(
                              case when es_fotomulta=0 and infraccion_fecha<='2017-06-30' then
                                    case when curdate()>DATE_ADD(infraccion_fecha, INTERVAL 6 MONTH) then false else DATE_ADD(infraccion_fecha, INTERVAL 6 MONTH) end
                                  when es_fotomulta=0 and infraccion_fecha>='2017-07-01' then
                                    case when curdate()>DATE_ADD(infraccion_fecha, INTERVAL 12 MONTH) then false else DATE_ADD(infraccion_fecha, INTERVAL 12 MONTH) end
                                  when es_fotomulta=1 and fecha_pago is null and fecha_notificacion is not null then
                                      DATE_ADD(fecha_notificacion, INTERVAL 12 MONTH)
                                  else
                                    null
                                  end
                              ) as limite_sancion"
            )
        )
            ->from(DB::raw('comparendos c'))
            ->join('ciudadanos as ci', 'ci.numero_documento', '=', 'infractor_documento')
            ->join('ciudadanos_ubicacion as cu', 'cu.id_ciudadano', '=', 'ci.id')
            ->leftJoin('vehiculos_clases as vc', 'vc.id', '=', 'c.vehiculo_tipo_vehiculo')
            ->leftJoin('infracciones as in', 'in.codigo', '=', 'c.infracciones')
            ->where(
                'cu.fecha_actualizacion', '>', DB::raw('DATE_ADD(curdate(), INTERVAL -3 MONTH)')
            )
            ->where(
                'infraccion_fecha', '>=', DB::raw("'2016-01-01'")
            )
            ->where(function ($query) {
                $query->where('id_tipo_evento', '=', DB::raw('0'))
                    ->orWhereNull('id_tipo_evento');
            })
            ->whereNull('fecha_pago')
            ->groupBy('c.id');

        $consulta = $comparendos;
        $querySql = $consulta->toSql();

        $queryFinal = DB::table(DB::raw("($querySql) as tabla"));
        $queryFinal = $queryFinal
            ->where('count_resolucion_sancion', '=', '0')
            ->where('limite_sancion', '!=', 0)
            ->whereNotNull('limite_sancion');

        if ($contar) {
            $queryFinal = $queryFinal->count();
        } else {
            if ($orden == 'antiguo') {
                $queryFinal = $queryFinal
                    ->orderBy(DB::raw('id asc, infraccion_fecha'), 'asc');
            } elseif ($orden == 'reciente') {
                $queryFinal = $queryFinal
                    ->orderBy(DB::raw('id desc, infraccion_fecha'), 'desc');
            }
        }
        return $queryFinal;
    }

    /**
     * @autor: David Bastidas
     * comparendos a verificar direccion mas reciente para sanciones
     */
    public static function verificarParaSancionar($orden = 'antiguo', $contar = false, $group = 'id')
    {
        $comparendos = Comparendo::select(
            DB::raw("(select count(1) from resoluciones_simit as rs where rs.COL7 = c.numero and rs.COL5 = '1') as count_resolucion_sancion"),
            DB::raw("c.*"),
            DB::raw("numero as final_numero"),
            DB::raw("DATE_FORMAT(MAX(cu.fecha_actualizacion), '%d/%m/%Y') as ultima_direccion"),
            DB::raw(
                "(
                              	case when es_fotomulta=1 and fecha_notificacion is not null then
                              				case when fecha_notificacion <= DATE_ADD(curdate(), INTERVAL -15 DAY) then
                              						true
                              					else
                              						false
                              					end
                              	     when es_fotomulta=0 and infraccion_fecha <= DATE_ADD(curdate(), INTERVAL -15 DAY) then
                              	     		true
                              	     else
                              	     		false
                              	     end
                              	) as is_sancionar"
            ),
            DB::raw(
                "(
                              	case when es_fotomulta=0 and infraccion_fecha<='2017-06-30' then
                              				case when curdate()>DATE_ADD(infraccion_fecha, INTERVAL 6 MONTH) then false else DATE_ADD(infraccion_fecha, INTERVAL 6 MONTH) end
                              		  when es_fotomulta=0 and infraccion_fecha>='2017-07-01' then
                              				case when curdate()>DATE_ADD(infraccion_fecha, INTERVAL 12 MONTH) then false else DATE_ADD(infraccion_fecha, INTERVAL 12 MONTH) end
                              		  when es_fotomulta=1 and fecha_pago is null and fecha_notificacion is not null then
                              		  		DATE_ADD(fecha_notificacion, INTERVAL 12 MONTH)
                              		  else
                              				null
                              		  end
                              	) as limite_sancion"
            )
        )
            ->from(DB::raw('comparendos c'))
            ->leftJoin('ciudadanos as ci', 'ci.numero_documento', '=', 'infractor_documento')
            ->leftJoin('ciudadanos_ubicacion as cu', 'cu.id_ciudadano', '=', 'ci.id')
            ->where(function ($query) {
                $query->where('cu.fecha_actualizacion', '<', DB::raw('DATE_ADD(curdate(), INTERVAL -3 MONTH)'))
                    ->orWhereNull('cu.fecha_actualizacion');
            })
            ->where(
                'infraccion_fecha', '>=', DB::raw("'2018-01-01'")
            )
            ->where(function ($query) {
                $query->where('id_tipo_evento', '=', DB::raw('0'))
                    ->orWhereNull('id_tipo_evento');
            })
            ->whereNull('fecha_pago')
            ->groupBy('c.id');

        $consulta = $comparendos;
        $querySql = $consulta->toSql();

        $queryFinal = DB::table(DB::raw("($querySql) as tabla"));
        $queryFinal = $queryFinal
            ->where('count_resolucion_sancion', '=', '0')
            ->where('limite_sancion', '!=', false)
            ->whereNotNull('limite_sancion');

        if ($contar) {
            $queryFinal = $queryFinal->count();
        } else {
            if ($group == 'id') {
                //se agrupa para tener comparendo unico
                $queryFinal = $queryFinal->groupBy('id');
            } elseif ($group == 'documento') {
                //se agrupa cuando se quiere tener la cedula para el archivo runt
                $queryFinal = $queryFinal->groupBy('infractor_documento');
            }
            if ($orden == 'antiguo') {
                $queryFinal = $queryFinal
                    ->orderBy('infraccion_fecha', 'asc');
            } elseif ($orden == 'reciente') {
                $queryFinal = $queryFinal
                    ->orderBy('infraccion_fecha', 'desc');
            }
        }
        return $queryFinal;
    }

    /**
     * @autor: David Bastidas
     * comparendos para sancion especial.
     * no necesito la direccion actualizada porque es un proceso especial y se piensa colgar en la web como no contactado
     */
    public static function habilitadosParaSancionEspecial($orden = 'antiguo', $contar = false, $validar = false)
    {

        $comparendos = Comparendo::select(
            DB::raw("(select count(rs.COL4) from resoluciones_simit as rs where rs.COL7 = c.numero and rs.COL5 = '2' order by rs.COL4 limit 2) as countexfallo"),
            DB::raw("(select count(rs.COL4) from resoluciones_simit as rs where rs.COL7 = c.numero and rs.COL5 = '6' order by rs.COL4 limit 2) as countap"),
            DB::raw("(select count(rs.COL4) from resoluciones_simit as rs where rs.COL7 = c.numero and rs.COL5 = '8' order by rs.COL4 limit 2) as countapresumen"),
            DB::raw("(select count(rs.COL4) from resoluciones_simit as rs where rs.COL7 = c.numero and rs.COL5 = '12' order by rs.COL4 limit 2) as countanulacion"),
            DB::raw("(select count(rs.COL4) from resoluciones_simit as rs where rs.COL7 = c.numero and rs.COL5 = '16' order by rs.COL4 limit 2) as countmandamiento"),
            DB::raw("(select infs.descripcion from infracciones_salarios infs where infs.codigo = SUBSTRING(c.infracciones, 1, 1) limit 1) as infraccion_salario"),
            DB::raw("(select infs.salarios_dias from infracciones_salarios infs where infs.codigo = SUBSTRING(c.infracciones, 1, 1) limit 1) as infraccion_salario_dias"),
            DB::raw("(select count(1) from resoluciones_simit as rs where rs.COL7 = c.numero and rs.COL5 = '1') as count_resolucion_sancion"),
            DB::raw("c.*"),
            DB::raw("vc.nombre as clase_vehiculo"),
            DB::raw("numero as final_numero"),
            DB::raw("in.infraccion as descripcion_infraccion"),
            DB::raw("'' as ultima_direccion"),
            DB::raw(
                "(
            case when es_fotomulta=1 and fecha_notificacion is not null then
                  case when fecha_notificacion <= DATE_ADD(curdate(), INTERVAL -15 DAY) then
                      true
                    else
                      false
                    end
                 when es_fotomulta=0 and infraccion_fecha <= DATE_ADD(curdate(), INTERVAL -15 DAY) then
                    true
                 else
                    false
                 end
            ) as is_sancionar"
            ),
            DB::raw(
                "(
            case when es_fotomulta=0 and infraccion_fecha<='2017-06-30' then
                  case when curdate()>DATE_ADD(infraccion_fecha, INTERVAL 6 MONTH) then false else DATE_ADD(infraccion_fecha, INTERVAL 6 MONTH) end
                when es_fotomulta=0 and infraccion_fecha>='2017-07-01' then
                  case when curdate()>DATE_ADD(infraccion_fecha, INTERVAL 12 MONTH) then false else DATE_ADD(infraccion_fecha, INTERVAL 12 MONTH) end
                when es_fotomulta=1 and fecha_pago is null and fecha_notificacion is not null then
                    DATE_ADD(fecha_notificacion, INTERVAL 12 MONTH)
                else
                  null
                end
            ) as limite_sancion"
            )
        )
            ->from(DB::raw('comparendos c'))
            ->leftJoin('vehiculos_clases as vc', 'vc.id', '=', 'c.vehiculo_tipo_vehiculo')
            ->leftJoin('infracciones as in', 'in.codigo', '=', 'c.infracciones')
            ->where('infraccion_fecha', 'BETWEEN', DB::raw("'2015-01-01' AND '2017-12-31'"))
            ->where(function ($query) {
                $query->where('id_tipo_evento', '=', DB::raw('0'))
                    ->orWhereNull('id_tipo_evento');
            })
            ->whereNull('fecha_pago')
            ->groupBy('c.id');
        /*validacion para filtrar las infracciones especiales que hay que ingresarles datos*/
        if ($validar) {
            $comparendos->where(function ($query) {
                $query->where('c.infracciones', '=', DB::raw('"D12"'))
                    ->orWhere('c.infracciones', '=', DB::raw('"E04"'))
                    ->orWhere('c.infracciones', '=', DB::raw('"F"'));
            });
        }
        $consulta = $comparendos;
        $querySql = $consulta->toSql();

        $queryFinal = DB::table(DB::raw("($querySql) as tabla"));

        if ($contar) {
            $comparendos = $queryFinal->count();
        } else {
            if ($orden == 'antiguo') {
                $queryFinal = $queryFinal
                    ->orderBy(DB::raw('id asc, infraccion_fecha'), 'asc');
            } elseif ($orden == 'reciente') {
                $queryFinal = $queryFinal
                    ->orderBy(DB::raw('id desc, infraccion_fecha'), 'desc');
            }
            $comparendos = $queryFinal;
        }
        return $queryFinal;
    }

    /**
     * @autor: David Bastidas
     * comparendos a verificar direccion mas reciente para sanciones
     */
    public static function verificarParaSancionEspecial($orden = 'antiguo', $contar = false, $group = 'id')
    {
        $comparendos = Comparendo::select(
            DB::raw("(select count(1) from resoluciones_simit as rs where rs.COL7 = c.numero and rs.COL5 = '1') as count_resolucion_sancion"),
            DB::raw("c.*"),
            DB::raw("numero as final_numero"),
            DB::raw("DATE_FORMAT(MAX(cu.fecha_actualizacion), '%d/%m/%Y') as ultima_direccion"),
            DB::raw(
                "(
                                case when es_fotomulta=1 and fecha_notificacion is not null then
                                      case when fecha_notificacion <= DATE_ADD(curdate(), INTERVAL -15 DAY) then
                                          true
                                        else
                                          false
                                        end
                                     when es_fotomulta=0 and infraccion_fecha <= DATE_ADD(curdate(), INTERVAL -15 DAY) then
                                        true
                                     else
                                        false
                                     end
                                ) as is_sancionar"
            ),
            DB::raw(
                "(
                                case when es_fotomulta=0 and infraccion_fecha<='2017-06-30' then
                                      case when curdate()>DATE_ADD(infraccion_fecha, INTERVAL 6 MONTH) then false else DATE_ADD(infraccion_fecha, INTERVAL 6 MONTH) end
                                    when es_fotomulta=0 and infraccion_fecha>='2017-07-01' then
                                      case when curdate()>DATE_ADD(infraccion_fecha, INTERVAL 12 MONTH) then false else DATE_ADD(infraccion_fecha, INTERVAL 12 MONTH) end
                                    when es_fotomulta=1 and fecha_pago is null and fecha_notificacion is not null then
                                        DATE_ADD(fecha_notificacion, INTERVAL 12 MONTH)
                                    else
                                      null
                                    end
                                ) as limite_sancion"
            )
        )
            ->from(DB::raw('comparendos c'))
            ->leftJoin('ciudadanos as ci', 'ci.numero_documento', '=', 'infractor_documento')
            ->leftJoin('ciudadanos_ubicacion as cu', 'cu.id_ciudadano', '=', 'ci.id')
            ->where(function ($query) {
                $query->where('cu.fecha_actualizacion', '<', DB::raw('DATE_ADD(curdate(), INTERVAL -3 MONTH)'))
                    ->orWhereNull('cu.fecha_actualizacion');
            })
            ->where('infraccion_fecha', 'BETWEEN', DB::raw("'2016-01-01' AND '2017-12-31'"))
            ->where(function ($query) {
                $query->where('id_tipo_evento', '=', DB::raw('0'))
                    ->orWhereNull('id_tipo_evento');
            })
            ->whereNull('fecha_pago')
            ->groupBy('c.id');

        $consulta = $comparendos;
        $querySql = $consulta->toSql();

        $queryFinal = DB::table(DB::raw("($querySql) as tabla"));
        $queryFinal = $queryFinal
            ->where('count_resolucion_sancion', '=', '0');
        if ($contar) {
            $queryFinal = $queryFinal->count();
        } else {
            if ($group == 'id') {
                //se agrupa para tener comparendo unico
                $queryFinal = $queryFinal->groupBy('id');
            } elseif ($group == 'documento') {
                //se agrupa cuando se quiere tener la cedula para el archivo runt
                $queryFinal = $queryFinal->groupBy('infractor_documento');
            }
            if ($orden == 'antiguo') {
                $queryFinal = $queryFinal
                    ->orderBy('infraccion_fecha', 'asc');
            } elseif ($orden == 'reciente') {
                $queryFinal = $queryFinal
                    ->orderBy('infraccion_fecha', 'desc');
            }
        }
        return $queryFinal;
    }

    /**
     * @autor: David Bastidas
     * comparendos persuadidos.
     */
    public static function persuadidos($orden = 'antiguo', $contar = false)
    {
        $comparendos = Comparendo::from('comparendos as c')
            ->join(DB::raw("comparendos_expediente ce"), 'ce.id_comparendo', '=', 'c.id')
            ->where('ce.id_tipo_evento', '=', '10');

        if ($contar) {
            $comparendos = $comparendos->count();
        } else {
            if ($orden == 'antiguo') {
                $comparendos = $comparendos
                    ->orderBy('ce.fecha_generacion', 'asc');
            } elseif ($orden == 'reciente') {
                $comparendos = $comparendos
                    ->orderBy('ce.fecha_generacion', 'desc');
            }
        }
        return $comparendos;
    }

    /**
     * @autor: David Bastidas
     * comparendos para cobro persuasivo entre 2012 y 2015
     */
    public static function habilitadoParaPersuasivo($orden = 'antiguo', $contar = false)
    {
        $comparendos = Comparendo::select(
            DB::raw("(select count(1) from resoluciones_simit as rs where rs.COL7 = c.numero and (rs.COL5 = '6' or rs.COL5 = '16' or rs.COL5 = '2' or rs.COL5 = '3' or rs.COL5 = '22' or rs.COL5 = '12')) as count_resolucion"),
            DB::raw("c.*"),
            DB::raw("numero as final_numero"),
            DB::raw("DATE_FORMAT(MAX(cu.fecha_actualizacion), '%d/%m/%Y') as ultima_direccion"),
            DB::raw("MAX(cu.direccion) as direccion_final"),
            DB::raw("MAX(cu.ciudad) as ciudad_final"),
            DB::raw("MAX(cu.telefono) as telefono_final"),
            DB::raw("in.infraccion as descripcion_infraccion"),
            DB::raw(
                "(
                              	case when es_fotomulta=1 and fecha_notificacion is not null then
                              				case when fecha_notificacion <= DATE_ADD(curdate(), INTERVAL -15 DAY) then
                              						true
                              					else
                              						false
                              					end
                              	     when es_fotomulta=0 and infraccion_fecha <= DATE_ADD(curdate(), INTERVAL -15 DAY) then
                              	     		true
                              	     else
                              	     		false
                              	     end
                              	) as is_sancionar"
            ),
            DB::raw(
                "(
                              	case when es_fotomulta=0 and infraccion_fecha<='2017-06-30' then
                              				case when curdate()>DATE_ADD(infraccion_fecha, INTERVAL 6 MONTH) then false else DATE_ADD(infraccion_fecha, INTERVAL 6 MONTH) end
                              		  when es_fotomulta=1 and fecha_pago is null and fecha_notificacion is not null then
                              		  		DATE_ADD(fecha_notificacion, INTERVAL 12 MONTH)
                              		  else
                              				null
                              		  end
                              	) as limite_sancion"
            )
        )
            ->from(DB::raw('comparendos c'))
            ->join('ciudadanos as ci', 'ci.numero_documento', '=', 'infractor_documento')
            ->join('ciudadanos_ubicacion as cu', 'cu.id_ciudadano', '=', 'ci.id')
            ->leftJoin('infracciones as in', 'in.codigo', '=', 'c.infracciones')
            ->where('cu.fecha_actualizacion', '>', DB::raw('DATE_ADD(curdate(), INTERVAL -3 MONTH)'))
            ->where('infraccion_fecha', 'BETWEEN', DB::raw("'2012-01-01' AND '2015-07-31'"))
            ->where(function ($query) {
                $query->where('id_tipo_evento', '=', DB::raw('0'))
                    ->orWhereNull('id_tipo_evento');
            })
            ->whereNull('fecha_pago')
            ->groupBy('c.id');

        $consulta = $comparendos;
        $querySql = $consulta->toSql();

        $queryFinal = DB::table(DB::raw("($querySql) as tabla where count_resolucion = 0"));

        if ($contar) {
            $queryFinal = $queryFinal->count();
        } else {
            if ($orden == 'antiguo') {
                $queryFinal = $queryFinal
                    ->orderBy(DB::raw('id asc, infraccion_fecha'), 'asc');
            } elseif ($orden == 'reciente') {
                $queryFinal = $queryFinal
                    ->orderBy(DB::raw('id desc, infraccion_fecha'), 'desc');
            }
        }
        return $queryFinal;
    }

    /**
     * @autor: David Bastidas
     * comparendos a verificar direccion mas reciente para cobro persuasivo entre 2012 y 2015
     */
    public static function verificarParaPersuasivo($orden = 'antiguo', $contar = false, $group = 'id')
    {
        $comparendos = Comparendo::select(
            DB::raw("(select count(1) from resoluciones_simit as rs where rs.COL7 = c.numero and (rs.COL5 = '6' or rs.COL5 = '16' or rs.COL5 = '2' or rs.COL5 = '3' or rs.COL5 = '22' or rs.COL5 = '12')) as count_resolucion"),
            DB::raw("c.*"),
            DB::raw("numero as final_numero"),
            DB::raw("DATE_FORMAT(MAX(cu.fecha_actualizacion), '%d/%m/%Y') as ultima_direccion"),
            DB::raw(
                "(
                              	case when es_fotomulta=1 and fecha_notificacion is not null then
                              				case when fecha_notificacion <= DATE_ADD(curdate(), INTERVAL -15 DAY) then
                              						true
                              					else
                              						false
                              					end
                              	     when es_fotomulta=0 and infraccion_fecha <= DATE_ADD(curdate(), INTERVAL -15 DAY) then
                              	     		true
                              	     else
                              	     		false
                              	     end
                              	) as is_sancionar"
            ),
            DB::raw(
                "(
                              	case when es_fotomulta=0 and infraccion_fecha<='2017-06-30' then
                              				case when curdate()>DATE_ADD(infraccion_fecha, INTERVAL 6 MONTH) then false else DATE_ADD(infraccion_fecha, INTERVAL 6 MONTH) end
                              		  when es_fotomulta=1 and fecha_pago is null and fecha_notificacion is not null then
                              		  		DATE_ADD(fecha_notificacion, INTERVAL 12 MONTH)
                              		  else
                              				null
                              		  end
                              	) as limite_sancion"
            )
        )
            ->from(DB::raw('comparendos c'))
            ->leftJoin('ciudadanos as ci', 'ci.numero_documento', '=', 'infractor_documento')
            ->leftJoin('ciudadanos_ubicacion as cu', 'cu.id_ciudadano', '=', 'ci.id')
            ->where(function ($query) {
                $query->where('cu.fecha_actualizacion', '<', DB::raw('DATE_ADD(curdate(), INTERVAL -3 MONTH)'))
                    ->orWhereNull('cu.fecha_actualizacion');
            })
            ->where('infraccion_fecha', 'BETWEEN', DB::raw("'2012-01-01' AND '2015-12-31'"))
            ->where(function ($query) {
                $query->where('id_tipo_evento', '=', DB::raw('0'))
                    ->orWhereNull('id_tipo_evento');
            })
            ->whereNull('fecha_pago')
            ->groupBy('c.id');

        $consulta = $comparendos;
        $querySql = $consulta->toSql();

        $queryFinal = DB::table(DB::raw("($querySql) as tabla where count_resolucion = 0"));

        if ($contar) {
            $queryFinal = $queryFinal->count();
        } else {
            if ($group == 'id') {
                //se agrupa para tener comparendo unico
                $queryFinal = $queryFinal->groupBy('id');
            } elseif ($group == 'documento') {
                //se agrupa cuando se quiere tener la cedula para el archivo runt
                $queryFinal = $queryFinal->groupBy('infractor_documento');
            }
            if ($orden == 'antiguo') {
                $queryFinal = $queryFinal
                    ->orderBy('infraccion_fecha', 'asc');
            } elseif ($orden == 'reciente') {
                $queryFinal = $queryFinal
                    ->orderBy('infraccion_fecha', 'desc');
            }
        }
        return $queryFinal;
    }

    /**
     * @autor: David Bastidas
     * funcion recursiva para tomar una fecha que no sea festivo, sabado o domingo.
     */
    public static function calcularFechaHabilLaboral($festivos, $fechaCarbon)
    {

        foreach ($festivos as $festivo) {
            if ($festivo->dia == $fechaCarbon->day && $festivo->mes == $fechaCarbon->month && $festivo->anio == $fechaCarbon->year) {
                $fechaCarbon = $fechaCarbon->addDays(1);
                $fechaCarbon = Comparendo::calcularFechaHabilLaboral($festivos, $fechaCarbon);
                break;
            } else if ($fechaCarbon->shortEnglishDayOfWeek == 'Sat') {
                $fechaCarbon = $fechaCarbon->addDays(2);
                $fechaCarbon = Comparendo::calcularFechaHabilLaboral($festivos, $fechaCarbon);
                break;
            } else if ($fechaCarbon->shortEnglishDayOfWeek == 'Sun') {
                $fechaCarbon = $fechaCarbon->addDays(1);
                $fechaCarbon = Comparendo::calcularFechaHabilLaboral($festivos, $fechaCarbon);
                break;
            }
        }
        return $fechaCarbon;
    }

    /**
     * @autor: David Bastidas
     * funcion recursiva para tomar una fecha que no sea festivo, sabado o domingo antes de un dia dado.
     */
    public static function calcularFechaHabilLaboralAnterior($festivos, $fechaCarbon)
    {

        foreach ($festivos as $festivo) {
            if ($festivo->dia == $fechaCarbon->day && $festivo->mes == $fechaCarbon->month && $festivo->anio == $fechaCarbon->year) {
                $fechaCarbon = $fechaCarbon->subDays(1);
                $fechaCarbon = Comparendo::calcularFechaHabilLaboralAnterior($festivos, $fechaCarbon);
                break;
            } else if ($fechaCarbon->shortEnglishDayOfWeek == 'Sat') {
                $fechaCarbon = $fechaCarbon->subDays(1);
                $fechaCarbon = Comparendo::calcularFechaHabilLaboralAnterior($festivos, $fechaCarbon);
                break;
            } else if ($fechaCarbon->shortEnglishDayOfWeek == 'Sun') {
                $fechaCarbon = $fechaCarbon->subDays(2);
                $fechaCarbon = Comparendo::calcularFechaHabilLaboralAnterior($festivos, $fechaCarbon);
                break;
            }
        }
        return $fechaCarbon;
    }

    public static function comparendosPendientesPorPago($ciudadano)
    {
        $comparendos = Comparendo::select(
            DB::raw("(select count(rs.COL4) from resoluciones_simit as rs where rs.COL7 = c.numero and rs.COL5 = '2' order by rs.COL4 limit 2) as countexfallo"),
            DB::raw("(select count(rs.COL4) from resoluciones_simit as rs where rs.COL7 = c.numero and rs.COL5 = '6' order by rs.COL4 limit 2) as countap"),
            DB::raw("(select count(rs.COL4) from resoluciones_simit as rs where rs.COL7 = c.numero and rs.COL5 = '8' order by rs.COL4 limit 2) as countapresumen"),
            DB::raw("(select count(rs.COL4) from resoluciones_simit as rs where rs.COL7 = c.numero and rs.COL5 = '12' order by rs.COL4 limit 2) as countanulacion"),
            DB::raw("(select count(rs.COL4) from resoluciones_simit as rs where rs.COL7 = c.numero and rs.COL5 = '16' order by rs.COL4 limit 2) as countmandamiento"),
            DB::raw("(select count(1) from resoluciones_simit as rs where rs.COL7 = c.numero and rs.COL5 = '1') as count_resolucion_sancion"),
            DB::raw("(select count(rs.COL4) from resoluciones_simit as rs where rs.COL7 = c.numero and rs.COL5 = '17' order by rs.COL4 limit 2) as count17"),
            DB::raw("(select count(rs.COL4) from resoluciones_simit as rs where rs.COL7 = c.numero and rs.COL5 = '18' order by rs.COL4 limit 2) as count18"),
            DB::raw("(select count(rs.COL4) from resoluciones_simit as rs where rs.COL7 = c.numero and rs.COL5 = '3' order by rs.COL4 limit 2) as prescrito"),
            DB::raw("(select count(rs.COL4) from resoluciones_simit as rs where rs.COL7 = c.numero and rs.COL5 = '21' order by rs.COL4 limit 2) as revocatoriadirecta"),
            DB::raw("c.*")
        )
            ->from(DB::raw('comparendos c'))
            ->where('c.infractor_documento', DB::raw("'$ciudadano'"))
            ->whereNull('fecha_pago');

        $consulta = $comparendos;
        $querySql = $consulta->toSql();

        $queryFinal = DB::table(DB::raw("($querySql) as tabla"));

        return $queryFinal;
    }

    public static function getResolucionesByComparendo($comparendo)
    {
        $resoluciones = ResolucionSimit::select(
            DB::raw("rs.*, STR_TO_DATE(COL4, '%d/%m/%Y') AS COL4F")
        )
            ->from(DB::raw('resoluciones_simit as rs'))
            ->where('COL7', DB::raw("'$comparendo'"));

        return $resoluciones;
    }

    public static function tieneSaldo($comparendo_id){
      $respuesta = true;
      $comparendo = Comparendo::find($comparendo_id);
      if($comparendo->fecha_pago != '' || $comparendo->fecha_pago != null){
        //esta pago por marcado en pago total como SI o por fecha de pago vieja
        $respuesta = false;
      }else{
        $resolucionParaTerminacion = ResolucionSimit::where('COL7', $comparendo->numero)
          ->where(function ($query) {
            $query->where('COL5', '=', '21')//revocatoria directa
                ->orWhere('COL5', '=', '2')//exoneracion fallo
                ->orWhere('COL5', '=', '3')//exoneracion prescripcion
                ->orWhere('COL5', '=', '4')//exoneracion caducidad
                ->orWhere('COL5', '=', '5')//cese procedimiento
                ->orWhere('COL5', '=', '10')//anulacion acuerdo pago
                ->orWhere('COL5', '=', '12')//anulacion resolucion
                ->orWhere('COL5', '=', '15')//deja comparendo pendiente fallo
                ->orWhere('COL5', '=', '18')//anulacion de cobro
                ->orWhere('COL5', '=', '22')//nulidad por fallo
                ->orWhere('COL5', '=', '23')//asistencia curso comparendo
                ->orWhere('COL5', '=', '25')//asistencia curso resolucion
                ->orWhere('COL5', '=', '27')//proceso en excepcion
                ->orWhere('COL5', '=', '29')//cumplimiento ap
                ->orWhere('COL5', '=', '31')//pendiente de pago de fallo
                ->orWhere('COL5', '=', '266');//terminacion de cobro propio de xiltrion
          })->first();
        if(isset($resolucionParaTerminacion->id)){
          //tiene una resolucion que lo da por terminado
          $respuesta = false;
        }
      }
      return $respuesta;
    }
    public static function tieneAcuerdoVigente($comparendo_id){
      //tomar el acuerdo mas reciente y validar si esta incumplido o
      //validar que los pagos sean lo mas reciente a la fecha de consulta
      $respuesta = false;
      $comparendo = Comparendo::find($comparendo_id);
      $acuerdo = ResolucionSimit::where('COL5', '6')->where('COL7', $comparendo->numero)->first();
      if(isset($acuerdo->id)){
        //tiene acuerdo y debe validar si esta en cumplimiento
        $incumplimiento_acuerdo = ResolucionSimit::where('COL7', $comparendo->numero)
                                                  ->where(function ($query) {
                                                      $query->where('COL5', '9')
                                                          ->orWhere('COL5', '10');
                                                  })->first();
        if(isset($incumplimiento_acuerdo->id)){
          $respuesta = false;
        }else{
          $respuesta = true;
        }
      }
      return $respuesta;
    }

    public static function estadoNotificacion($comparendo_id){
      //buscando en que punto se encuentra la notificacion
      $objeto = new UnObjeto();
      $objeto->mensaje = "";
      $objeto->tipo = "";
      $objeto->fecha = "";
      $objeto->fecha_format = "";
      $objeto->flag = false;

      $citacion = EntregaNotificaciones::where('id_comparendo', $comparendo_id)->where('id_tipo_evento', 24)->first();
      if(isset($citacion->id)){//tiene citacion
        $fechaEntrega = new Carbon($citacion->fecha_entrega);
        $fechaEntrega = $fechaEntrega->format('d/m/Y');
        $fechaGestion = new Carbon($citacion->fecha_gestion);
        $fechaGestion = $fechaGestion->format('d/m/Y');
        if($citacion->estado == -1){
          $objeto->mensaje = "Enviada E-mail: " . $citacion->numero_guia . " - FECHA: ". $fechaEntrega;
          $objeto->flag = true;
        } else if($citacion->estado == 1 || $citacion->estado == 3){
          $objeto->mensaje = "Citacion Entregada - Guia: " . $citacion->numero_guia . " - FECHA: ". $fechaGestion;
          $objeto->flag = true;
        } else if($citacion->estado == 2){//fue devuelto por citacion
          $objeto->mensaje = "Citacion Devuelta - Guia: " . $citacion->numero_guia . " - FECHA: ". $fechaGestion;
          $objeto->flag = false;
        }
      }

      //buscar la notificacion personal
      $notificacion = NotiOfi::where('id_comparendo', $comparendo_id)->where('id_tipo_evento', 35)->first();
      if(isset($notificacion->id)){//tiene notificacion
        $fechaGestion = new Carbon($notificacion->fecha_gestion);
        $fechaGestion = $fechaGestion->format('d/m/Y');
        if($notificacion->estado == 1 || $notificacion->estado == 3){
          $objeto->mensaje = "Notificacion Personal Entregada - Guia: " . $notificacion->numero_guia . " - FECHA: ". $fechaGestion;
          $objeto->tipo = "notificacionpersonal";
          $fechaC = new Carbon($notificacion->fecha_gestion);
          $objeto->fecha = $fechaC->format('d/m/Y');
          $objeto->fecha_format =  $fechaC->format('Y-m-d');
          $objeto->flag = true;
        } else if($notificacion->estado == 2){//fue devuelto por citacion
          $objeto->mensaje = "Notificacion Personal Devuelta - Guia: " . $notificacion->numero_guia . " - FECHA: ". $fechaGestion;
          $objeto->flag = false;
        }
      }

      //buscar la notificacion personal
      $notiOfi = EntregaNotificaciones::where('id_comparendo', $comparendo_id)->where(function ($query) {
                                          $query->where('id_tipo_evento', 45)
                                              ->orWhere('id_tipo_evento', 47);
                                      })->first();
      if(isset($notiOfi->id)){//tiene notificacion por oficina
        $fechaGestion = new Carbon($notiOfi->fecha_generacion);
        $fechaGestion = $fechaGestion->format('d/m/Y');
        $objeto->mensaje = "Notificacion Por Oficina. FECHA: ". $fechaGestion;
        $objeto->tipo = "notificacionmanual";
        $fechaC = new Carbon($notiOfi->fecha_generacion);
        $objeto->fecha = $fechaC->format('d/m/Y');
        $objeto->fecha_format =  $fechaC->format('Y-m-d');
        $objeto->flag = true;
      }

      //buscar la notificacion por acuerdo de pago
      $acuerdo = ComparendoExpediente::where('id_tipo_evento', '=', '16')
                                          ->where('id_comparendo', '=', $comparendo_id)
                                          ->first();
      if(isset($acuerdo->id)){//tiene acuerdo
        $fechaGestion = new Carbon($acuerdo->fecha_generacion);
        $fechaGestion = $fechaGestion->format('d/m/Y');
        $objeto->mensaje = "Notificado Por Acuerdo de Pago - AP: " . $acuerdo->nombre_documento . " - FECHA: ". $fechaGestion;
        $objeto->tipo = "acuerdo";
        $fechaC = new Carbon($acuerdo->fecha_generacion);
        $objeto->fecha = $fechaC->format('d/m/Y');
        $objeto->fecha_format =  $fechaC->format('Y-m-d');
        $objeto->flag = true;
      }

      //buscar la notificacion por aviso
      $aviso = ComparendoExpediente::where('id_tipo_evento', '=', '14')
                                          ->where('id_comparendo', '=', $comparendo_id)
                                          ->first();
      if(isset($aviso->id)){//tiene aviso
        $fechaGestion = new Carbon($aviso->fecha_generacion);
        $fechaGestion = $fechaGestion->format('d/m/Y');
        $objeto->mensaje = "Notificado Por Aviso - Aviso: " . $aviso->nombre_documento . " - FECHA: ". $fechaGestion;
        $objeto->tipo = "avisomandamiento";
        $fechaC = new Carbon($aviso->fecha_generacion);
        $objeto->fecha = $fechaC->format('d/m/Y');
        $objeto->fecha_format =  $fechaC->format('Y-m-d');
        $objeto->flag = true;
      }
      return $objeto;
    }

    public static function comparendosParaProcesoSentencia()
    {
        $comparendos = Comparendo::select(
            DB::raw("(select count(1) from ettcurumani.comparendos_expediente as ce where ce.id_comparendo = c.id and ce.id_tipo_evento = 14 limit 1) as avisomandamiento"),
            DB::raw("(select count(1) from ettcurumani.comparendos_expediente as ce where ce.id_comparendo = c.id and ce.id_tipo_evento = 35 limit 1) as notificacionpersonal"),
            DB::raw("c.*")
        )
        ->from(DB::raw('ettcurumani.comparendos c'))
        ->whereNull('fecha_pago');

        $consulta = $comparendos;
        $querySql = $consulta->toSql();

        $queryFinal = DB::table(DB::raw("($querySql) as tabla"));

        return $queryFinal;
    }

    public static function saldo($comparendo_id){
      $objeto = new ClaseSaldo();
      $objeto->esAcuerdo = false;
      $objeto->saldo = 0;

      $campana = 0;
      $campana2 = 0;
	    $respuesta = 0;
      $honorario = ParamHonorario::orderby('id', 'desc')->first();
      $sistematizacion = ParamSistematizacion::orderby('id', 'desc')->first();
	    $comparendos = Comparendo::where('id', $comparendo_id)->get();
      foreach($comparendos as $comparendo){
  
    $col5=0;
    $rid=0;
    $dif =0;
    $intereses_calculados2=0;
    $intereses_calculados=0;
    $campana_calculados =0;
    $campana2_calculados =0;
    $valor_honorario=0;
    $valor_sistematizacion=0;
    $tipo_resol=0;
    $pagos=$comparendo->pendiente;
    $total=$comparendo->valor - $comparendo->pagos;
    //$ff = "".Carbon::now()->format('Y-m-d');
    /*
    $date1 = new DateTime($comparendo->infraccion_fecha);
    $date2 = new DateTime("now");
    $dif = $date1->diff($date2);*/


    //$date1 = new DateTime($comparendo->infraccion_fecha);
    //$date2 = new DateTime("now");
    //$dif = $date1->diff($date2);



        foreach($comparendo->obtenerInfracciones() as $infraccion){

					foreach($comparendo->obtenerResolucion() as $resolucion){


					  $tipo_resol=$resolucion->COL5;
					  $valo=$resolucion->COL23;

					  $total=$valo - $comparendo->pagos;
                      $id_resolucion_pagar=$resolucion->COL2;

					  $col5=$resolucion->COL5;
					  $rid=$resolucion->id;
                      $val_compa=$resolucion->COL23;
					  //$total=$resolucion->COL23;
					  if($resolucion->COL5=="1"|| $resolucion->COL5=="270"
                       || $resolucion->COL5=="16"  || $resolucion->COL5=="17"){

            $c=ResolucionSimit::where('COL7', $comparendo->numero)->where('COL5', 1)->get();
            $fecha_inicial=$resolucion->COL4;
            
            foreach($c as $resol){
                $fecha_inicial=$resol->COL4;
                $val_compa=$resol->COL23;
            }




              //$intereses_calculados2 =Comparendo::calcularIntereses($fecha_inicial,$val_compa,1);
              $intereses_calculados = Comparendo::calcularIntereses($fecha_inicial,$val_compa,0);
              //$diff = Comparendo::calcularIntereses($fecha_inicial,$val_compa,2);

    $campana_calculados =($intereses_calculados * $campana/100);
        $campana2_calculados =($val_compa * $campana2/100);
        //$val_compa=$val_compa-$campana2_calculados;
    $comparendo->intereses=$intereses_calculados;   
    $valor_honorario2 = $honorario->valor * ($intereses_calculados*1 + $val_compa*1 )/100; //- $campana_calculados
        $comparendo->campana=$campana;
        $comparendo->campana=$campana2;

                              $comparendo->honorarios=$valor_honorario; 
                               $comparendo->sistematizacion=$valor_sistematizacion;
          		//$campana_calculados =($intereses_calculados * $campana/100);
          		//$comparendo->intereses=$intereses_calculados;
          		//$valor_honorario2 = $honorario->valor * ($intereses_calculados*1 + $val_compa*1)/100;
              //$comparendo->campana=$campana;
                       if( $resolucion->COL5=="16"  || $resolucion->COL5=="17"){
							  $valor_sistematizacion=$sistematizacion->valor;
					      $comparendo->honorarios=$valor_honorario2;
							  $valor_honorario=$valor_honorario2;
						  }else
                         {
                            //$valor_sistematizacion=$sistematizacion->valor;
                            $comparendo->intereses=0;   
                            $intereses_calculados=0;                   
                         }
					   

                if( $resolucion->COL5=="1"  && env('TRANSITO')=="Santa Catalina")
                 {
                   $valor_sistematizacion=$sistematizacion->valor;
                  // $comparendo->honorarios=$valor_honorario2;
                  // $valor_honorario=$valor_honorario2;
                 }

                               if( $resolucion->COL5=="6"  || $resolucion->COL5=="8")
                               {
                                   $comparendo->honorarios=0;
                                   $comparendo->intereses=0;
                                   $comparendo->sistematizacion=0;
                               }   
                     }
						$comparendo->valor_resolucion=$val_compa;
						$comparendo->save();
					}//end for
				}//end for
      }//end for
//$respuesta =($total+$intereses_calculados+$valor_honorario+$valor_sistematizacion-$campana_calculados);
$respuesta =   $total+$intereses_calculados+$valor_honorario+$valor_sistematizacion-$campana_calculados-$campana2_calculados;
      $objeto->saldo = $respuesta;

      $objeto->inte = $intereses_calculados;
      $objeto->hono = $valor_honorario;
      $objeto->siste = $valor_sistematizacion;
      $objeto->campa = $campana_calculados;
      $objeto->campa2 = $campana2_calculados;
      //$objeto->descu = $respuesta;
      $objeto->compa = $total;


      return $objeto;
    }

static function calcularIntereses(String $fi,int $valor,int $par)
    {



        $interes = 0;
        $total_dias = 0;
        $cad_interes = "";
        $ano=substr($fi,6,4);
        $mes=substr($fi,3,2);
        $dia=substr($fi,0,2);
        $ff = "".Carbon::now()->format('Y-m-d');
        $anof=substr($ff,0,4);
        $mesf=substr($ff,5,2);
        $diaf=substr($ff,8,2);

        $festivos=FestivosBack::where('anio','>=', $ano)->get();
        $fi_a=$ano."-".$mes."-".$dia;
        $fi_a = new Carbon($fi_a);

        for($i=1;$i<=15;$i++)
        {
              $fi_a = Comparendo::calcularFechaHabilLaboral($festivos, $fi_a);
              $fi_a=new Carbon($fi_a);
              if($i<15)
              {
              $fi_a=$fi_a->addDays(1);
              }
        }


    if($fi_a->lt(Carbon::now()))
    {
        $fi=$fi_a->format('d-m-Y');
        $ano=substr($fi,6,4);
        $mes=substr($fi,3,2);
        $dia=substr($fi,0,2);
        
        $parametros = ParamInteres::where('ano','=', $ano)->where('mes','>=', $mes*1)->where('valor','>', 0)->orderBy('id')->get();
        foreach ($parametros as $parametro) {
            $dias=$parametro->dias;
            if($parametro->ano==$ano && $parametro->mes==$mes)
            {
                $dias=$dias-$dia;
            }
            if($parametro->ano==$anof && $parametro->mes==$mesf)
            {
                $dias=$diaf;
            }
            $total_dias = $total_dias+$dias;
            $interes=$interes + ($parametro->valor/12)/30*$valor*$dias/100;
            $cad_interes= $cad_interes . "(".$parametro->valor."/12)/30*".$valor."*".$dias."-->".$parametro->ano."-".$parametro->mes."\r";
        }

        $parametros = ParamInteres::where('ano','>', $ano*1)->where('valor','>', 0)->orderBy('id')->get();
        foreach ($parametros as $parametro) {
            $dias=$parametro->dias;
            if($parametro->ano==$anof && $parametro->mes==$mesf)
            {
                $dias=$diaf;
            }
            $total_dias = $total_dias+$dias;
            $interes=$interes + ($parametro->valor/12)/30*$valor*$dias/100;
            $cad_interes= $cad_interes . "(".$parametro->valor."/12)/30*".$valor."*".$dias."-->".$parametro->ano."-".$parametro->mes."\r";
        }
    }


        //return $ano."-".$mes."-".$dia."--".$anof."-".$mesf."-".$diaf;
        if($par==1)
        {
            return $cad_interes." = ".$interes;
        }
        if($par==0)
        {
            return $interes;
        }
        if($par==2)
        {
            return $interes;
        }
    }


    static function calcularInteresesback(String $fi,int $valor,int $par)
    {
        $interes = 0;
        $total_dias = 0;
        $cad_interes = "";
        $ano=substr($fi,6,4);
        $mes=substr($fi,3,2);
        $dia=substr($fi,0,2);
        $ff = "".Carbon::now()->format('Y-m-d');
        $anof=substr($ff,0,4);
        $mesf=substr($ff,5,2);
        $diaf=substr($ff,8,2);

        $festivos=FestivosBack::where('anio','>=', $ano)->get();
        $fi_a=$ano."-".$mes."-".$dia;
        $fi_a = new Carbon($fi_a);

        for($i=1;$i<=15;$i++)
        {
              $fi_a = Comparendo::calcularFechaHabilLaboral($festivos, $fi_a);
              $fi_a=new Carbon($fi_a);
              if($i<15)
              {
              $fi_a=$fi_a->addDays(1);
              }
        }


    if($fi_a->lt(Carbon::now()))
    {
        $fi=$fi_a->format('d-m-Y');
        $ano=substr($fi,6,4);
        $mes=substr($fi,3,2);
        $dia=substr($fi,0,2);
        
        $parametros = ParamInteres::where('ano','=', $ano)->where('mes','>=', $mes*1)->where('valor','>', 0)->orderBy('id')->get();
        foreach ($parametros as $parametro) {
            $dias=$parametro->dias;
            if($parametro->ano==$ano && $parametro->mes==$mes)
            {
                $dias=$dias-$dia;
            }
            if($parametro->ano==$anof && $parametro->mes==$mesf)
            {
                $dias=$diaf;
            }
            $total_dias = $total_dias+$dias;
            $interes=$interes + ($parametro->valor/12)/30*$valor*$dias/100;
            $cad_interes= $cad_interes . "(".$parametro->valor."/12)/30*".$valor."*".$dias."-->".$parametro->ano."-".$parametro->mes."\r";
        }

        $parametros = ParamInteres::where('ano','>', $ano*1)->where('valor','>', 0)->orderBy('id')->get();
        foreach ($parametros as $parametro) {
            $dias=$parametro->dias;
            if($parametro->ano==$anof && $parametro->mes==$mesf)
            {
                $dias=$diaf;
            }
            $total_dias = $total_dias+$dias;
            $interes=$interes + ($parametro->valor/12)/30*$valor*$dias/100;
            $cad_interes= $cad_interes . "(".$parametro->valor."/12)/30*".$valor."*".$dias."-->".$parametro->ano."-".$parametro->mes."\r";
        }
    }


        //return $ano."-".$mes."-".$dia."--".$anof."-".$mesf."-".$diaf;
        if($par==1)
        {
            return $cad_interes." = ".$interes;
        }
        if($par==0)
        {
            return $interes;
        }
        if($par==2)
        {
            return $interes;
        }
    }

    public static function calcularInteresesack(String $fi,int $valor,int $par){
      $interes = 0;
      $total_dias = 0;
      $cad_interes = "";
      $ano=substr($fi,6,4);
      $mes=substr($fi,3,2);
      $dia=substr($fi,0,2);
      $ff = "".Carbon::now()->format('Y-m-d');
      $anof=substr($ff,0,4);
      $mesf=substr($ff,5,2);
      $diaf=substr($ff,8,2);
      $parametros = ParamInteres::where('ano','=', $ano)->where('mes','>=', $mes*1)->where('valor','>', 0)->orderBy('id')->get();
      foreach ($parametros as $parametro) {
          $dias=$parametro->dias;
          if($parametro->ano==$ano && $parametro->mes==$mes)
          {
              $dias=$dias-$dia;
          }
          if($parametro->ano==$anof && $parametro->mes==$mesf)
          {
              $dias=$diaf;
          }
          $total_dias = $total_dias+$dias;
          $interes=$interes + ($parametro->valor/12)/30*$valor*$dias/100;
          $cad_interes= $cad_interes . "(".$parametro->valor."/12)/30*".$valor."*".$dias."-->".$parametro->ano."-".$parametro->mes."\r";
      }

      $parametros = ParamInteres::where('ano','>', $ano*1)->where('valor','>', 0)->orderBy('id')->get();
      foreach ($parametros as $parametro) {
          $dias=$parametro->dias;
          if($parametro->ano==$anof && $parametro->mes==$mesf)
          {
              $dias=$diaf;
          }
          $total_dias = $total_dias+$dias;
          $interes=$interes + ($parametro->valor/12)/30*$valor*$dias/100;
          $cad_interes= $cad_interes . "(".$parametro->valor."/12)/30*".$valor."*".$dias."-->".$parametro->ano."-".$parametro->mes."\r";
      }

      //return $ano."-".$mes."-".$dia."--".$anof."-".$mesf."-".$diaf;
      if($par==1)
      {
          return $cad_interes." = ".$interes;
      }
      if($par==0)
      {
          return $interes;
      }
      if($par==2)
      {
          return $interes;
      }
    }

    public static function comparendosParaProcesoApropiacion($identificacion)
    {
        $comparendos = Comparendo::select(
            DB::raw("(select count(1) from ettcurumani.comparendos_expediente as ce where ce.id_comparendo = c.id and ce.id_tipo_evento = 7 limit 1) as sentencia"),
            DB::raw("c.*")
        )
        ->from(DB::raw('comparendos c'))
        ->where('infractor_documento', DB::raw("'$identificacion'"));

        $consulta = $comparendos;
        $querySql = $consulta->toSql();

        $queryFinal = DB::table(DB::raw("($querySql) as tabla"));

        return $queryFinal;
    }
    //marca el comparendo como notificado para poder generar sentencia
    public static function marcarNotificado($comparendo_id, $tipo, $fechaNotificado){
      $respuesta = false;
      $comparendo = Comparendo::find($comparendo_id);

      if($tipo == 45){
        $tipo = 'notificacionpersonal';$respuesta = true;
      } elseif($tipo == 46){
        $tipo = 'notificacionsentencia';$respuesta = true;
      } elseif($tipo == 47){
        $tipo = 'notificacionmanual';$respuesta = true;
      } elseif($tipo == 48){
        $tipo = 'notificacionmanualsentencia';$respuesta = true;
      } elseif($tipo == 'acuerdo'){
        $tipo = 'acuerdo';$respuesta = true;
      } elseif($tipo == 'avisomandamiento'){
        $tipo = 'avisomandamiento';$respuesta = true;
      }
      if($respuesta){
        $not = new ComparendosNotificados();
        $not->id_comparendo = $comparendo->id;
        $not->fecha = $fechaNotificado;
        $not->medio = $tipo;
        $not->mensaje = "";
        $not->save();
      }
      return $respuesta;
    }
}
class UnObjeto{
  var $mensaje;
  var $tipo;
  var $fecha;
  var $flag;
}
class ClaseSaldo{
  var $esAcuerdo;
  var $saldo;
  var $inte;
  var $hono;
  var $siste;
  var $campa;
  var $campa2;
  var $descu;
  var $compa;
}
