<?php

namespace App\Console\Commands;

use App\Impuesto;
use App\Numeracion;
use App\NumeracionDetalle;
use App\Pago;
use App\Transaccion;
use App\Vehiculo;
use Carbon\Carbon;
use Illuminate\Console\Command;

class ImpuestoHistorico extends Command
{
    /**
     * The name and signature of the console command.
     *
     * @var string
     */
    protected $signature = 'impuesto:historico';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description = 'Command description';

    /**
     * Create a new command instance.
     *
     * @return void
     */
    public function __construct()
    {
        parent::__construct();
    }

    /**
     * Execute the console command.
     *
     * @return mixed
     */
    public function handle()
    {
        \Excel::load('storage/app/enero.csv', function ($reader) {
            // Getting all results
            $results = $reader->get();

            $c = 1;
            $fecha = null;
            $placa = null;
            $numeroRecibo = null;
            $totalTransaccion = 0;

            foreach ($results as $result){
                if($result->ano){
                    $ano = trim($result->ano);

                    if (!empty($result->fecha)) {
                        $fecha = Carbon::createFromFormat("d/m/y", $result->fecha);
                    }

                    if (!empty($result->placa)) {
                        $placa = trim($result->placa);
                    }

                    $this->line("");
                    $this->line("============================");
                    $this->line("PLACA: {$placa} - ANO: {$ano}");


                    if (!Vehiculo::where('placa', $placa)->exists()) {
                        $this->line("CREANDO VEHICULO");
                        $vehiculo = new Vehiculo();
                        $vehiculo->placa = $placa;
                        $vehiculo->id_tipo = 2;
                        $vehiculo->save();
                    } else {
                        $vehiculo = Vehiculo::where('placa', $placa)->first();
                        $this->line("VEHICULO ID {$vehiculo->id}");
                    }

                    if (!empty($result->recibo)) {
                        $numeroRecibo = $result->recibo;
                    }

                    $impuestos = 0;
                    if ($result->impuesto) {
                        $impuestos = $result->impuesto;
                    }

                    $intereses = 0;
                    if ($result->intereses) {
                        $intereses = $result->intereses;
                    }

                    $honorarios = 0;
                    if ($result->gastosdecobranza) {
                        $honorarios = $result->gastosdecobranza;
                    }

                    $sistematizacion = 0;
                    if ($result->sistematizacion) {
                        $sistematizacion = $result->sistematizacion;
                    }


                    if (Impuesto::where('ano', $ano)->where('id_vehiculo', $vehiculo->id)->exists()) {
                        $this->error("IMPUESTO PAGADO EXISTE");
                    } else {
                        $this->line("REGISTRANDO IMPUESTO PAGADO");
                        $impuesto = new Impuesto();
                        $impuesto->ano = $ano;
                        $impuesto->id_vehiculo = $vehiculo->id;
                        $impuesto->save();
                    }


                    if (Pago::where('ano', $ano)->where('id_vehiculo', $vehiculo->id)->exists()) {
                        $this->error("PAGO EXISTE");
                    } else {
                        $this->line("REGISTRANDO PAGO ($" . number_format($sistematizacion + $honorarios + $impuestos + $intereses, 0, ".", ".") . ")");
                        $pago = new Pago();
                        $pago->id_vehiculo = $vehiculo->id;
                        $pago->concepto = 'impuesto';
                        $pago->descripcion = "Pago Impuesto Vehicular";
                        $pago->valor = $sistematizacion + $honorarios + $impuestos + $intereses;
                        $pago->pago_aplicado_intereses = $intereses;
                        $pago->pago_aplicado_impuestos = $impuestos;
                        $pago->pago_aplicado_honorarios = $honorarios;
                        $pago->pago_aplicado_sistematizacion = $sistematizacion;
                        $pago->estado = 'pagado';
                        $pago->ano = $ano;
                        $pago->created_at = $fecha->format("Y-m-d");
                        $pago->id_transaccion = 9999;
                        $pago->save();
                    }

                    $c++;
                }
            }
        })->get();

        $pagos = Pago::where('id_transaccion', 9999)->groupBy('id_vehiculo')->get();

        foreach ($pagos as $pago) {
            $total = Pago::where('id_transaccion', 9999)->where('id_vehiculo', $pago->id_vehiculo)->sum('valor');

            $recibo = [];
            $recibo['iva'] = 0;
            $recibo['ciudadano'] = 9999;
            $recibo['vehiculo'] = $pago->id_vehiculo;
            $recibo['datos'] = [];

            $now = Carbon::now()->format('Ymd');
            $dir = storage_path('app/public/recibos/' . $now);

            if (!\File::exists($dir)) {
                \File::makeDirectory($dir);
            }

            $archivo = uniqid() . '.pdf';
            $recibo['total'] = $total - $recibo['iva'];

            $this->line("REGISTRANDO TRANSACCIÓN - VEHICULO {$pago->id_vehiculo} ($" . number_format($total, 0, ".", ".") . ")");
            $transaccion = new Transaccion();
            $transaccion->valor = $total;
            $transaccion->archivo = $now . '/' . $archivo;
            $transaccion->descripcion = "Pago Impuesto";
            $transaccion->etiqueta = "pago-impuesto";
            $transaccion->id_usuario = 0;
            $transaccion->created_at = $pago->created_at;
            $transaccion->factura = json_encode($recibo);
            $transaccion->save();

            Pago::where('id_vehiculo', $pago->id_vehiculo)->where('id_transaccion', 9999)->update(['id_transaccion' => $transaccion->id]);
            $pago->save();

            $numeracion = Numeracion::find(6);
            $numero = $numeracion->ultimo() + 1;

            //Agregar detalle
            $detalle = new NumeracionDetalle();
            $detalle->id_numeracion = $numeracion->id;
            $detalle->id_transaccion = $transaccion->id;
            $detalle->numero = $numero;
            $detalle->save();
        }
    }
}