<?php

namespace App\Console\Commands;

use Illuminate\Console\Command;
use Carbon\Carbon;
use App\Comparendo;
use App\ComparendoExpediente;
use App\ComparendoNumeracionImpresion as Numeracion;
use App\Festivos;
use Illuminate\Support\Facades\DB;
use Barryvdh\DomPDF\Facade as PDF;
use LynX39\LaraPdfMerger\PdfManage;

class MandamientoEspecial extends Command
{
    /**
     * The name and signature of the console command.
     *
     * @var string
     */
    protected $signature = 'mandamientoespecial:start {total} {medio}';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description = 'Command description';

    /**
    * variables de contenido de la tarea
    */
    protected $relacionContenido = '';
    protected $pdfMasivo = '';
    protected $comparendosImpresos = array();
    protected $ultimaNumeracion = 1900;
    protected $comparendopdf = '';
    protected $meses = [];
    protected $organismoNombreSecreteria = '';
    protected $organismoDireccion = '';
    protected $rutaImagenTop = '';
    protected $rutaFirma = '';

    /**
     * Create a new command instance.
     *
     * @return void
     */
    public function __construct()
    {
        parent::__construct();
    }

    /**
     * Execute the console command.
     *
     * @return mixed
     */
    public function handle()
    {
        $totalAImprimir = $this->argument('total');
        $medio = $this->argument('medio');
        $this->rutaImagenTop = '';
        if($medio == "c"){
          $this->rutaImagenTop = base_path() . '/public/images/hoja membrete.jpg';
          $this->rutaFirma = base_path() . '/public/images/firma2.png';
        } else if($medio == "w"){
          $this->rutaImagenTop = base_path() . '/public/images/hoja membrete.jpg';
          $this->rutaFirma = base_path() . '/public/images/firma2.png';
        }
        $this->line("totalAImprimir: $totalAImprimir");
        $rutaExpediente = \Config::get('myconfig.ruta_comparendo_expediente');
        $rutaPaquete = \Config::get('myconfig.ruta_paquetes_mensajeria');

        $organismo = \App\Organismo::first();
        $this->organismoDireccion = $organismo->direccion . ' ' . $organismo->ciudad->nombre . ' - ' . $organismo->ciudad->departamento->nombre;
        $this->organismoNombreSecreteria = $organismo->secretaria_nombre;

        $this->pdfMasivo = view('comparendos.especial.mandamiento_head_pdf', [
                                'organismoDireccion' => $this->organismoDireccion,
                                'rutaImagenTop' => $this->rutaImagenTop
                              ]);
        $this->pdfMasivo .= '<style>.page-break {page-break-after: always;}</style>';

        //creando el paquete
        $paquete = new \App\ComparendoPaquete();
        $paquete->nombre = Carbon::now();
        $paquete->fecha = Carbon::now();
        $paquete->id_user = 4;
        $paquete->id_tipo_evento = 5;
        $paquete->es_impreso = 0;
        $paquete->save();

        $maxId = Comparendo::where('id_tipo_evento', '13')->limit(1)->offset(0)->orderBy('id', 'desc')->value('id');
        if($maxId > 0){
          $numeracion = Numeracion::select(DB::raw("max(final) as final"))->where('id_tipo_evento', '5')->first();

          if($numeracion != null){
            $this->ultimaNumeracion = $numeracion->final;
          }
          $inicioNumeracion = $this->ultimaNumeracion + 1;

          $this->meses = array('Enero', 'Febrero', 'Marzo', 'Abril', 'Mayo', 'Junio', 'Julio',
                         'Agosto', 'Septiembre', 'Octubre', 'Noviembre', 'Diciembre');

          $convertidorNumerosALetras = new \NumberToLetterConverter();

          $festivos = Festivos::all();
          Comparendo::where('id_tipo_evento', '13')->where('id', '<=', $maxId)->orderBy('id', 'desc')
                      ->chunk(200, function ($comparendos) use ($rutaExpediente, $paquete, $convertidorNumerosALetras, $festivos) {

                          foreach ($comparendos as $comparendo) {
                              $this->ultimaNumeracion++;

                              $aviso = ComparendoExpediente::where('id_comparendo', '=', $comparendo->id)->where('id_tipo_evento', '=', '13')->first();
                              $fechaAvisoCarbon = new Carbon($aviso->fecha_generacion);

                              $fechaRetiroAviso = Comparendo::calcularFechaHabilLaboral($festivos, $fechaAvisoCarbon->addDays(7));
                              $fechaRetiroCarbon = new Carbon($fechaRetiroAviso);

                              $fechaMandamiento = $fechaRetiroCarbon->addDays(30);
                              $fechaMandamientoCarbon = new Carbon($fechaMandamiento);
                              $fechaGeneracionMandamiento = $fechaMandamientoCarbon->day . ' de ' . $this->meses[$fechaMandamientoCarbon->month - 1] . ' de ' . $fechaMandamientoCarbon->year;

                              $archivo = 'MP-' . $this->ultimaNumeracion . '-' . $fechaMandamientoCarbon->year . '.pdf';

                              $this->comparendosImpresos[] = array('final_numero' => $comparendo->numero);
                              $folder = $rutaExpediente . '/' . $comparendo->final_numero;
                              \File::makeDirectory($folder, 0755, true, true);

                              $this->comparendopdf = view('comparendos.especial.mandamiento_head_pdf',[
                                                      'organismoDireccion' => $this->organismoDireccion,
                                                      'rutaImagenTop' => $this->rutaImagenTop
                                                    ]);
                              $infraccion_fecha = new Carbon($comparendo->infraccion_fecha);
                              $infraccion_fecha = $infraccion_fecha->format('d/m/Y');
                              $mandamientopdf =  view('comparendos.especial.mandamiento_pdf', [
                                                      'comparendo' => $comparendo,
                                                      'infraccion_fecha' => $infraccion_fecha,
                                                      'fecha_actual' => $fechaGeneracionMandamiento,
                                                      'valorLetras' => $convertidorNumerosALetras->to_word(round($comparendo->valor)),
                                                      'numeroResolucion' => $this->ultimaNumeracion,
                                                      'rutaFirma' => $this->rutaFirma
                                                    ]);

                              $this->comparendopdf .= $mandamientopdf . '</body></html>';

                              $pdf = PDF::loadHTML($this->comparendopdf)->setPaper('letter', 'portrait');
                              $pdf->save($folder . '/' . $archivo);

                              //creando el registro en expediente
                              $expediente = new \App\ComparendoExpediente();
                              $expediente->id_comparendo = $comparendo->id;
                              $expediente->fecha_generacion = $fechaMandamiento;
                              $expediente->nombre_documento = $archivo;
                              $expediente->id_tipo_evento = 5;//mandamiento de pago
                              $expediente->id_paquete = $paquete->id;
                              $expediente->id_user = 4;
                              $expediente->save();

                              $this->pdfMasivo .=  $mandamientopdf;
                              $this->pdfMasivo .= '<div class="page-break"></div>';
                              $this->relacionContenido .= $comparendo->final_numero . "\r\n";

                              $comparendoActualizar = Comparendo::find($comparendo->id);
                              $comparendoActualizar->id_tipo_evento = 5;//mandamiento de pago
                              $comparendoActualizar->save();
                              $this->line("mandamiento impreso: " . $comparendo->id);
                          }
          });
          if($this->ultimaNumeracion >= $inicioNumeracion){
            $this->line("Actualizando Numeracion...");
            //actualizar la numeracion en un nuevo registro
            $numeracion = new Numeracion();
            $numeracion->prefijo = 'MP';
            $numeracion->inicio = $inicioNumeracion;
            $numeracion->final = $this->ultimaNumeracion;
            $numeracion->id_tipo_evento = 5;//mandamiento de pago
            $numeracion->id_organismo = 1;
            $numeracion->id_paquete = $paquete->id;
            $numeracion->save();
            $this->line("Fin Numeracion");

            //$pdf = PDF::loadHTML($this->comparendopdf)->setPaper('letter', 'portrait');
            //return $pdf->stream('pdf.pdf');
            $this->line("Creando el PDF Masivo...");
            $this->pdfMasivo .= '</body></html>';
            $folder = $rutaPaquete . '/' . $paquete->id;
            \File::makeDirectory($folder, 0755, true, true);

            $pdf = PDF::loadHTML($this->pdfMasivo)->setPaper('letter', 'portrait');
            $archivo = 'paquete_' . $paquete->id;
            $pdf->save($folder . '/' . $archivo . '.pdf');
            $paquete->archivo_pdf = $archivo . '.pdf';

            //el archivo de remision
            \File::put($folder . '/' . $archivo . '.txt', $this->relacionContenido);

            //remision en pdf
            $pdf = PDF::loadView('comparendos.relacion_paquete',
                                    [ 'comparendos' => $this->comparendosImpresos ]
                                )->setPaper('letter', 'portrait');
            $pdf->save($folder . '/remision.pdf');
            $paquete->archivo_remision = 'remision.pdf';

            $paquete->save();
            $this->line("Fin Pdf masivo y actualizacion del Paquete.");
          } else {
            $this->line("No se imprimo mandamientos.");
          }
        }else{
          $this->line("No se encontraron avisos para mandamiento.");
        }
    }
}
