<?php

namespace App\Console\Commands;

use App\Agente;
use App\Ciudad;
use App\Ciudadano;
use App\Comparendo;
use App\ComparendoSimit;
use App\Grua;
use App\Patio;
use App\Tipo;
use App\Vehiculo;
use Carbon\Carbon;
use Illuminate\Console\Command;
use App\ComparendoNumeracionImpresion as Numeracion;
use Illuminate\Support\Facades\DB;

class MoverComparendoSimit extends Command
{
    /**
     * The name and signature of the console command.
     *
     * @var string
     */
    protected $signature = 'simit:mover-comparendo';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description = 'Mueve de comparendos_simit a comparendo';

    /**
    * variables de contenido de la tarea
    */
    protected $ultimaNumeracion = 1900;

    /**
     * Create a new command instance.
     *
     * @return void
     */
    public function __construct()
    {
        parent::__construct();
    }

    /**
     * Execute the console command.
     *
     * @return mixed
     */
    public function handle()
    {
        $numeracion = Numeracion::select(DB::raw("max(final) as final"))->where('id_tipo_evento', '11')->first();

        if($numeracion != null){
          $this->ultimaNumeracion = $numeracion->final;
        }
        $inicioNumeracion = $this->ultimaNumeracion + 1;
        $c = 0;

        ComparendoSimit::chunk(100, function ($comparendos) use (&$c) {
            foreach ($comparendos as $compsimit) {
                $c++;
                $this->line("{$c}. Comparendo {$compsimit->COL2} - {$compsimit->COL31} - {$compsimit->COL33}..");

                if (Comparendo::where('numero', $compsimit->COL2)->exists()) {
                    $this->error("COMPARENDO EXISTENTE!");
                } else {
                    $this->ultimaNumeracion++;
                    $comparendo = new Comparendo();

                    $comparendo->numero_expediente = $this->ultimaNumeracion;

                    $comparendo->numero = $compsimit->COL2;
                    $comparendo->numero_corto = $compsimit->COL2;

                    if (!empty($compsimit->COL3)) {
                        $comparendo->infraccion_fecha = Carbon::createFromFormat('d/m/Y', $compsimit->COL3)->format("Y-m-d");
                    }

                    if (!empty($compsimit->COL4)) {
                        $comparendo->infraccion_hora = Carbon::createFromFormat('H:i', $compsimit->COL4)->format("H:i:s");
                    }

                    if (!empty($compsimit->COL5)) {
                        $comparendo->infraccion_direccion = $compsimit->COL5;
                    }

                    $comparendo->infraccion_ciudad = $compsimit->COL6; //"13052000";

                    if (!empty($compsimit->COL7)) {
                        $comparendo->infraccion_localidad = $compsimit->COL7;
                    }

                    if (!empty($compsimit->COL8)) {
                        $comparendo->vehiculo_placa = $compsimit->COL8;
                    }

                    $codigoCiudadMatricula = substr($compsimit->COL9, 2, 3);
                    if ($ciudadMatricula = Ciudad::where('codigo_dane', $codigoCiudadMatricula)->first()) {
                        $this->line("Ciudad matricula ({$codigoCiudadMatricula}) : {$ciudadMatricula->nombre}");
                        $comparendo->vehiculo_ciudad_matricula = $ciudadMatricula->id;
                    } else {
                        $this->line("Ciudad matricula no encontrada");
                    }

                    if (!empty($compsimit->COL10)) {
                        $tipo = Tipo::where('tipo', 'vehiculo')->where('codigo', $compsimit->COL10)->first();

                        if($tipo){
                            $comparendo->vehiculo_tipo_vehiculo = $tipo->id;
                        }
                    }

                    if (!empty($compsimit->COL11)) {
                        $tipo = Tipo::where('tipo', 'servicio')->where('codigo', $compsimit->COL11)->first();
                        if ($tipo) {
                            $comparendo->vehiculo_tipo_servicio = $tipo->id;
                        }
                    }

                    if (!empty($compsimit->COL12)) {
                        $comparendo->vehiculo_radio_accion = $compsimit->COL12;
                    }

                    if (!empty($compsimit->COL13)) {
                        $tipo = Tipo::where('tipo', 'modalidad')->where('codigo', $compsimit->COL13)->first();

                        if($tipo){
                            $comparendo->vehiculo_modalidad = $tipo->id;
                        }
                    }

                    if (!empty($compsimit->COL14)) {
                        $tipo = Tipo::where('tipo', 'transporte')->where('codigo', $compsimit->COL14)->first();

                        if ($tipo) {
                            $comparendo->vehiculo_tipo_transporte = $tipo->id;
                        }
                    }

                    if (!empty($compsimit->COL15)) {
                        $comparendo->infractor_documento = trim($compsimit->COL15);
                    }

                    if (!empty($compsimit->COL16)) {
                        $tipo = Tipo::where('tipo', 'documento')->where('codigo', $compsimit->COL16)->first();

                        if ($tipo) {
                            $comparendo->infractor_tipo_documento = $tipo->id;
                        }
                    }

                    if (!empty($compsimit->COL17)) {
                        $comparendo->infractor_nombre = mb_convert_case(mb_strtolower(utf8_encode($compsimit->COL17)), MB_CASE_TITLE, 'UTF-8');
                    }

                    if (!empty($compsimit->COL18)) {
                        $comparendo->infractor_apellido = mb_convert_case(mb_strtolower(utf8_encode($compsimit->COL18)), MB_CASE_TITLE, 'UTF-8');
                    }

                    if (!empty($compsimit->COL19)) {
                        $comparendo->infractor_edad = $compsimit->COL19;
                    }

                    if (!empty($compsimit->COL20)) {
                        $comparendo->infractor_direccion = $compsimit->COL20;
                    }

                    if (!empty($compsimit->COL21)) {
                        $comparendo->infractor_email = $compsimit->COL21;
                    }

                    if (!empty($compsimit->COL22)) {
                        $comparendo->infractor_telefono = $compsimit->COL22;
                    }

                    $codigoCiudadInfractor = substr($compsimit->COL23, 2, 3);
                    if ($ciudadInfractor = Ciudad::where('codigo_dane', $codigoCiudadInfractor)->first()) {
                        $this->line("Ciudad infractor ({$codigoCiudadInfractor}) : {$ciudadInfractor->nombre}");
                        $comparendo->infractor_ciudad = $ciudadInfractor->id;
                    } else {
                        $this->line("Ciudad infractor no encontrada");
                    }

                    if (!Ciudadano::where('numero_documento', trim($comparendo->infractor_documento))->exists()) {
                        $this->line("CREANDO CIUDADANO {$comparendo->infractor_nombre} {$comparendo->infractor_apellido}");
                        $ciudadano = new Ciudadano();
                        $ciudadano->nombre = $comparendo->infractor_nombre . " " . $comparendo->infractor_apellido;
                        $ciudadano->numero_documento = trim($comparendo->infractor_documento);
                        $ciudadano->ciudad_residencia = $comparendo->infractor_ciudad;
                        $ciudadano->direccion_residencia = $comparendo->infractor_direccion;

                        if (!empty($comparendo->infractor_telefono)) {
                            if (strlen($comparendo->infractor_telefono) == 10) {
                                $ciudadano->telefono_celular = $comparendo->infractor_telefono;
                            } elseif (strlen($comparendo->infractor_telefono) == 7) {
                                $ciudadano->telefono_fijo = $comparendo->infractor_telefono;
                            }
                        }

                        $ciudadano->email = $comparendo->infractor_email;

                        $ciudadano->save();
                    }


                    if (!empty($compsimit->COL24)) {
                        $comparendo->infractor_licencia = $compsimit->COL24;
                    }

                    if (!empty($compsimit->COL25)) {
                        $comparendo->infractor_licencia_categoria = $compsimit->COL25;
                    }

                    if (!empty($compsimit->COL26)) {
                        $comparendo->infractor_licencia_divipo = $compsimit->COL26;
                    }

                    if (!empty($compsimit->COL27)) {
                        $comparendo->infractor_licencia_vence = $compsimit->COL27;
                    }

                    if (!empty($compsimit->COL28)) {
                        $comparendo->infractor_tipo = $compsimit->COL28;
                    }

                    if (!empty($compsimit->COL29)) {
                        $comparendo->vehiculo_licencia = $compsimit->COL29;
                    }

                    if (!empty($compsimit->COL30)) {
                        $comparendo->vehiculo_licencia_divipo = $compsimit->COL30;
                    }

                    $comparendo->id_propietario = $compsimit->id_propietario;

                    if (!empty($compsimit->COL34)) {
                        $comparendo->empresa_nombre = $compsimit->COL34;
                    }

                    if (!empty($compsimit->COL35)) {
                        $comparendo->empresa_nit = $compsimit->COL35;
                    }

                    if (!empty($compsimit->COL36)) {
                        $comparendo->empresa_tarjeta_operacion = $compsimit[35];
                    }


                    if (!empty($compsimit->COL37)) {
                        if ($agente = Agente::where('codigo_simit', trim($compsimit->COL37))->first()) {
                            $comparendo->id_agente = $agente->id;
                        }
                    }

                    if (!empty($compsimit->COL38)) {
                        $comparendo->observacion = $compsimit->COL38;
                    }

                    $comparendo->es_fuga = false;
                    if (!empty($compsimit->COL39)) {
                        if ($compsimit->COL39 == 'S') {
                            $comparendo->es_fuga = true;
                        }
                    }

                    $comparendo->es_accidente = false;
                    if (!empty($compsimit->COL40)) {
                        if ($compsimit->COL40 == 'S') {
                            $comparendo->es_accidente = true;
                        }
                    }

                    $comparendo->es_inmovilizacion = false;
                    if (!empty($compsimit->COL41)) {
                        if ($compsimit->COL41 == 'S') {
                            $comparendo->es_inmovilizacion = true;
                        }
                    }

                    $comparendo->id_patio = '';
                    if (!empty($compsimit->COL42)) {
                        if ($patio = Patio::where('nombre', trim($compsimit->COL42))->first()) {
                            $comparendo->id_patio = $patio->id;
                        }
                    }

                    $comparendo->id_grua = '';
                    if (!empty($compsimit->COL45)) {
                        if ($grua = Grua::where('placa', trim($compsimit->COL45))->first()) {
                            $comparendo->id_grua = $grua->id;
                        }
                    }

                    if (!empty($compsimit->COL46)) {
                        $comparendo->consecutivo_inmovilizacion = trim($compsimit->COL46);
                    }

                    if (!empty($compsimit->COL47)) {
                        $comparendo->testigo_documento = trim($compsimit->COL47);
                    }

                    if (!empty($compsimit->COL48)) {
                        $comparendo->testigo_nombre = trim($compsimit->COL48);
                    }

                    if (!empty($compsimit->COL49)) {
                        $comparendo->testigo_direccion = trim($compsimit->COL49);
                    }

                    if (!empty($compsimit->COL50)) {
                        $comparendo->testigo_telefono = trim($compsimit->COL50);
                    }

                    $comparendo->valor = $compsimit->COL51;
                    $comparendo->valor_adicional = $compsimit->COL52;
                    $comparendo->estado = trim($compsimit->COL54);

                    $comparendo->es_polca = false;
                    if (!empty($compsimit->COL55)) {
                        if (trim($compsimit->COL55) == 'S') {
                            $comparendo->es_polca = true;
                        }
                    }

                    $comparendo->infracciones = trim($compsimit->COL56);

                    $comparendo->es_fotomulta = false;
                    /*El campo 58 es el grado de alcohol, si en el sistema de descarga este campo esta apagado se toma por defecto
                    como el campo de fotomulta S/N */
                    if (!empty($compsimit->COL58)) {
                        if (trim($compsimit->COL58) == 'S') {
                            $comparendo->es_fotomulta = true;
                        }else{
                          $comparendo->es_fotomulta = false;
                        }
                    }


                    if (!empty($compsimit->COL59)) {
                        //$comparendo->fecha_notificacion = Carbon::createFromFormat('d/m/Y', $compsimit->COL59)->format("Y-m-d");
                    }

                    if($compsimit->COL56 == 'F'){
                      /*Si el comparendo es F en el campo 58 esta el grado de alcohol*/
                      $comparendo->grado_alcohol = trim($compsimit->COL58);
                    }

                    $comparendo->id_organismo = 1;

                    $comparendo->fuente = "importado";
                    $comparendo->es_descargado = 1;
                    $comparendo->fecha_descarga = Carbon::now();

                    if(trim($compsimit->COL56) == 'D12' || trim($compsimit->COL56) == 'E04' || trim($compsimit->COL56) == 'F'){
                      $comparendo->validacion = 0;
                    }else{
                      $comparendo->validacion = 1;
                    }

                    $comparendo->save();

                    $this->info("CREADO");
                    $this->info("");
                }
            }
        });

        $this->line("Actualizando Numeracion...");
        //actualizar la numeracion en un nuevo registro
        $numeracion = new Numeracion();
        $numeracion->prefijo = 'EXPEDIENTE';
        $numeracion->inicio = $inicioNumeracion;
        $numeracion->final = $this->ultimaNumeracion;
        $numeracion->id_tipo_evento = 11;//expediente nuevo
        $numeracion->id_organismo = 1;
        $numeracion->id_paquete = 0;
        $numeracion->save();
        $this->line("Fin Numeracion");
    }
}
