<?php

namespace App\Console\Commands;

use Illuminate\Console\Command;
use Carbon\Carbon;
use App\Comparendo;
use App\ComparendoExpediente;
use App\ResolucionSimit;
use App\DireccionesNotificacionTemp as Direccion;
use App\ComparendoNumeracionImpresion as Numeracion;
use Illuminate\Support\Facades\DB;
use Barryvdh\DomPDF\Facade as PDF;
use LynX39\LaraPdfMerger\PdfManage;

class NotificacionPersonalSancionPdf extends Command
{
  /**
   * The name and signature of the console command.
   *
   * @var string
   * php artisan mandamiento:start 0 c new no
   */
  protected $signature = 'notificacionpersonal:sancion';

  /**
   * The console command description.
   *
   * @var string
   */
  protected $description = 'Carta de notificacion de sancion personal';

  /**
  * variables de contenido de la tarea
  */
  protected $relacionContenido = '';
  protected $pdfMasivo = '';
  protected $comparendosImpresos = array();
  protected $comparendopdf = '';
  protected $meses = [];
  protected $organismoNombreSecreteria = '';
  protected $organismoDireccion = '';
  protected $rutaImagenTop = '';
  protected $rutaFirma = '';

  /**
   * Create a new command instance.
   *
   * @return void
   */
  public function __construct()
  {
      parent::__construct();
  }

  /**
   * Execute the console command.
   *
   * @return mixed
   */
  public function handle()
  {
    $this->rutaImagenTop = '';

    //$this->rutaImagenTop = base_path() . '/public/images/transito_curumani.png';
    $this->rutaImagenTop =base_path() . '/public/images/hoja membrete.jpg';
    $this->rutaFirma = base_path() . '/public/images/firma2.png';

    $rutaExpediente = \Config::get('myconfig.ruta_comparendo_expediente');
    $rutaPaquete = \Config::get('myconfig.ruta_paquetes_mensajeria');

    $organismo = \App\Organismo::first();
    $this->organismoDireccion = $organismo->direccion . ' ' . $organismo->ciudad->nombre . ' - ' . $organismo->ciudad->departamento->nombre;
    $this->organismoNombreSecreteria = $organismo->secretaria_nombre;

    $this->pdfMasivo = view('comparendos.notificacion.head_pdf',[
                            'organismoDireccion' => $this->organismoDireccion,
                            'rutaImagenTop' => $this->rutaImagenTop
                          ]);
    $this->pdfMasivo .= '<style>.page-break {page-break-after: always;}</style>';

    $this->meses = array('Enero', 'Febrero', 'Marzo', 'Abril', 'Mayo', 'Junio', 'Julio',
                   'Agosto', 'Septiembre', 'Octubre', 'Noviembre', 'Diciembre');

    $convertidorNumerosALetras = new \NumberToLetterConverter();
    $resoluciones = null;


    $fecha = Carbon::now();

    do {
      $seProcesaronCitaciones = false;
      $resoluciones = ResolucionSimit::where('es_pdf_notificado', '=', '0')
                                      ->where('COL5', '=', '1')
                                      ->where('estado_notificacion', '=', '0')
                                      ->where("fecha_format_comparendo", '>=', '2016-03-30')
                                      ->limit(20)
                                      ->get();
      //numeracion de los paquetes_oficios
      $ultimaNumeracionPaq = 0;
      $numeracionPaq = Numeracion::select(DB::raw("max(final) as final"))->where('id_tipo_evento', '24')->first();

      if($numeracionPaq != null){
        $ultimaNumeracionPaq = $numeracionPaq->final;
      }
      $inicioNumeracionPaq = $ultimaNumeracionPaq + 1;

      //numeracion de los oficios en expedientes
      $ultimaNumeracion = 0;
      $numeracion = Numeracion::select(DB::raw("max(final) as final"))->where('id_tipo_evento', '24')->first();

      if($numeracion != null){
        $ultimaNumeracion = $numeracion->final;
      }
      $inicioNumeracion = $ultimaNumeracion + 1;

      $paquete = null;
      if(count($resoluciones) >= 1){
        //creando el paquete
        $paquete = new \App\ComparendoPaquete();
        $paquete->nombre = Carbon::now();
        $paquete->fecha = Carbon::now();
        $paquete->id_user = 4;
        $paquete->id_tipo_evento = 24;
        $paquete->es_impreso = 0;
        $paquete->save();
      }

      $this->comparendosImpresos = [];
      $this->relacionContenido = '';
      foreach ($resoluciones as $resolucion) {
        //validando pagos y/o terminaciones de proceso
        $comparendo = Comparendo::where('numero', '=', $resolucion->COL7)->first();
        if(isset($comparendo->id)){
          $puedeNotificarse = false;
          $tieneSaldo = $comparendo->tieneSaldo($comparendo->id);
          $tieneAcuerdo = $comparendo->tieneAcuerdoVigente($comparendo->id);
          if($tieneSaldo){
            $puedeNotificarse = true;
            if($tieneAcuerdo){
              $puedeNotificarse = false;
            }
          }elseif($tieneAcuerdo){
            $puedeNotificarse = false;
          }

          //si la respuesta es falsa
          if($puedeNotificarse){
            $direccion = Direccion::where('comparendo','=',$resolucion->COL7)->orWhere('cedula','=',$resolucion->COL9)->first();

            $direccionInfractor = $comparendo->infraccion_direccion . ' ' . $comparendo->infractor_direccion;
            $direccionUbicacion = $organismo->ciu;
            if(isset($direccion->id)){
              $direccionInfractor = $direccion->direccion;
              $direccionUbicacion = $direccion->ciudad;
            }
            $mandamiento = ResolucionSimit::where('COL7', '=', $resolucion->COL7)
                                          ->where('COL3', '=', $resolucion->COL2)
                                          ->where('COL5', '=', '16')
                                          ->orderByDesc('id')->first();

            if(isset($mandamiento->id)){
              $seProcesaronCitaciones = true;
              $this->line("Sancion: " . $resolucion->COL2);

              $fechaMandamientoCarbon = Carbon::createFromFormat('d/m/Y', $mandamiento->COL4);
              $fechaGeneracionMandamiento = $fechaMandamientoCarbon->day . ' de ' . $this->meses[$fechaMandamientoCarbon->month - 1] . ' de ' . $fechaMandamientoCarbon->year;

              $fechaSancion = Carbon::createFromFormat('d/m/Y', $resolucion->COL4);
              $fechaGeneracionSancion = $fechaSancion->day . ' de ' . $this->meses[$fechaSancion->month - 1] . ' de ' . $fechaSancion->year;

              $ultimaNumeracion++;
              $nombreDocumento = 'OFNC-' . $ultimaNumeracion . '-' . $fecha->year;
              $archivo = $nombreDocumento . '.pdf';

              $this->comparendosImpresos[] = array('final_numero' => $comparendo->numero . ' - DOC: ' . $comparendo->infractor_documento . ' - ' . $nombreDocumento);
              $folder = $rutaExpediente . '/' . $comparendo->numero_expediente;
              \File::makeDirectory($folder, 0777, true, true);

              $infraccionFecha = new Carbon($comparendo->infraccion_fecha);
              $infraccionFecha = $infraccionFecha->format('d/m/Y');

              $fechaLetras = $fecha->day . ' de ' . $this->meses[$fecha->month - 1] . ' de ' . $fecha->year;

              $this->comparendopdf = view('comparendos.notificacion.head_pdf',[
                                      'organismoDireccion' => $this->organismoDireccion,
                                      'rutaImagenTop' => $this->rutaImagenTop
                                    ]);
              $notificacionpdf =  view('comparendos.notificacion.pdf', [
                                      'fechaImpresion' => $fechaLetras,
                                      'numeroOficio' => 'OFICIO No. ' . $nombreDocumento,
                                      'nombreInfractor' => mb_strtoupper ($comparendo->infractor_nombre . ' ' . $comparendo->infractor_apellido),
                                      'direccionInfractor' => $direccionInfractor,
                                      'ubicacion' => $direccionUbicacion,
                                      'numeroMandamiento' => $mandamiento->COL2,
                                      'fechaMandamiento' => $mandamiento->COL4,
                                      'numeroResolucion' => $resolucion->COL2,
                                      'fechaResolucion' => $resolucion->COL4,
                                      'rutaFirma' => $this->rutaFirma,
                                      'organismoNombreSecreteria' => $this->organismoNombreSecreteria,
                                      'secretarioNombre' => $organismo->secretario_nombre
                                    ]);

              $this->comparendopdf .= $notificacionpdf . '</body></html>';

              $pdf = PDF::loadHTML($this->comparendopdf)->setPaper('letter', 'portrait');
              $pdf->save($folder . '/' . $archivo);

              //creando el registro en expediente
              $expediente = new \App\ComparendoExpediente();
              $expediente->id_comparendo = $comparendo->id;
              $expediente->fecha_generacion = $fecha->format('Y-m-d');
              $expediente->nombre_documento = $archivo;
              $expediente->id_tipo_evento = 24;//oficio de citacion para notificacion mandamiento
              $expediente->id_paquete = $paquete->id;
              $expediente->id_user = 4;
              $expediente->save();

              $this->pdfMasivo .=  $notificacionpdf;
              $this->pdfMasivo .= '<div class="page-break"></div>';
              $this->relacionContenido .= $comparendo->numero . ' - DOC: ' . $comparendo->infractor_documento . ' - ' . $nombreDocumento . "\r\n";

              $comparendoActualizar = Comparendo::find($comparendo->id);
              $comparendoActualizar->id_tipo_evento = 24;//oficio de notificacion sancion
              $comparendoActualizar->save();
              $this->line("notificacion impresa: " . $archivo);

              $resolucion->es_pdf_notificado = 1;
              $resolucion->estado_notificacion = 2;
              $resolucion->save();
            }
          }else{
            $resolucion->es_pdf_notificado = -1;
            $resolucion->estado_notificacion = -1;
            $resolucion->save();
          }
        }else{
          $resolucion->es_pdf_notificado = -1;
          $resolucion->estado_notificacion = -1;
          $resolucion->save();
        }
      }

      if ($seProcesaronCitaciones) {
        $this->line("Creando el PDF Masivo...");
        $this->pdfMasivo .= '</body></html>';
        $folder = $rutaPaquete . $paquete->id;
        \File::makeDirectory($folder, 0775, true, true);

        $pdf = PDF::loadHTML($this->pdfMasivo)->setPaper('letter', 'portrait');
        $archivo = 'paquete_' . $paquete->id;
        $pdf->save($folder . '/' . $archivo . '.pdf');
        $paquete->archivo_pdf = $archivo . '.pdf';

        //el archivo de remision
        \File::put($folder . '/' . $archivo . '.txt', $this->relacionContenido);

        //remision en pdf
        $pdf = PDF::loadView('comparendos.relacion_paquete',
                                [ 'comparendos' => $this->comparendosImpresos ]
                            )->setPaper('letter', 'portrait');
        //$pdf->save($folder . '/remision.pdf');
        $paquete->archivo_remision = 'remision.pdf';

        $paquete->save();
        $this->line("Fin Pdf masivo y actualizacion del Paquete.");
        $this->pdfMasivo = view('comparendos.notificacion.head_pdf',[
                                'organismoDireccion' => $this->organismoDireccion,
                                'rutaImagenTop' => $this->rutaImagenTop
                              ]);
        $this->pdfMasivo .= '<style>.page-break {page-break-after: always;}</style>';
      }else{
        if($paquete != null){
          $paquete->delete();
        }
      }

      if($ultimaNumeracion >= $inicioNumeracion){
        $this->line("Actualizando Numeracion...");
        //actualizar la numeracion en un nuevo registro
        $numeracion = new Numeracion();
        $numeracion->prefijo = 'OFNC';
        $numeracion->inicio = $inicioNumeracion;
        $numeracion->final = $ultimaNumeracion;
        $numeracion->id_tipo_evento = 24;//oficio notificacion sancion
        $numeracion->id_organismo = $organismo->id;
        $numeracion->id_paquete = $paquete->id;
        $numeracion->save();
        $this->line("Fin Numeracion oficio notificacion sancion.");
      } else {
        $this->line("No se imprimo oficio notificacion sancion.");
      }

      if(!$seProcesaronCitaciones){
        $paquete->delete();
      }

    } while ($seProcesaronCitaciones);
  }
}
