<?php

namespace App\Console\Commands;

use Illuminate\Console\Command;
use Carbon\Carbon;
use App\Comparendo;
use App\ComparendoNumeracionImpresion as Numeracion;
use Illuminate\Support\Facades\DB;
use Barryvdh\DomPDF\Facade as PDF;
use LynX39\LaraPdfMerger\PdfManage;

class PersuadirComparendo extends Command
{
    /**
     * The name and signature of the console command.
     *
     * @var string
     * medio: -c: consola, -w: web
     */
    protected $signature = 'persuadir:start {total} {medio}';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description = 'Command description';

    /**
    * variables de contenido de la tarea
    */
    protected $relacionContenido = '';
    protected $pdfMasivo = '';
    protected $comparendosImpresos = array();
    protected $ultimaNumeracion = 1900;
    protected $comparendopdf = '';
    protected $meses = [];
    protected $organismoNombreSecreteria = '';
    protected $organismoDireccion = '';
    protected $rutaImagenTop = '';
    /**
     * Create a new command instance.
     *
     * @return void
     */
    public function __construct()
    {
        parent::__construct();
    }

    /**
     * Execute the console command.
     *
     * @return mixed
     */
    public function handle()
    {
        $totalAImprimir = $this->argument('total');
        $medio = $this->argument('medio');
        $this->rutaImagenTop = '';
        if($medio == "c"){
          $this->rutaImagenTop = asset(config('myconfig.proyect_route') . '/images/titulo.png');
        }else if($medio == "w"){
          $this->rutaImagenTop = asset('images/titulo.png');
        }
        $this->line("totalAImprimir: $totalAImprimir");
        $rutaExpediente = \Config::get('myconfig.ruta_comparendo_expediente');
        $rutaPaquete = \Config::get('myconfig.ruta_paquetes_mensajeria');

        $organismo = \App\Organismo::first();
        $this->organismoDireccion = $organismo->direccion . ' ' . $organismo->ciudad->nombre . ' - ' . $organismo->ciudad->departamento->nombre;
        $this->organismoNombreSecreteria = $organismo->secretaria_nombre;

        $this->pdfMasivo = view('comparendos.persuadir_head_pdf', [
                                'organismoDireccion' => $this->organismoDireccion,
                                'rutaImagenTop' => $this->rutaImagenTop
                              ]);
        $this->pdfMasivo .= '<style>.page-break {page-break-after: always;}</style>';

        //creando el paquete
        $paquete = new \App\ComparendoPaquete();
        $paquete->nombre = Carbon::now();
        $paquete->fecha = Carbon::now();
        $paquete->id_user = 4;
        $paquete->id_tipo_evento = 10;
        $paquete->es_impreso = 0;
        $paquete->save();

        $count = Comparendo::habilitadoParaPersuasivo('antiguo', false)->count();
        if($totalAImprimir >= $count){
          $totalAImprimir = $count - 1;
        }
        $maxId = Comparendo::habilitadoParaPersuasivo('antiguo', false)->skip($totalAImprimir)->take(1)->value('id');

        $numeracion = Numeracion::select(DB::raw("max(final) as final"))->where('id_tipo_evento', '10')->first();

        if($numeracion != null){
          $this->ultimaNumeracion = $numeracion->final;
        }
        $inicioNumeracion = $this->ultimaNumeracion + 1;

        $this->meses = array('Enero', 'Febrero', 'Marzo', 'Abril', 'Mayo', 'Junio', 'Julio',
                       'Agosto', 'Septiembre', 'Octubre', 'Noviembre', 'Diciembre');
        Comparendo::habilitadoParaPersuasivo('antiguo', false)->where('id', '<', $maxId)
                    ->chunk(200, function ($comparendos) use ($rutaExpediente, $paquete) {

                        foreach ($comparendos as $comparendo) {
                          $this->ultimaNumeracion++;
                          $this->comparendosImpresos[] = array('final_numero' => $comparendo->final_numero);
                          $folder = $rutaExpediente . '/' . $comparendo->final_numero;
                          \File::makeDirectory($folder, 0755, true, true);
                          $archivo = '';

                          $archivo = 'CP-' . $this->ultimaNumeracion . '.pdf';

                          $this->comparendopdf = view('comparendos.persuadir_head_pdf', [
                                                  'organismoDireccion' => $this->organismoDireccion,
                                                  'rutaImagenTop' => $this->rutaImagenTop
                                                ]);
                          $cuerpoPdf = '';
                          $hoyMas20Dias = Carbon::now()->addDays(20);
                          $hoyMas20Dias = $hoyMas20Dias->day . ' de ' . $this->meses[$hoyMas20Dias->month - 1] . ' de ' . $hoyMas20Dias->year;
                          if($comparendo->es_fotomulta == 1){
                            //carta para fotomulta
                            $cuerpoPdf =  view('comparendos.persuadir_fotomulta_pdf', [
                                                    'comparendo' => $comparendo,
                                                    'ultimaNumeracion' => $this->ultimaNumeracion,
                                                    'hoyMas20Dias' => $hoyMas20Dias,
                                                    'organismoNombreSecreteria' => $this->organismoNombreSecreteria,
                                                    'organismoDireccion' => $this->organismoDireccion,
                                                    'infraccion_fecha' => Carbon::createFromFormat('Y-m-d', $comparendo->infraccion_fecha)->format('d/m/Y'),
                                                    'fecha_actual' => Carbon::now()->day . ' de ' . $this->meses[Carbon::now()->month - 1] . ' de ' . Carbon::now()->year
                                                  ]);
                                                  dd($cuerpoPdf);die;
                          }else if($comparendo->es_fotomulta == 0){
                            //carta para comparendo fisico
                            $cuerpoPdf =  view('comparendos.persuadir_multa_pdf', [
                                                    'comparendo' => $comparendo,
                                                    'descripcionInfraccion' => $comparendo->descripcion_infraccion,
                                                    'ultimaNumeracion' => $this->ultimaNumeracion,
                                                    'hoyMas20Dias' => $hoyMas20Dias,
                                                    'organismoNombreSecreteria' => $this->organismoNombreSecreteria,
                                                    'organismoDireccion' => $this->organismoDireccion,
                                                    'infraccion_fecha' => Carbon::createFromFormat('Y-m-d', $comparendo->infraccion_fecha)->format('d/m/Y'),
                                                    'fecha_actual' => Carbon::now()->day . ' de ' . $this->meses[Carbon::now()->month - 1] . ' de ' . Carbon::now()->year
                                                  ]);

                          }
                          $this->comparendopdf .= $cuerpoPdf . '</body></html>';
                          $pdf = PDF::loadHTML($this->comparendopdf)->setPaper('letter', 'portrait');
                          //return false;

                          $pdf->save($folder . '/' . $archivo);

                          //creando el registro en expediente
                          $expediente = new \App\ComparendoExpediente();
                          $expediente->id_comparendo = $comparendo->id;
                          $expediente->fecha_generacion = Carbon::now();
                          $expediente->nombre_documento = $archivo;
                          $expediente->id_tipo_evento = 10;//cobro persuasivo
                          $expediente->id_paquete = $paquete->id;
                          $expediente->id_user = 4;
                          $expediente->save();

                          $this->pdfMasivo .=  $cuerpoPdf;
                          $this->pdfMasivo .= '<div class="page-break"></div>';
                          $this->relacionContenido .= $comparendo->final_numero . "\r\n";

                          $comparendoActualizar = Comparendo::find($comparendo->id);
                          $comparendoActualizar->id_tipo_evento = 10;
                          $comparendoActualizar->save();
                          $this->line("comparendo impreso: " . $comparendo->id);
                        }
        });
        $this->line("Actualizando Numeracion...");
        //actualizar la numeracion en un nuevo registro
        $numeracion = new Numeracion();
        $numeracion->prefijo = 'CP';
        $numeracion->inicio = $inicioNumeracion;
        $numeracion->final = $this->ultimaNumeracion;
        $numeracion->id_tipo_evento = 10;//cobro persuasivo
        $numeracion->id_organismo = 1;
        $numeracion->id_paquete = $paquete->id;
        $numeracion->save();
        $this->line("Fin Numeracion");

        //$pdf = PDF::loadHTML($this->comparendopdf)->setPaper('letter', 'portrait');
        //return $pdf->stream('pdf.pdf');
        $this->line("Creando el PDF Masivo...");
        $this->pdfMasivo .= '</body></html>';
        $folder = $rutaPaquete . '/' . $paquete->id;
        \File::makeDirectory($folder, 0755, true, true);

        $pdf = PDF::loadHTML($this->pdfMasivo)->setPaper('letter', 'portrait');
        $archivo = 'paquete_' . $paquete->id;
        $pdf->save($folder . '/' . $archivo . '.pdf');
        $paquete->archivo_pdf = $archivo . '.pdf';

        //el archivo de remision
        \File::put($folder . '/' . $archivo . '.txt', $this->relacionContenido);

        //remision en pdf
        $pdf = PDF::loadView('comparendos.relacion_paquete',
                                [ 'comparendos' => $this->comparendosImpresos ]
                            )->setPaper('letter', 'portrait');
        $pdf->save($folder . '/remision.pdf');
        $paquete->archivo_remision = 'remision.pdf';

        $paquete->save();
        $this->line("Fin Pdf masivo y actualizacion del Paquete.");
    }
}
