<?php

namespace App\Console\Commands;

use App\Agente;
use App\Archivo;
use App\Ciudadano;
use App\Comparendo;
use App\Grua;
use App\Patio;
use App\Tipo;
use App\Vehiculo;
use Carbon\Carbon;
use Illuminate\Console\Command;
use League\Csv\Reader;
use League\Csv\Statement;
use App\ComparendoNumeracionImpresion as Numeracion;

class ProcesarArchivo extends Command
{
    /**
     * The name and signature of the console command.
     *
     * @var string
     */
    protected $signature = 'archivos:procesar';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description = 'Procesa archivos pendientes de carga';

    /**
    * variables de contenido de la tarea
    */
    protected $ultimaNumeracion = 1900;

    /**
     * Create a new command instance.
     *
     * @return void
     */
    public function __construct()
    {
        parent::__construct();
    }

    /**
     * Execute the console command.
     *
     * @return mixed
     */
    public function handle()
    {
        $numeracion = Numeracion::select(DB::raw("max(final) as final"))->where('id_tipo_evento', '11')->first();

        if($numeracion != null){
          $this->ultimaNumeracion = $numeracion->final;
        }
        $inicioNumeracion = $this->ultimaNumeracion + 1;

        $archivos = Archivo::where('estado', 'pendiente')->get();

        foreach($archivos as $archivo){
            $csv = Reader::createFromPath(public_path('uploads/' . $archivo->nombre), 'r');

            $stmt = (new Statement());

            $records = $stmt->process($csv);


            $c = 1;
            foreach ($records as $record) {
                if (count($record) == 4) {
                    echo("{$c}. PROCESANDO REGISTRO DE CONTROL...");
                } else {
                    echo("{$c}. PROCESANDO " . $record[1] . "...");

                    if(Comparendo::where('numero', $record[1])->exists()){
                        $this->error("COMPARENDO EXISTENTE!");
                    }else{
                        $this->ultimaNumeracion++;
                        $comparendo = new Comparendo();

                        $comparendo->numero_expediente = $this->ultimaNumeracion;

                        $comparendo->numero = $record[1];
                        $comparendo->numero_corto = $record[1];

                        if (!empty($record[2])) {
                            $comparendo->infraccion_fecha = Carbon::createFromFormat('d/m/Y', $record[2])->format("Y-m-d");
                        }

                        if (!empty($record[3])) {
                            $comparendo->infraccion_hora = $record[3]; //Carbon::createFromFormat('Hi', $record[3])->format("H:i");
                        }

                        if (!empty($record[4])) {
                            $comparendo->infraccion_direccion = $record[4];
                        }

                        if (!empty($record[5])) {
                            $comparendo->infraccion_ciudad = $record[5];
                        }

                        if (!empty($record[6])) {
                            $comparendo->infraccion_localidad = $record[6];
                        }

                        if (!empty($record[7])) {
                            if(!Vehiculo::where('placa', trim($record[7]))->exists()){
                                $vehiculo = new Vehiculo();
                                $vehiculo->placa = trim($record[7]);
                                $vehiculo->id_organismo = $archivo->id_organismo;
                                $vehiculo->save();
                            }

                            $comparendo->vehiculo_placa = $record[7];
                        }

                        if(!empty($record[8])){
                            $comparendo->vehiculo_ciudad_matricula = $record[8];
                        }

                        if (!empty($record[9])) {
                            $comparendo->vehiculo_tipo_vehiculo = $record[9];
                        }

                        if (!empty($record[10])) {
                            $comparendo->vehiculo_tipo_servicio = $record[10];
                        }

                        if (!empty($record[11])) {
                            $comparendo->vehiculo_radio_accion = $record[11];
                        }

                        if (!empty($record[12])) {
                            $comparendo->vehiculo_modalidad = $record[12];
                        }

                        if (!empty($record[13])) {
                            $comparendo->vehiculo_tipo_transporte = $record[13];
                        }

                        if (!empty($record[14])) {
                            $comparendo->infractor_documento = $record[14];
                        }

                        if (!empty($record[15])) {
                            $tipo = Tipo::where('tipo', 'documento')->where('codigo', $record[15])->first();
                            $comparendo->infractor_tipo_documento = $tipo->id;
                        }

                        if (!empty($record[16])) {
                            $comparendo->infractor_nombre = mb_convert_case(mb_strtolower(utf8_encode($record[16])), MB_CASE_TITLE, 'UTF-8');
                        }

                        if (!empty($record[17])) {
                            $comparendo->infractor_apellido = mb_convert_case(mb_strtolower(utf8_encode($record[17])), MB_CASE_TITLE, 'UTF-8');
                        }

                        if (!empty($record[18])) {
                            $comparendo->infractor_edad = $record[18];
                        }


                        if (!empty($record[19])) {
                            $comparendo->infractor_direccion = $record[19];
                        }

                        if (!empty($record[20])) {
                            $comparendo->infractor_email = $record[20];
                        }

                        if (!empty($record[21])) {
                            $comparendo->infractor_telefono = $record[21];
                        }

                        if (!empty($record[22])) {
                            $comparendo->infractor_ciudad = $record[22];
                        }


                        if ($propietario = Ciudadano::where('numero_documento', trim($comparendo->infractor_documento))->first()) {
                            //$comparendo->id_propietario = $record[30];
							//echo("cc existe...");
                        }else{
						echo("cc " . $record[30] ."-" . $record[32]. "...");
                            if (!empty($comparendo->infractor_documento) && !empty($comparendo->infractor_nombre)) {

                                $propietario = new Ciudadano();
                                $propietario->id_organismo = 1;
                                $propietario->nombre = $comparendo->infractor_nombre . " " . $comparendo->infractor_apellido;
                                $propietario->tipo_documento = 'cc';
                                $propietario->numero_documento = trim($comparendo->infractor_documento);
                                $propietario->direccion_residencia = trim($comparendo->infractor_direccion);
                                $propietario->telefono_fijo = trim($comparendo->infractor_telefono);

                                $propietario->save();

                                $comparendo->id_propietario = $propietario->id;
                                $comparendo->save();
                            }
                        }



                        if (!empty($record[23])) {
                            $comparendo->infractor_licencia = $record[23];
                        }

                        if (!empty($record[24])) {
                            $comparendo->infractor_licencia_categoria = $record[24];
                        }

                        if (!empty($record[25])) {
                            $comparendo->infractor_licencia_divipo = $record[25];
                        }

                        if (!empty($record[26])) {
                            $comparendo->infractor_licencia_vence = $record[26];
                        }

                        if (!empty($record[27])) {
                            $comparendo->infractor_tipo = $record[27];
                        }

                        if (!empty($record[28])) {
                            $comparendo->vehiculo_licencia = $record[28];
                        }

                        if (!empty($record[29])) {
                            $comparendo->vehiculo_licencia_divipo = $record[29];
                        }

                        $comparendo->id_propietario = null;

                        if ($propietario = Ciudadano::where('numero_documento', trim($record[30]))->first()) {
                            $comparendo->id_propietario = $record[30];
							echo("cc existe...");
                        }else{
						echo("cc " . $record[30] ."-" . $record[32]. "...");
                            if (!empty($record[30]) && !empty($record[32])) {

                                $propietario = new Ciudadano();
                                $propietario->id_organismo = 1;
                                $propietario->nombre = mb_strtoupper(trim($record[32]));//$comparendo->COL33
                                $propietario->tipo_documento = 'cc';
                                $propietario->numero_documento = trim($record[30]);//$comparendo->COL31
                                $propietario->save();

                                $comparendo->id_propietario = $propietario->id;
                                $comparendo->save();
                            }
                        }

                        if (!empty($record[33])) {
                            $comparendo->empresa_nombre = $record[33];
                        }

                        if (!empty($record[34])) {
                            $comparendo->empresa_nit = $record[34];
                        }

                        if (!empty($record[35])) {
                            $comparendo->empresa_tarjeta_operacion = $record[35];
                        }


                        $comparendo->id_agente = '';
                        if (!empty($record[36])) {
                            if ($agente = Agente::where('codigo_simit', trim($record[36]))->first()) {
                                $comparendo->id_agente = $agente->id;
                            }
                        }

                        if (!empty($record[37])) {
                            $comparendo->observacion = $record[37];
                        }

                        $comparendo->es_fuga = false;
                        if (!empty($record[38])) {
                            if($record[38] == 'S'){
                                $comparendo->es_fuga = true;
                            }
                        }

                        $comparendo->es_accidente = false;
                        if (!empty($record[39])) {
                            if ($record[39] == 'S') {
                                $comparendo->es_accidente = true;
                            }
                        }

                        $comparendo->es_inmovilizacion = false;
                        if (!empty($record[40])) {
                            if ($record[40] == 'S') {
                                $comparendo->es_inmovilizacion = true;
                            }
                        }

                        $comparendo->id_patio = '';
                        if (!empty($record[41])) {
                            if($patio = Patio::where('nombre', trim($record[41]))->first()){
                                $comparendo->id_patio = $patio->id;
                            }
                        }

                        $comparendo->id_grua = '';
                        if (!empty($record[44])) {
                            if ($grua = Grua::where('placa', trim($record[44]))->first()) {
                                $comparendo->id_grua = $grua->id;
                            }
                        }

                        if (!empty($record[45])) {
                            $comparendo->consecutivo_inmovilizacion = trim($record[45]);
                        }

                        if (!empty($record[46])) {
                            $comparendo->testigo_documento = trim($record[46]);
                        }

                        if (!empty($record[47])) {
                            $comparendo->testigo_nombre = trim($record[47]);
                        }

                        if (!empty($record[48])) {
                            $comparendo->testigo_direccion = trim($record[48]);
                        }

                        if (!empty($record[49])) {
                            $comparendo->testigo_telefono = trim($record[49]);
                        }

                        $comparendo->valor = $record[50];
                        $comparendo->valor_adicional = '0';
                        $comparendo->estado = trim($record[53]);

                        $comparendo->es_polca = false;
                        if (!empty($record[54])) {
                            if (trim($record[54]) == 'S') {
                                $comparendo->es_polca = true;
                            }
                        }

                        $comparendo->infracciones = trim($record[55]);

                        $comparendo->es_fotomulta = false;
                        if (!empty($record[57])) {
                            if (trim($record[57]) == 'S') {
                                $comparendo->es_fotomulta = true;
                            }
                        }


                        if (!empty($record[58])) {
                            //952 $comparendo->fecha_notificacion = Carbon::createFromFormat('d/m/Y', $record[58])->format("Y-m-d");
                        }

                        if (!empty($record[59])) {
                            $comparendo->grado_alcohol = trim($record[59]);
                        }

                        $comparendo->es_descargado = 1;
                        $comparendo->fecha_descarga = Carbon::now();
                        $comparendo->id_organismo = $archivo->id_organismo;

                        $comparendo->fuente = "masivo";

                        $comparendo->save();

                        $this->info("CREADO!");
                    }
                }

                $c++;
            }
        }

        $archivo->estado = 'procesado';
        $archivo->save();

        $this->line("Actualizando Numeracion...");
        //actualizar la numeracion en un nuevo registro
        $numeracion = new Numeracion();
        $numeracion->prefijo = 'EXPEDIENTE';
        $numeracion->inicio = $inicioNumeracion;
        $numeracion->final = $this->ultimaNumeracion;
        $numeracion->id_tipo_evento = 11;//expediente nuevo
        $numeracion->id_organismo = 1;
        $numeracion->id_paquete = 0;
        $numeracion->save();
        $this->line("Fin Numeracion");
    }
}
