<?php

namespace App\Console\Commands;

use Illuminate\Console\Command;
use Carbon\Carbon;
use App\Comparendo;
use App\ComparendoNumeracionImpresion as Numeracion;
use Illuminate\Support\Facades\DB;
use Barryvdh\DomPDF\Facade as PDF;
use LynX39\LaraPdfMerger\PdfManage;

class ResolucionSancionComparendo extends Command
{
    /**
     * The name and signature of the console command.
     *
     * @var string
     */
    protected $signature = 'sancionar:start {total} {medio}';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description = 'Command description';

    /**
    * variables de contenido de la tarea
    */
    protected $relacionContenido = '';
    protected $pdfMasivo = '';
    protected $comparendosImpresos = array();
    protected $ultimaNumeracion = 1900;
    protected $comparendopdf = '';
    protected $meses = [];
    protected $organismoNombreSecreteria = '';
    protected $organismoDireccion = '';
    protected $rutaImagenTop = '';

    /**
     * Create a new command instance.
     *
     * @return void
     */
    public function __construct()
    {
        parent::__construct();
    }

    /**
     * Execute the console command.
     *
     * @return mixed
     */
    public function handle()
    {
        $totalAImprimir = $this->argument('total');
        $medio = $this->argument('medio');
        $this->rutaImagenTop = '';
        if($medio == "c"){
          $this->rutaImagenTop = asset(config('myconfig.proyect_route') . '/images/transito_curumani.png');
        } else if($medio == "w"){
          $this->rutaImagenTop = asset('images/transito_curumani.png');
        }
        $this->line("totalAImprimir: $totalAImprimir");
        $rutaExpediente = \Config::get('myconfig.ruta_comparendo_expediente');
        $rutaPaquete = \Config::get('myconfig.ruta_paquetes_mensajeria');

        $organismo = \App\Organismo::first();
        $this->organismoDireccion = $organismo->direccion . ' ' . $organismo->ciudad->nombre . ' - ' . $organismo->ciudad->departamento->nombre;
        $this->organismoNombreSecreteria = $organismo->secretaria_nombre;

        $this->pdfMasivo = view('comparendos.comparendo_sancionado_head_pdf', [
                                'organismoDireccion' => $this->organismoDireccion,
                                'rutaImagenTop' => $this->rutaImagenTop
                              ]);
        $this->pdfMasivo .= '<style>.page-break {page-break-after: always;}</style>';

        //creando el paquete
        $paquete = new \App\ComparendoPaquete();
        $paquete->nombre = Carbon::now();
        $paquete->fecha = Carbon::now();
        $paquete->id_user = 4;
        $paquete->id_tipo_evento = 4;
        $paquete->es_impreso = 0;
        $paquete->save();

        $maxId = Comparendo::habilitadosParaSancionar('antiguo', false)->skip($totalAImprimir)->take(1)->value('id');

        $numeracion = Numeracion::select(DB::raw("max(final) as final"))->where('id_tipo_evento', '4')->first();

        if($numeracion != null){
          $this->ultimaNumeracion = $numeracion->final;
        }
        $inicioNumeracion = $this->ultimaNumeracion + 1;

        $this->meses = array('Enero', 'Febrero', 'Marzo', 'Abril', 'Mayo', 'Junio', 'Julio',
                       'Agosto', 'Septiembre', 'Octubre', 'Noviembre', 'Diciembre');

        $convertidorNumerosALetras = new \NumberToLetterConverter();

        $countAudiencia = 0;
        $horaAudiencia = new Carbon(Carbon::createFromTime(8, 0, 0));

        Comparendo::habilitadosParaSancionar('antiguo', false)->where('id', '<', $maxId)
                    ->chunk(200, function ($comparendos) use ($rutaExpediente, $paquete, $convertidorNumerosALetras, $countAudiencia, $horaAudiencia) {

                        foreach ($comparendos as $comparendo) {
                          /*INICIANDO EL CALCULO PARA EL TIEMPO DE AUDIENCIA*/
                          if ($countAudiencia == 32) {
                            $countAudiencia = 0;
                            $horaAudiencia = new Carbon(Carbon::createFromTime(8, 0, 0));
                          }
                          $horaInicio = $horaAudiencia->format('H:i A');
                          $horaAudiencia->addMinutes(15);
                          $horaFinal = $horaAudiencia->format('H:i A');
                          $countAudiencia++;
                          /*FIN DEL CALCULO*/

                          $this->ultimaNumeracion++;
                          $this->comparendosImpresos[] = array('final_numero' => $comparendo->final_numero);
                          $folder = $rutaExpediente . '/' . $comparendo->final_numero;
                          \File::makeDirectory($folder, 0755, true, true);
                          $archivo = '';

                          $archivo = 'RSC-' . $this->ultimaNumeracion . '-' . Carbon::now()->year . '.pdf';

                          $this->comparendopdf = view('comparendos.comparendo_sancionado_head_pdf',[
                                                  'organismoDireccion' => $this->organismoDireccion,
                                                  'rutaImagenTop' => $this->rutaImagenTop
                                                ]);
                          $infraccion_fecha = new Carbon($comparendo->infraccion_fecha);
                          $infraccion_fecha = $infraccion_fecha->day . ' de ' . $this->meses[$infraccion_fecha->month - 1] . ' de ' . $infraccion_fecha->year;
                          $sancionpdf =  view('comparendos.comparendo_sancionado_pdf', [
                                                  'comparendo' => $comparendo,
                                                  'descripcionInfraccion' => $comparendo->descripcion_infraccion,
                                                  'infraccion_fecha' => $infraccion_fecha,
                                                  'fecha_actual' => Carbon::now()->day . ' de ' . $this->meses[Carbon::now()->month - 1] . ' de ' . Carbon::now()->year,
                                                  'valorLetras' => $convertidorNumerosALetras->to_word(round($comparendo->valor)),
                                                  'horaInicio' => $horaInicio,
                                                  'horaFinal' => $horaFinal
                                                ]);

                          $this->comparendopdf .= $sancionpdf . '</body></html>';

                          $pdf = PDF::loadHTML($this->comparendopdf)->setPaper('letter', 'portrait');
                          $pdf->save($folder . '/' . $archivo);

                          //creando el registro en expediente
                          $expediente = new \App\ComparendoExpediente();
                          $expediente->id_comparendo = $comparendo->id;
                          $expediente->fecha_generacion = Carbon::now();
                          $expediente->nombre_documento = $archivo;
                          $expediente->id_tipo_evento = 4;//sancion
                          $expediente->id_paquete = $paquete->id;
                          $expediente->id_user = 4;
                          $expediente->save();

                          $this->pdfMasivo .=  $sancionpdf;
                          $this->pdfMasivo .= '<div class="page-break"></div>';
                          $this->relacionContenido .= $comparendo->final_numero . "\r\n";

                          $comparendoActualizar = Comparendo::find($comparendo->id);
                          $comparendoActualizar->id_tipo_evento = 4;
                          $comparendoActualizar->save();
                          $this->line("comparendo impreso: " . $comparendo->id);
                        }
        });
        $this->line("Actualizando Numeracion...");
        //actualizar la numeracion en un nuevo registro
        $numeracion = new Numeracion();
        $numeracion->prefijo = 'RSC';
        $numeracion->inicio = $inicioNumeracion;
        $numeracion->final = $this->ultimaNumeracion;
        $numeracion->id_tipo_evento = 4;//cobro persuasivo
        $numeracion->id_organismo = 1;
        $numeracion->id_paquete = $paquete->id;
        $numeracion->save();
        $this->line("Fin Numeracion");

        //$pdf = PDF::loadHTML($this->comparendopdf)->setPaper('letter', 'portrait');
        //return $pdf->stream('pdf.pdf');
        $this->line("Creando el PDF Masivo...");
        $this->pdfMasivo .= '</body></html>';
        $folder = $rutaPaquete . '/' . $paquete->id;
        \File::makeDirectory($folder, 0755, true, true);

        $pdf = PDF::loadHTML($this->pdfMasivo)->setPaper('letter', 'portrait');
        $archivo = 'paquete_' . $paquete->id;
        $pdf->save($folder . '/' . $archivo . '.pdf');
        $paquete->archivo_pdf = $archivo . '.pdf';

        //el archivo de remision
        \File::put($folder . '/' . $archivo . '.txt', $this->relacionContenido);

        //remision en pdf
        $pdf = PDF::loadView('comparendos.relacion_paquete',
                                [ 'comparendos' => $this->comparendosImpresos ]
                            )->setPaper('letter', 'portrait');
        $pdf->save($folder . '/remision.pdf');
        $paquete->archivo_remision = 'remision.pdf';

        $paquete->save();
        $this->line("Fin Pdf masivo y actualizacion del Paquete.");
    }
}
