<?php

namespace App\Console\Commands;

use Illuminate\Console\Command;
use Carbon\Carbon;
use App\Comparendo;
use App\ResolucionSimit;
use App\ComparendoNumeracionImpresion as Numeracion;
use App\Festivos;
use App\Pqr;
use App\Tipo;
use App\Infraccion;
use App\InfraccionF;
use App\InfraccionSalario;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Artisan;
use Barryvdh\DomPDF\Facade as PDF;
use LynX39\LaraPdfMerger\PdfManage;
use App\ParamHonorario;
use App\ParamImpuesto;
use App\ParamInteres;
use App\ParamSistematizacion;

class ResolucionesSimitSancion extends Command
{
  /**
   * The name and signature of the console command.
   *
   * @var string
   */
  protected $signature = 'resolucionessimit:sancion';

  /**
   * The console command description.
   *
   * @var string
   */
  protected $description = 'Genera sanciones en la tabla resoluciones simit a los comparendos';

  /**
   * Create a new command instance.
   *
   * @return void
   */
  public function __construct()
  {
      parent::__construct();
  }

  /**
   * Execute the console command.
   *
   * @return mixed
   */
  public function handle()
  {
    $phono=ParamHonorario::orderby('id', 'desc')->first();
    $psiste=ParamSistematizacion::orderby('id', 'desc')->first();
    $festivos = Festivos::all();
    $organismo = \App\Organismo::first();

      $ultimaNumeracion = 0;
      $numeracion = Numeracion::select(DB::raw("max(final) as final"))
                               ->where('id_tipo_evento', '4')->first();

      if($numeracion != null){
        $ultimaNumeracion = $numeracion->final;
      }
      $inicioNumeracion = $ultimaNumeracion + 1;

      $comparendos = Comparendo::where('infracciones', 'not like', DB::raw("'%I%'"))
                              ->where('infracciones', 'not like', DB::raw("'%J%'"))
                              ->where('infracciones', 'not like', DB::raw("'%G%'"))
                              //->where('infraccion_fecha', '>=', DB::raw("'2015-01-01'"))
                              ->where('tiene_saldo', 1)
                              ->where('inactivarsancion', 0)
                              ->orderBy('infraccion_fecha', 'desc')
                              ->get();

      $puedePasar = false;
      foreach ($comparendos as $comparendo) {


        $sancion = ResolucionSimit::where('COL5', '1')->where('COL7', $comparendo->numero)->first();
        if($comparendo->tieneSaldo($comparendo->id) && !isset($sancion->id)){
          //comparar las fechas
          $fechaActual = Carbon::now();
          $fechaComparendo = new Carbon($comparendo->infraccion_fecha);
          $fechaSancion = $fechaComparendo->addDays(31);//31 dias despues de la infraccion es sancion
          $fechaSancion = Comparendo::calcularFechaHabilLaboral($festivos, $fechaSancion);
          $fechaSancion = new Carbon($fechaSancion);//fecha de mandamiento habil
          if($fechaSancion->lt($fechaActual)){
            $ultimaNumeracion++;
            $numeroResolucion = 'RS-' . $ultimaNumeracion . '-' . $fechaSancion->year;
            //creando el registro en resoluciones simit
            $fechaComparendo = new Carbon($comparendo->infraccion_fecha);
            $resolucion = new ResolucionSimit();
            $resolucion->COL2 = $numeroResolucion;
            $resolucion->COL4 = $fechaSancion->format('d/m/Y');
            $resolucion->COL5 = '1';
            $resolucion->COL7 = $comparendo->numero;
            $resolucion->COL8 = $fechaComparendo->format('d/m/Y');
            $resolucion->COL9 = $comparendo->infractor_documento;

            $infractor_tipo_doc = Tipo::where('id', $comparendo->infractor_tipo_documento)->get();
            foreach ($infractor_tipo_doc as $tp) {
                $resolucion->COL10 = $tp->codigo;              
            }


            
            $resolucion->COL11 = mb_strtoupper($comparendo->infractor_nombre);
            $resolucion->COL12 = mb_strtoupper($comparendo->infractor_apellido);
            $resolucion->COL13 = mb_strtoupper($comparendo->infraccion_direccion);
            $resolucion->COL15 = $organismo->codigo;
            $resolucion->COL16 = $comparendo->valor-$comparendo->pagos;
            $resolucion->COL17 = 0;

          if($organismo->codigo=="13673000")
          {
           // $hono2=$hono2+22076;
           //  $resolucion->COL17 = round(($comparendo->valor * $phono->valor) / 100)+$psiste->valor;
          }

            if($comparendo->es_fotomulta == 0){
              $resolucion->COL18 = 'N';
            } elseif($comparendo->es_fotomulta == 1){
              $resolucion->COL18 = 'S';
            }
            $resolucion->COL19 = $organismo->codigo;

            if($comparendo->es_polca == 0){
              $resolucion->COL20 = 'N';
            } else{
              $resolucion->COL20 = 'S';
            }

            $resolucion->COL21 = $comparendo->infracciones;
            $resolucion->COL22 = $comparendo->valor-$comparendo->pagos;
            $resolucion->COL23 = $comparendo->valor-$comparendo->pagos;

            if($comparendo->infracciones == 'F'){
              $resolucion->COL24 = $comparendo->grado_alcohol;
              $resolucion->COL25 = 'N';
            }else{
              $resolucion->COL24 = '';
              $resolucion->COL25 = '';
            }
            $resolucion->confirmado_simit = 0;
            $resolucion->es_pdf_impreso = 0;
            $resolucion->save();


      //ojo comentariar
          Artisan::call('sancionpdf:start', [
              'id_resolucion' => $resolucion->id,
              'medio' => 'c',
              'banner' => 'new'
          ]);
          $this->info(Artisan::output());


            $this->line("Num RES... " . $numeroResolucion);
            $comparendoActualizar = Comparendo::find($comparendo->id);
            $comparendoActualizar->id_tipo_evento = 4;//sancion
            $comparendoActualizar->pagos= 0;
            $comparendoActualizar->save();




          }
        }else{
          $comparendo->tiene_saldo = 0;
          $comparendo->save();
        }
      }
        $this->line("Actualizando Numeracion:");
      if($ultimaNumeracion >= $inicioNumeracion){
        $this->line("Actualizando Numeracion...".$inicioNumeracion);
        //actualizar la numeracion en un nuevo registro
        $numeracion = new Numeracion();
        $numeracion->prefijo = 'RS';
        $numeracion->inicio = $inicioNumeracion;
        $numeracion->final = $ultimaNumeracion;
        $numeracion->id_tipo_evento = 4;//sancion
        $numeracion->id_organismo = $organismo->id;
        $numeracion->id_paquete = 0;
        $numeracion->save();
        $this->line("Fin Numeracion".$ultimaNumeracion);
      } else {
        $this->line("No se imprimo sanciones.");
      }

  }
}
