<?php

namespace App\Console\Commands;

use Illuminate\Console\Command;
use Carbon\Carbon;
use App\Comparendo;
use App\ResolucionSimit;
use App\NumeracionOficio;
use App\Http\Controllers\HomeController;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Collection;

class RuntExportarCiudadanos extends Command
{
  /**
   * The name and signature of the console command.
   *
   * @var string
   */

  protected $signature = 'runt:exportar_ciudadanos';

  /**
   * The console command description.
   *
   * @var string
   */
  protected $description = 'Exporta los ciudadanos que tienen desactualizada la direccion X tiempo para consultar en RUNT.';

  /**
   * Create a new command instance.
   *
   * @return void
   */
  public function __construct()
  {
      parent::__construct();
  }

  /**
   * Execute the console command.
   *
   * @return mixed
   */
  public function handle()
  {
    $rutaArchivo = $basePath = storage_path().'/app/runt/exportar/';

    $organismo = \App\Organismo::first();
    $organismoCodigo = $organismo->codigo;
    $folder = $rutaArchivo . Carbon::now()->format('Y-m-d'). '/';
    $archivo = $organismoCodigo . 'consultar_runt.txt';
    \File::makeDirectory($folder, 0777, true, true);

    $resoluciones = ResolucionSimit::resolucionesDireccionDesactualizada()
    ->where(function ($query) {
        $query->where('COL2', 'like', DB::raw("'RMP-%'"))
            ->orWhere('COL2', 'like', DB::raw("'RS-%'"));
    })
    ->get();
    $arrayComparendosRecorridos = [];
    array_push($arrayComparendosRecorridos, (object) array(
        'cedula' => $resoluciones->get(0)->COL9
    ));
    $txt = "";
    $count = 1;
    foreach ($resoluciones as $resolucion) {
      $collectionRecorridos = new Collection($arrayComparendosRecorridos);
      $countRecorridos = $collectionRecorridos->where('cedula', '=', $resolucion->COL9)->count();
      if($countRecorridos == 0){
        array_push($arrayComparendosRecorridos, (object) array(
            'cedula' => $resolucion->COL9
        ));
        $comparendo = Comparendo::where('numero', '=', $resolucion->COL7)->first();
        $tmp = [];

        $this->line("resolucion: " . $resolucion->COL2);
        $count++;
        $tmp['CEDULA'] = str_replace(',', '', $resolucion->COL9);
        $tmp['PLACA'] = str_replace(',', '', $comparendo->vehiculo_placa);
        $txt .= implode(',', $tmp) . "\n";
      }
    }
    $this->line("resoluciones: " . count($resoluciones));
    $this->line("total: " . $count);

    \File::put($folder . $archivo, $txt);
    $this->line("FIN: " . $archivo);
  }
}
