<?php

namespace App\Console\Commands;

use Illuminate\Console\Command;
use Carbon\Carbon;
use App\Comparendo;
use App\ResolucionSimit;
use App\NumeracionOficio;
use App\Http\Controllers\HomeController;
use Illuminate\Support\Facades\DB;
use App\RecaudoSimit;

class SimitTxtResoluciones extends Command
{
  /**
   * The name and signature of the console command.
   *
   * @var string
   */

  protected $signature = 'simittxt:resoluciones {tipo_resolucion}';

  /**
   * The console command description.
   *
   * @var string
   */
  protected $description = 'Busca las resoluciones que no se han impreso en el txt a enviar al simit.';

  /**
   * Create a new command instance.
   *
   * @return void
   */
  public function __construct()
  {
      parent::__construct();
  }

  /**
   * Execute the console command.
   *
   * @return mixed
   */
  public function handle()
  {
    $tipoResolucion = $this->argument('tipo_resolucion');
    $rutaArchivo = $basePath = storage_path().'/app/simittxt/resoluciones/';

    $organismo = \App\Organismo::first();
    $organismoCodigo = $organismo->codigo;
    $folder = $rutaArchivo . Carbon::now()->format('Y-m-d'). '/';
    $archivo = $organismoCodigo . 'resol.txt';
    \File::makeDirectory($folder, 0777, true, true);

    $resoluciones = ResolucionSimit::where('confirmado_simit', '=', '0');
    if($tipoResolucion == 'rs'){
      $resoluciones = $resoluciones->where('COL2', 'like', DB::raw("'RS-%'"));
    } else if($tipoResolucion == 'rmp'){
      $resoluciones = $resoluciones->where('COL2', 'like', DB::raw("'RMP-%'"));
    } else if($tipoResolucion == 'rp'){//prescripcion
      $resoluciones = $resoluciones->where('COL2', 'like', DB::raw("'RP-%'"));
    } else if($tipoResolucion == 'irap'){//incumplimiento acuerdo de pago
      $resoluciones = $resoluciones->where('COL2', 'like', DB::raw("'IRAP-%'"));
    } else if($tipoResolucion == 'arap'){//anulacion acuerdo de pago
      $resoluciones = $resoluciones->where('COL2', 'like', DB::raw("'ARAP-%'"));
    } else if($tipoResolucion == 'rd'){//revocatoria directa
      $resoluciones = $resoluciones->where('COL2', 'like', DB::raw("'RD-%'"));
    } else if($tipoResolucion == 'rap'){//acuerdo de pago
      $resoluciones = $resoluciones->where('COL2', 'like', DB::raw("'RAP-%'"));
    } else if($tipoResolucion == 'ars'){
      $resoluciones = $resoluciones->where('COL2', 'like', DB::raw("'ARS-%'"));
    } else if($tipoResolucion == 'armp'){
      $resoluciones = $resoluciones->where('COL2', 'like', DB::raw("'ARMP-%'"));
    } else{
      $this->line("CODIGO NO VALIDO");
      die;
    }
    $resoluciones = $resoluciones->limit(1000)->get();

    $txt = "";
    $total = 0;
    $consecutivo = 0;
    $totalAcuerdo = 0;
    $puedeIrASimit = false;
    foreach ($resoluciones as $resolucion) {
      if($resolucion->COL5 == '6' || $resolucion->COL5 == '8'){
        //buscando el recaudo
        $recaudoCount = RecaudoSimit::where('C10', '=', $resolucion->COL2)
                                      ->orWhere('C10', '=', $resolucion->COL7)
                                      ->orWhere('C15', '=', $resolucion->COL2)
                                      ->orWhere('C15', '=', $resolucion->COL7)
                                      ->orWhere('C16', '=', $resolucion->COL2)
                                      ->orWhere('C16', '=', $resolucion->COL7)
                                      ->count();
        if($recaudoCount > 0){
          $puedeIrASimit = true;
        } else {
          $puedeIrASimit = false;
        }
      } else {
        $puedeIrASimit = true;
      }
      if($puedeIrASimit){
        $tmp = [];
        $consecutivo++;
        $total += $resolucion->COL16;

        $this->line("resolucion: " . $resolucion->COL2);
        $tmp['RESCONSECUTIVO'] = $consecutivo;
        $tmp['RESNUMERO'] = str_replace(',', '', $resolucion->COL2);
        $tmp['RESNUMANT'] = str_replace(',', '', $resolucion->COL3);
        $tmp['RESFECHA'] = str_replace(',', '', $resolucion->COL4);
        $tmp['RESTIPORES'] = str_replace(',', '', $resolucion->COL5);
        $tmp['RESFHASTA'] = str_replace(',', '', $resolucion->COL6);
        $tmp['RESCOMP'] = str_replace(',', '', $resolucion->COL7);
        $tmp['RESCOMPF'] = str_replace(',', '', $resolucion->COL8);
        $tmp['RESNIPINFRAC'] = str_replace(',', '', $resolucion->COL9);
        $tmp['RESTIPODOC'] = str_replace(',', '', $resolucion->COL10);
        $tmp['RESNOMBE'] = str_replace(',', '', $resolucion->COL11);
        $tmp['RESAPELLIDO'] = str_replace(',', '', $resolucion->COL12);
        $tmp['RESDIRINFRACTOR'] = str_replace(',', '', $resolucion->COL13);
        $tmp['RESTELEINFRACTOR'] = str_replace(',', '', $resolucion->COL14);
        $tmp['RESIDCIUDAD'] = str_replace(',', '', $resolucion->COL15);
        $tmp['RESVALOR'] = str_replace(',', '', $resolucion->COL16);
        if($resolucion->COL17 >= '0'){
          $tmp['RESVALAD'] = str_replace(',', '', $resolucion->COL17);
        }else{
          $tmp['RESVALAD'] = '0';
        }
        $tmp['FOTOMULTA'] = str_replace(',', '', $resolucion->COL18);
        $tmp['RESORGANISMO'] = str_replace(',', '', $resolucion->COL19);
        $tmp['RESCOMPOLCA'] = str_replace(',', '', $resolucion->COL20);
        $tmp['RESINFRACCION'] = str_replace(',', '', $resolucion->COL21);
        $tmp['RESVALINF'] = str_replace(',', '', $resolucion->COL22);
        $tmp['RESVALPAG'] = str_replace(',', '', $resolucion->COL16);
        if($resolucion->COL21 == 'F'){
          $tmp['GRADOALCOHOL'] = str_replace(',', '', $resolucion->COL24);
          $tmp['HORASCOMUNITARIAS'] = str_replace(',', '', $resolucion->COL25);
        }else{
          $tmp['GRADOALCOHOL'] = '';
          $tmp['HORASCOMUNITARIAS'] = '';
        }
        $txt .= implode(',', $tmp) . "\n";
      }
    }

    $ascii = HomeController::string_to_ascii($txt);
    $digitoChequeo = $ascii % 10000;

    //Insertar oficio
    $ultimo = NumeracionOficio::where('id_organismo', $organismo->id)->orderBy('id', 'DESC')->first();

    $oficio = new NumeracionOficio();
    $oficio->prefijo = 'OF';
    $oficio->numero = $ultimo->numero + 1;
    $oficio->id_organismo = $organismo->id;
    $oficio->save();

    $control = array();
    $control['numreg'] = $consecutivo;
    $control['sumreg'] = round($total);
    $control['oficio'] = "OF" . str_pad($oficio->numero, 8, "0", 0);
    $control['codchequeo'] = $digitoChequeo;

    $txt .= implode(',', $control);

    \File::put($folder . $archivo, $txt);
    $puedeIrASimit = false;
    foreach ($resoluciones as $resolucion2) {
      if($resolucion2->COL5 == '6' || $resolucion2->COL5 == '8'){
        //buscando el recaudo
        $recaudoCount = RecaudoSimit::where('C10', '=', $resolucion2->COL2)
                                      ->orWhere('C10', '=', $resolucion2->COL7)
                                      ->orWhere('C15', '=', $resolucion2->COL2)
                                      ->orWhere('C15', '=', $resolucion2->COL7)
                                      ->orWhere('C16', '=', $resolucion2->COL2)
                                      ->orWhere('C16', '=', $resolucion2->COL7)
                                      ->count();
        if($recaudoCount > 0){
          $puedeIrASimit = true;
        } else {
          $puedeIrASimit = false;
        }
      } else {
        $puedeIrASimit = true;
      }
      if ($puedeIrASimit) {
        $resolucion2->confirmado_simit = 1;
        $resolucion2->save();
      }
    }
    $this->line("FIN: " . $archivo);
  }
}
