<?php

namespace App\Console\Commands;

use Illuminate\Console\Command;
use App\Comparendo;
use App\ResolucionSimit;
use App\ComparendoSimit;
use App\ResolucionSimitError;
use App\ResolucionSimitErrorDetalle;
use App\RecaudoSimit;
use App\Transaccion;
use Carbon\Carbon;
use Illuminate\Support\Collection;

class TransaccionesToRecaudosSimit extends Command
{
  /**
   * The name and signature of the console command.
   *
   * @var string
   */

  protected $signature = 'transacciones:torecaudosimit';

  /**
   * The console command description.
   *
   * @var string
   */
  protected $description = 'Este comando transfiere de transacciones a recaudos simit.';

  /**
   * Create a new command instance.
   *
   * @return void
   */
  public function __construct()
  {
      parent::__construct();
  }

  /**
   * Execute the console command.
   *
   * @return mixed
   */
  public function handle()
  {

    //pasa los pagos de transacciones a recaudos simit
    $organismo = \App\Organismo::first();
    $transacciones = Transaccion::whereNotNull('fecha_descarga')->where('etiqueta', '=', 'pago-comparendo')->get();
    $arrayComparendosRecorridos = [];
    foreach ($transacciones as $transaccion) {
      if($transaccion->esTransaccionAprobada()){
        $recaudo = new RecaudoSimit();
        $recaudo->C2 = Carbon::createFromFormat("Y-m-d H:i:s", $transaccion->created_at)->format('d/m/Y');
        $recaudo->C3 = Carbon::createFromFormat("Y-m-d H:i:s", $transaccion->created_at)->format('H:i');
        $recaudo->C4 = Carbon::createFromFormat("Y-m-d", $transaccion->getFechaTransaccion())->format('d/m/Y');
        $recaudo->C5 = '0';
        $recaudo->C6 = 'taquilla transito';
        $recaudo->C7 = $transaccion->valor;
        $recaudo->C8 = '0';
        $recaudo->C9 = $transaccion->valor;
        $resolucion = Comparendo::getResolucionesByComparendo($transaccion->obtenerPrimerComparendo()->numero)->orderBy('COL4F', 'desc')->first();
        //si han pagado es porque tienen o tenian resolucion 1, 6, 8, 16 o 17 activa, no hay que hacer filtro de tipo de resolucion.
        if(isset($resolucion->COL5)){
          if ($resolucion->COL5 == '16' || $resolucion->COL5 == '17' || $resolucion->COL5 == '6' || $resolucion->COL5 == '8') {
            $recaudo->C10 = $resolucion->COL2;
          } else {
            $recaudo->C10 = $transaccion->obtenerPrimerComparendo()->numero;
          }
        } else {
          $recaudo->C10 = $transaccion->obtenerPrimerComparendo()->numero;
        }

        $recaudo->C11 = 'N';
        if ($transaccion->obtenerPrimerComparendo()->es_polca) {
            $recaudo->C11 = 'S';
        }

        $recaudo->C12 = $transaccion->obtenerPrimerComparendo()->infractor_documento;

        if(isset($resolucion->COL5)){
          if ($resolucion->COL5 == '6' || $resolucion->COL5 == '8') {
            $recaudo->C13 = '4';
          } elseif ($resolucion->COL5 == '16' || $resolucion->COL5 == '17') {
            $recaudo->C13 = '6';
          } else {
            $recaudo->C13 = '1';
          }
        } else {
          $recaudo->C13 = '1';
        }

        $recaudo->C14 = $organismo->codigo;
        $recaudo->C15 = $transaccion->cns_factura;

        $recaudo->C16 = $recaudo->C10;//numero de cuota, pero no puedo calcularla hasta que descargue el pago.
        $recaudo->fuente = 'local';

        $recaudoBuscado = RecaudoSimit::where('C2', '=', $recaudo->C2)
                                      ->where('C3', '=', $recaudo->C3)
                                      ->where('C4', '=', $recaudo->C4)
                                      ->where('C5', '=', $recaudo->C5)
                                      ->where('C6', '=', $recaudo->C6)
                                      ->where('C7', '=', $recaudo->C7)
                                      ->where('C8', '=', $recaudo->C8)
                                      ->where('C9', '=', $recaudo->C9)
                                      ->where('C10', '=', $recaudo->C10)
                                      ->where('C11', '=', $recaudo->C11)
                                      ->where('C12', '=', $recaudo->C12)
                                      ->where('C13', '=', $recaudo->C13)
                                      ->where('C14', '=', $recaudo->C14)
                                      ->where('C15', '=', $recaudo->C15)
                                      ->get();
        $this->line("COUNT " . count($recaudoBuscado));
        if(count($recaudoBuscado) == 0){
          $this->line("INSERTANDO RECAUDO " . $transaccion->id);
          $recaudo->save();
        }else{
          $this->error("YA REGISTRADO " . $transaccion->id);
        }
      }
    }
  }
}
