<?php

namespace App\Console\Commands;

use App\Coactivo;
use App\Http\Controllers\ImpuestosController;
use App\Http\Controllers\VehiculosController;
use App\Impuesto;
use App\ImpuestoAnulado;
use App\Vehiculo;
use Carbon\Carbon;
use Illuminate\Console\Command;

class morosos extends Command
{
    /**
     * The name and signature of the console command.
     *
     * @var string
     */
    protected $signature = 'coactivos';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description = 'Genera tabla coactivos';

    /**
     * Create a new command instance.
     *
     */
    public function __construct()
    {
        parent::__construct();
    }

    /**
     * Execute the console command.
     *
     * @return void
     */
    public function handle()
    {
        
        \DB::table('coactivos')->truncate();
        $anoActual = Carbon::now()->format('Y');

        $chunks = Vehiculo::where('auto','1')->get()->sortBy('placa')->chunk(100);
        $c = 0;
        foreach($chunks as $vehiculos){
            foreach($vehiculos as $vehiculo){

                $c++;
                $this->line("{$c}. CONSULTANDO {$vehiculo->placa}");
                $this->line("============================================================");

                VehiculosController::actualizarPropietario($vehiculo);

                //$anoInicial = 2007;
				$anoInicial =config('myconfig.ano_inicial');
                if ($vehiculo->ano) {
                    if ($vehiculo->ano >= $anoInicial) {
                        $anoInicial = $vehiculo->ano;
                    }
                }

                $this->line("Consultando impuestos desde año {$anoInicial}");

                $impuestosAnulados = ImpuestoAnulado::where('id_vehiculo', $vehiculo->id)
                    ->where('estado', 'anulado')
                    ->get(['ano'])->pluck('ano')->toArray();

                $impuestosPagados = Impuesto::where('id_vehiculo', $vehiculo->id)
                    ->where('estado', 'pagado')
                    ->get(['ano'])->pluck('ano')->toArray();

                $impuestosSaneados = array_merge($impuestosAnulados, $impuestosPagados);

                $impuestosPendientes = [];
                //Obtener impuestos que debe
                for($i = $anoInicial; $i <= $anoActual; $i++){
                    if(!in_array($i, $impuestosSaneados)){
                        $impuestosPendientes[] = $i;
                    }
                }

                $this->line("Pagados: " . implode(', ', $impuestosPagados));

                if($impuestosPendientes){
                    $this->error("Pendientes: " . implode(', ', $impuestosPendientes));

                    foreach ($impuestosPendientes as $pendiente) {
                        $coactivo = new Coactivo();
                        $coactivo->placa = $vehiculo->placa;

                        if($vehiculo->ciudadano && $vehiculo->ciudadano->nombre){
                            $coactivo->nombre = $vehiculo->ciudadano->nombre;
                        }

                        if ($vehiculo->ciudadano && $vehiculo->ciudadano->numero_documento) {
                            $coactivo->documento = strtoupper($vehiculo->ciudadano->tipo_documento) . " " .number_format(intval($vehiculo->ciudadano->numero_documento), 0, '.', '.');
                        }

                        $coactivo->ano = $pendiente;

                        if ($vehiculo->ciudadano && $vehiculo->ciudadano->direccion_residencia) {
                            $coactivo->direccion = $vehiculo->ciudadano->direccion_residencia;
                        }

                        if ($vehiculo->ciudadano && $vehiculo->ciudadano->ciudad) {
                            $coactivo->ciudad = $vehiculo->ciudadano->ciudad->nombre;
                        }

                        if ($vehiculo->ciudadano && $vehiculo->ciudadano->ciudad) {
                            $coactivo->departamento = $vehiculo->ciudadano->ciudad->departamento->nombre;
                        }

                        if ($vehiculo->ciudadano && $vehiculo->ciudadano->telefono_fijo) {
                            $coactivo->fijo = $vehiculo->ciudadano->telefono_fijo;
                        }

                        if ($vehiculo->ciudadano && $vehiculo->ciudadano->telefono_celular) {
                            $coactivo->celular = $vehiculo->ciudadano->telefono_celular;
                        }


                        $tmp = ImpuestosController::calcularImpuestos($vehiculo, $pendiente);
                        $coactivo->impuestos = round($tmp['pendiente_impuestos']);
                        $coactivo->intereses = round($tmp['pendiente_intereses']);
                        $coactivo->honorarios = round($tmp['pendiente_honorarios']);
                        $coactivo->sistematizacion = round($tmp['pendiente_sistematizacion']);
                        $coactivo->total = $coactivo->impuestos + $coactivo->intereses + $coactivo->honorarios + $coactivo->sistematizacion;

                        $coactivo->save();
                    }
                }


                $this->line("============================================================");
                $this->line("");
            }
        }

        
    }
}
