<?php

namespace App\Exports;
use App\Http\Controllers\LogController;
use App\Pqrs;
use Illuminate\Support\Facades\DB;
use Maatwebsite\Excel\Concerns\FromCollection;
use Maatwebsite\Excel\Concerns\FromQuery;
use Maatwebsite\Excel\Concerns\Exportable;
use Maatwebsite\Excel\Concerns\WithHeadings;
use Maatwebsite\Excel\Events\AfterSheet;
use Maatwebsite\Excel\Concerns\WithEvents;
use Maatwebsite\Excel\Concerns\WithDrawings;
use Maatwebsite\Excel\Concerns\WithCustomStartCell;
use PhpOffice\PhpSpreadsheet\Worksheet\Drawing;
use App\User;
use \Maatwebsite\Excel\Sheet;

class PostExportEstadisticaArea implements FromCollection,WithCustomStartCell,WithHeadings, WithEvents,WithDrawings
{
    /**
    * @return \Illuminate\Support\Collection
    */
    use Exportable;
    protected $input;


    function __construct($input) {
        $this->input = $input;
    }
    public function startCell(): string
    {
        return 'A2';
    }
    public function drawings()
    {
        $drawing = new Drawing();
        $drawing->setName('LOGO');
        $drawing->setDescription('REPORTE ESTADISTICO DE PETICIONES PQR');
        $drawing->setPath(public_path('assets/images/xiltrion.png'));
        $drawing->setHeight(20);
        $drawing->setCoordinates('A1');
        return $drawing;
    }
    public function headings(): array{
        return [
            "AREA",
            "CANTIDAD",
            "PORCENTAJE",
            "REPROCESOS"
        ];
    }
    public function registerEvents(): array {
        
        return [
            AfterSheet::class => function(AfterSheet $event) {
                /** @var Sheet $sheet */
                $sheet = $event->sheet;
                $sheet->mergeCells('B1:D1');
                $sheet->setCellValue('B1', "REPORTE ESTADISTICO DE PETICIONES PQR");
                
                $styleArray = [
                    'alignment' => [
                        'horizontal' => \PhpOffice\PhpSpreadsheet\Style\Alignment::HORIZONTAL_CENTER,
                    ],
                ];
                $sheet->getStyle('A1:D1')->applyFromArray([
                    'font' => [
                        'bold' => true
                    ]
                ]);
                $sheet->getStyle('A2:D2')->applyFromArray([
                    'font' => [
                        'bold' => true
                    ]
                ]);

                
                $cellRange = 'A1:D1'; // All headers
                $event->sheet->getDelegate()->getStyle($cellRange)->applyFromArray($styleArray);
            },
        ];
    }
    public function collection()
    {
        $modulo = 'ExportEstadisticaGenerales/query';
        $request = "Solicitud de reporte de estadisticas de area";
        $fecha_busqueda = $this->input->fecha_buscar;
        $fecha_busqueda2 = $this->input->fecha_buscar2;
        $user = user::where("id",Auth()->id())->first();
        try{
            if(!empty($fecha_busqueda ) && !empty($fecha_busqueda2)){
                if($user->is_super ==1){
                    $datos_area_general = Pqrs::select('a.nombre as area' ,db::raw('COUNT(*) as cantidad ,CONCAT( ROUND( ( COUNT(*)  / ( SELECT COUNT(*) FROM pqrs LIMIT 1) * 100 ),2 ), "%" ) AS porcentaje,
                    (SELECT COUNT(*) AS cantidad FROM observaciones_pqr op JOIN pqrs pq ON op.id_pqr = pq.id JOIN area a2 ON a2.id = pq.area WHERE a2.id  = a.id ) AS cantidad_rechazada'))
                    ->from('pqrs as p')
                    ->join('area as a', 'a.id', '=', 'p.area')
                    ->where('p.active',1)
                    ->whereBetween('p.fecha_recepcion',[$fecha_busqueda,$fecha_busqueda2])
                    ->groupBy('area','cantidad_rechazada')->get();
                }else{
                    $datos_area_general = Pqrs::select('a.nombre as area' ,db::raw('COUNT(*) as cantidad ,CONCAT( ROUND( ( COUNT(*)  / ( SELECT COUNT(*) FROM pqrs LIMIT 1) * 100 ),2 ), "%" ) AS porcentaje,
                    (SELECT COUNT(*) AS cantidad FROM observaciones_pqr op JOIN pqrs pq ON op.id_pqr = pq.id JOIN area a2 ON a2.id = pq.area WHERE a2.id  = a.id ) AS cantidad_rechazada'))
                    ->from('pqrs as p')
                    ->join('area as a', 'a.id', '=', 'p.area')
                    ->where('p.area',$user->id_area)
                    ->where('p.active',1)
                    ->whereBetween('p.fecha_recepcion',[$fecha_busqueda,$fecha_busqueda2])
                    ->groupBy('area','cantidad_rechazada')->get();
                }
            }else{
                if($user->is_super ==1){
                    $datos_area_general = Pqrs::select('a.nombre as area' ,db::raw('COUNT(*) as cantidad ,CONCAT( ROUND( ( COUNT(*)  / ( SELECT COUNT(*) FROM pqrs LIMIT 1) * 100 ),2 ), "%" ) AS porcentaje,
                    (SELECT COUNT(*) AS cantidad FROM observaciones_pqr op JOIN pqrs pq ON op.id_pqr = pq.id JOIN area a2 ON a2.id = pq.area WHERE a2.id  = a.id ) AS cantidad_rechazada'))
                    ->from('pqrs as p')
                    ->join('area as a', 'a.id', '=', 'p.area')
                    ->groupBy('area')->get();
                }else{
                    $datos_area_general = Pqrs::select('a.nombre as area' ,db::raw('COUNT(*) as cantidad ,CONCAT( ROUND( ( COUNT(*)  / ( SELECT COUNT(*) FROM pqrs LIMIT 1) * 100 ),2 ), "%" ) AS porcentaje,
                    (SELECT COUNT(*) AS cantidad FROM observaciones_pqr op JOIN pqrs pq ON op.id_pqr = pq.id JOIN area a2 ON a2.id = pq.area WHERE a2.id  = a.id ) AS cantidad_rechazada'))
                    ->from('pqrs as p')
                    ->where('p.area',$user->id_area)
                    ->where('p.active',1)
                    ->join('area as a', 'a.id', '=', 'p.area')
                    ->groupBy('area','cantidad_rechazada')->get();
                    $flag = true;
                }
            }

        } catch (\Exception $e) {
            $datos_area_general = $e->getMessage();   
        }
        LogController::guardarLog($modulo,$request,$datos_area_general);
        return collect($datos_area_general);
    }
}
