<?php

namespace App\Exports;
use App\Http\Controllers\LogController;
use App\Pqrs;
use App\PeticionesApoyo;
use App\TpDocumento;
use Carbon\Carbon;
use App\Http\Controllers\PQRController;
use Maatwebsite\Excel\Concerns\FromCollection;
use Maatwebsite\Excel\Concerns\Exportable;
use Maatwebsite\Excel\Concerns\WithHeadings;
use Maatwebsite\Excel\Events\AfterSheet;
use Maatwebsite\Excel\Concerns\WithEvents;
use Maatwebsite\Excel\Concerns\WithDrawings;
use Maatwebsite\Excel\Concerns\WithCustomStartCell;
use PhpOffice\PhpSpreadsheet\Worksheet\Drawing;


class PostExportEstadisticaGenerales implements  FromCollection,WithCustomStartCell,WithHeadings, WithEvents,WithDrawings
{
    /**
    * @return \Illuminate\Support\Collection
    */
    use Exportable;
    protected $input;


    function __construct($input) {
        $this->input = $input;
    }
    public function startCell(): string
    {
        return 'A2';
    }
    public function headings(): array{
     
        return [
            'cantidad_radicacion',
            'cantidad_estudio' ,
            'cantidad_gestion',
            'cantidad_pendiente',
            'cantidad_enviado',
            'cantidad_reproceso',
            'total_pqr',
            'total_pqr_apoyo',
            'vencidos_con_respuestas',
            'vencidos_sin_respuestas',
            'porcentaje_radicacion',
            'porcentaje_estudio',
            'porcentaje_gestion',
            'porcentaje_pendiente',
            'porcentaje_enviado',
            'porcentaje_total',
            'eficacia_general',
            'radicacion_vs_resueltos',
            'enviados_vs_radicacion',
            'reproceso_vs_radicacion',
        ];
    }

    public function drawings()
    {
        $drawing = new Drawing();
        $drawing->setName('LOGO');
        $drawing->setDescription('REPORTE ESTADISTICO DE PETICIONES PQR');
        $drawing->setPath(public_path('assets/images/xiltrion.png'));
        $drawing->setHeight(20);
        $drawing->setCoordinates('A1');
        return $drawing;
    }
    public function registerEvents(): array {
        
        return [
            AfterSheet::class => function(AfterSheet $event) {
                /** @var Sheet $sheet */
                $sheet = $event->sheet;
                $header = $event->sheet;
                $sheet->mergeCells('B1:T1');
                $sheet->setCellValue('B1', "REPORTE ESTADISTICO DE PETICIONES PQR");
                
                $styleArray = [
                    'alignment' => [
                        'horizontal' => \PhpOffice\PhpSpreadsheet\Style\Alignment::HORIZONTAL_CENTER,
                    ],
                ];
                $sheet->getStyle('A1:T1')->applyFromArray([
                    'font' => [
                        'bold' => true
                    ]
                ]);
                $header->getStyle('A2:T2')->applyFromArray([
                    'font' => [
                        'bold' => true
                    ]
                ]);

                
                $cellRange = 'A1:T1'; // All headers
                $cell_header_range = 'A2:T2';
                $event->sheet->getDelegate()->getStyle($cellRange)->applyFromArray($styleArray);
                $event->sheet->getDelegate()->getStyle($cell_header_range)->applyFromArray($styleArray);
            },
        ];
    }

    public function collection()
    {   
        $modulo = 'ExportEstadisticaGenerales/query';
        $request = "Solicitud de reporte de estadisticas generales";
        $datos = [];
        $fecha_busqueda = $this->input->fecha_buscar;
        $fecha_busqueda2 = $this->input->fecha_buscar2;
        $vencidos_sin_respuestas = 0;
        $vencidos_con_respuestas = 0;
        $ratio_pqrs = 0;
        $pqrcontroller = new PQRController();
        try{
            if(!empty($fecha_busqueda ) && !empty($fecha_busqueda2)){
                $cantidad_ingreso = Pqrs::where('estado', '1')->where("active","1")->whereBetween('fecha_recepcion',[$fecha_busqueda, $fecha_busqueda2])->get()->count();
                $cantidad_estudio = Pqrs::where('estado', '2')->where("active","1")->whereBetween('fecha_recepcion',[$fecha_busqueda, $fecha_busqueda2])->get()->count();
                $cantidad_gestion =  Pqrs::whereIn('estado', ['6','7'])->where("active","1")->whereBetween('fecha_recepcion',[$fecha_busqueda, $fecha_busqueda2])->get()->count();
                $cantidad_pendiente = Pqrs::where('estado', '3')->where("active","1")->whereBetween('fecha_recepcion',[$fecha_busqueda, $fecha_busqueda2])->get()->count();
                $cantidad_enviado = Pqrs::where('estado', '4')->where("active","1")->whereBetween('fecha_recepcion',[$fecha_busqueda, $fecha_busqueda2])->get()->count();
                $cantidad_rechazados = Pqrs::where('estado', '5')->where("active","1")->whereBetween('fecha_recepcion',[$fecha_busqueda, $fecha_busqueda2])->get()->count();
                $total_pqrs = Pqrs::where("active","1")->whereBetween('fecha_recepcion',[$fecha_busqueda,$fecha_busqueda2])->get()->count();
                $pqr_vencido = Pqrs::where("active",1)->whereBetween('fecha_recepcion',[$fecha_busqueda,$fecha_busqueda2])->get();
                $pqr_apoyo = PeticionesApoyo::where("active",1)->whereBetween('created_at',[$fecha_busqueda,$fecha_busqueda2])->get()->count();
                //LINEA NUEVA
                foreach($pqr_vencido as $doc){
                    $fecha = new Carbon($doc->fecha_recepcion);
                    $tp_doc = TpDocumento::where("id", $doc->tp_doc)->first();
                    $flr = explode(' ', $pqrcontroller->getFiveDays($fecha, $tp_doc->dias_respuesta).'')[0];
                    $fecha_frl = new Carbon($flr);
                    $fecha_frl  = Carbon::parse($fecha_frl)->format('Y-m-d');
                    if($doc->estado ==4){
                        if($doc->fecha_respuesta > $fecha_frl){
                            $vencidos_con_respuestas = $vencidos_con_respuestas +1;
                        }
                    }else{
                        if(empty($doc->fecha_respuesta) &&   Carbon::now()->format('Y-m-d') > $fecha_frl ){
                            $vencidos_sin_respuestas = $vencidos_sin_respuestas + 1;
                       }
                    }
                }
            }else{
                $cantidad_ingreso = Pqrs::where('estado', '1')->where("active","1")->get()->count();
                $cantidad_estudio = Pqrs::where('estado', '2')->where("active","1")->get()->count();
                $cantidad_pendiente = Pqrs::where('estado', '3')->where("active","1")->get()->count();
                $cantidad_gestion = Pqrs::whereIn('estado', ['6','7'])->where("active","1")->get()->count();
                $cantidad_enviado = Pqrs::where('estado', '4')->where("active","1")->get()->count();
                $cantidad_rechazados = Pqrs::where('estado', '5')->where("active","1")->get()->count();
                $total_pqrs = Pqrs::where("active","1")->get()->count();
                $pqr_vencido = Pqrs::where("active",1)->get();
                $pqr_apoyo = PeticionesApoyo::where("active",1)->get()->count();
                //LINEA NUEVA
                foreach($pqr_vencido as $doc){
                    $fecha = new Carbon($doc->fecha_recepcion);
                    $tp_doc = TpDocumento::where("id", $doc->tp_doc)->first();
                    $flr = explode(' ', $pqrcontroller->getFiveDays($fecha, $tp_doc->dias_respuesta).'')[0];
                    $fecha_frl = new Carbon($flr);
                    $fecha_frl  = Carbon::parse($fecha_frl)->format('Y-m-d');
                    if($doc->estado ==4){
                        if($doc->fecha_respuesta > $fecha_frl){
                            $vencidos_con_respuestas = $vencidos_con_respuestas +1;
                        }
                    }else{
                        if(empty($doc->fecha_respuesta) &&   Carbon::now()->format('Y-m-d') > $fecha_frl ){
                            $vencidos_sin_respuestas = $vencidos_sin_respuestas + 1;
                       }
                    }
                }
            }
            if($total_pqrs > 0){
                /* CALCULA EL PORCENTAJE POR CADA ESTADO DEL PQRS */
                $porcentaje_ingresado = ($cantidad_ingreso * 100)/ $total_pqrs;
                $porcentaje_estudio = ($cantidad_estudio * 100)/ $total_pqrs;
                $porcentaje_pendiente = ($cantidad_pendiente * 100)/ $total_pqrs;
                $porcentaje_gestion = ($cantidad_gestion * 100)/ $total_pqrs;
                $porcentaje_enviado = ($cantidad_enviado * 100)/ $total_pqrs;
                $resultado_alcanzado_general =  ($cantidad_ingreso  +  $cantidad_estudio +  $cantidad_pendiente + $cantidad_gestion);
                $porcentaje_rechazados = ($cantidad_rechazados * 100)/$total_pqrs;
                $total_porcentaje_pqrs = ($porcentaje_ingresado +  $porcentaje_estudio  +  $porcentaje_gestion  + $porcentaje_pendiente +  $porcentaje_enviado +$porcentaje_rechazados );

                /* CALCULA EL RATIO */
                if($cantidad_ingreso>0 ){
                    $ratio_pqrs_comparacion_general = ($cantidad_enviado / $cantidad_ingreso ) * 100;
                }  else {
                    $ratio_pqrs_comparacion_general = 0;
                }
                /* CALCULA EL RATIO ingresos vs resueltos*/
                if($resultado_alcanzado_general>0 & $cantidad_ingreso>0 ) {
                    $ratio_pqrs = ($cantidad_enviado / $resultado_alcanzado_general ) * 100;
                } else if($resultado_alcanzado_general==0 && $cantidad_enviado >0 ){
                    $ratio_pqrs = ($cantidad_enviado / $cantidad_enviado ) * 100;
                }
                /* CALCULA EL RATIO rechazados vs ingresos  */
                if($cantidad_ingreso>0 ){
                    $ratio_enviado_rechazado = ($cantidad_rechazados /$resultado_alcanzado_general ) * 100;
                }  else {
                    $ratio_enviado_rechazado = 0;
                }
                /* CALCULA LA EFICACIA GENERAL*/
                if($cantidad_enviado >0 && $resultado_alcanzado_general >0 ){
                    $eficacia_general = ($resultado_alcanzado_general * 100) / ($total_pqrs);
                } else if($cantidad_enviado >0 && $resultado_alcanzado_general == 0){
                    $eficacia_general = ($cantidad_enviado * 100) / ($total_pqrs);
                } else{
                    $eficacia_general = 0;
                }
           
               $datos= [  
                        [                        
                            'cantidad_radicacion' => strval($cantidad_ingreso),
                            'cantidad_estudio'  => strval($cantidad_estudio),
                            'cantidad_gestion' => strval($cantidad_gestion),
                            'cantidad_pendiente' => strval($cantidad_pendiente),
                            'cantidad_enviado' => strval($cantidad_enviado),
                            'cantidad_reproceso' => strval($cantidad_rechazados) ,
                            'total_pqr' => strval($total_pqrs),
                            'total_pqr_apoyo' => strval($pqr_apoyo),
                            'vencidos_con_respuestas' => strval($vencidos_con_respuestas), 
                            'vencidos_sin_respuestas' => strval($vencidos_sin_respuestas), 
                            'porcentaje_radicacion' => strval(round($porcentaje_ingresado,2)),
                            'porcentaje_estudio' => strval(round($porcentaje_estudio,2)),
                            'porcentaje_gestion' => strval(round($porcentaje_gestion,2)),
                            'porcentaje_pendiente' => strval(round($porcentaje_pendiente,2)),
                            'porcentaje_enviado' => strval(round($porcentaje_enviado,2)),
                            'porcentaje_total' => strval(round($total_porcentaje_pqrs)),
                            'eficacia_general' => strval(round($eficacia_general , 2)),
                            'radicacion_vs_resueltos' => strval(round($ratio_pqrs,2)),
                            'enviados_vs_radicacion' => strval(round($ratio_pqrs_comparacion_general,2)),
                            'reproceso_vs_radicacion' => strval(round($ratio_enviado_rechazado,2))
                        ]
                    ];
            }else {
                    $datos = [[
                        'cantidad_radicacion' =>"0",
                        'cantidad_estudio'  =>"0",
                        'cantidad_gestion' =>"0",
                        'cantidad_pendiente' =>"0",
                        'cantidad_enviado' =>"0",   
                        'cantidad_reproceso' =>"0",
                        'total_pqr' =>"0",
                        'total_pqr_apoyo' =>"0",
                        'vencidos_con_respuestas' =>"0",
                        'vencidos_sin_respuestas' =>"0",
                        'porcentaje_radicacion' =>"0",
                        'porcentaje_estudio' =>"0",
                        'porcentaje_gestion' =>"0",
                        'porcentaje_pendiente' =>"0",
                        'porcentaje_enviado' =>"0",
                        'porcentaje_total' =>"0",
                        'eficacia_general' =>"0",
                        'radicacion_vs_resueltos' =>"0",
                        'enviados_vs_radicacion' =>"0",
                        'reproceso_vs_radicacion' =>"0"

                    ]];
            }
    
        } catch (\Exception $e) {
            $datos = $e->getMessage();   
        }
        LogController::guardarLog($modulo,$request,$datos);
        return collect($datos);
    }

}
