<?php

namespace App\Exports;
use App\Http\Controllers\LogController;
use App\Pqrs;
use Illuminate\Support\Facades\DB;
use Maatwebsite\Excel\Concerns\FromCollection;
use Maatwebsite\Excel\Concerns\Exportable;
use Maatwebsite\Excel\Concerns\WithHeadings;
use Maatwebsite\Excel\Events\AfterSheet;
use Maatwebsite\Excel\Concerns\WithEvents;
use Maatwebsite\Excel\Concerns\WithDrawings;
use Maatwebsite\Excel\Concerns\WithCustomStartCell;
use PhpOffice\PhpSpreadsheet\Worksheet\Drawing;

class PostExportEstadisticaUsuario implements FromCollection,WithCustomStartCell,WithHeadings, WithEvents,WithDrawings
{
    /**
    * @return \Illuminate\Support\Collection
    */
    protected $input;


    function __construct($input) {
        $this->input = $input;
    }
    public function startCell(): string
    {
        return 'A2';
    }
    public function drawings()
    {
        $drawing = new Drawing();
        $drawing->setName('LOGO');
        $drawing->setDescription('REPORTE ESTADISTICO DE PETICIONES PQR');
        $drawing->setPath(public_path('assets/images/xiltrion.png'));
        $drawing->setHeight(20);
        $drawing->setCoordinates('A1');
        return $drawing;
    }
    public function registerEvents(): array {
        
        return [
            AfterSheet::class => function(AfterSheet $event) {
                /** @var Sheet $sheet */
                $sheet = $event->sheet;
                $sheet->mergeCells('B1:F1');
                $sheet->setCellValue('B1', "REPORTE ESTADISTICO DE PETICIONES PQR");
                
                $styleArray = [
                    'alignment' => [
                        'horizontal' => \PhpOffice\PhpSpreadsheet\Style\Alignment::HORIZONTAL_CENTER,
                    ],
                ];
                $sheet->getStyle('A1:H1')->applyFromArray([
                    'font' => [
                        'bold' => true
                    ]
                ]);
                $sheet->getStyle('A2:H2')->applyFromArray([
                    'font' => [
                        'bold' => true
                    ]
                ]);
           
                $cellRange = 'A1:F1'; // All headers
                $event->sheet->getDelegate()->getStyle($cellRange)->applyFromArray($styleArray);
            },
        ];
    }
    public function headings(): array{
        return [
            "#",
            "USUARIO",
            "AREA",
            "CANTIDAD",
            "PORCENTAJE",
            "REPROCESOS",
            "EFICACIA",
            "PQR APOYO"
        ];
    }
    public function collection()
    {
        $modulo = 'ExportEstadisticaUsuario/query';
        $request = "Solicitud de reporte de estadisticas de usuario";
        $buscar = $this->input->buscar_datos;
        $fecha_busqueda = $this->input->fecha_buscar;
        $fecha_busqueda2 = $this->input->fecha_buscar2;
        try{
            if(!empty($fecha_busqueda) && !empty($fecha_busqueda2) && !empty( $buscar )){
                $datos_usuario_general= Pqrs::select('u.id', 'u.name as usuario','a.nombre as area',db::raw('SUM(p.active) cantidad, CONCAT( ROUND( ( COUNT(*)  / ( SELECT COUNT(*) FROM pqrs LIMIT 1) * 100 ),2 ), "%" ) AS porcentaje'),
                db::raw('SUM((select count(op.id) from observaciones_pqr op where op.id_pqr = p.id)) as rechazado '),
                db::raw('CONCAT( ROUND((( select COUNT(*) from pqrs pq where pq.usuario_asignado  = u.id  and pq.estado =4 )* 100) / ( SELECT COUNT(*) FROM pqrs pqs where pqs.usuario_asignado = u.id  LIMIT 1),2 ), "%" ) as eficacia'),
                db::raw('(SELECT count(*) from pqrs_peticiones_apoyo ppa where ppa.id_user = u.id) as pqr_apoyo'))
                ->from('pqrs as p')
                ->join('users as u', 'u.id', '=', 'p.usuario_asignado')
                ->join('area as a', 'a.id', '=', 'p.area')
                ->whereBetween('p.fecha_recepcion',[ $fecha_busqueda ,$fecha_busqueda2 ])
                ->where(function($query) use ($buscar){
                    $query->where('u.name','LIKE', '%' . $buscar . '%')
                    ->orWhere('a.nombre','LIKE', '%' . $buscar . '%');              
                })
                ->groupBy('u.id','u.name','a.nombre')->get();
            }
            else if(!empty($fecha_busqueda) && !empty($fecha_busqueda2)){
                $datos_usuario_general= Pqrs::select('u.id', 'u.name as usuario','a.nombre as area',db::raw('SUM(p.active) cantidad, CONCAT( ROUND( ( COUNT(*)  / ( SELECT COUNT(*) FROM pqrs LIMIT 1) * 100 ),2 ), "%" ) AS porcentaje'),
                db::raw('SUM((select count(op.id) from observaciones_pqr op where op.id_pqr = p.id)) as rechazado '),
                db::raw('CONCAT( ROUND((( select COUNT(*) from pqrs pq where pq.usuario_asignado  = u.id  and pq.estado =4 )* 100) / ( SELECT COUNT(*) FROM pqrs pqs where pqs.usuario_asignado = u.id  LIMIT 1),2 ), "%" ) as eficacia'),
                db::raw('(SELECT count(*) from pqrs_peticiones_apoyo ppa where ppa.id_user = u.id) as pqr_apoyo'))
                ->from('pqrs as p')
                ->join('users as u', 'u.id', '=', 'p.usuario_asignado')
                ->join('area as a', 'a.id', '=', 'p.area')
                ->whereBetween('p.fecha_recepcion',[ $fecha_busqueda ,$fecha_busqueda2 ])
                ->groupBy('u.id','u.name','a.nombre')->get();
            }
            else if(!empty($buscar )  && empty($fecha_busqueda) || is_null($fecha_busqueda )){
                $datos_usuario_general= Pqrs::select('u.id', 'u.name as usuario','a.nombre as area',db::raw('SUM(p.active) cantidad, CONCAT( ROUND( ( COUNT(*)  / ( SELECT COUNT(*) FROM pqrs LIMIT 1) * 100 ),2 ), "%" ) AS porcentaje'),
                db::raw('SUM((select count(op.id) from observaciones_pqr op where op.id_pqr = p.id)) as rechazado '),
                db::raw('CONCAT( ROUND((( select COUNT(*) from pqrs pq where pq.usuario_asignado  = u.id  and pq.estado =4 )* 100) / ( SELECT COUNT(*) FROM pqrs pqs where pqs.usuario_asignado = u.id  LIMIT 1),2 ), "%" ) as eficacia'),
                db::raw('(SELECT count(*) from pqrs_peticiones_apoyo ppa where ppa.id_user = u.id) as pqr_apoyo'))
                ->from('pqrs as p')
                ->join('users as u', 'u.id', '=', 'p.usuario_asignado')
                ->join('area as a', 'a.id', '=', 'p.area')
                ->Where('u.name', 'LIKE', '%' . $buscar. '%')
                ->OrWhere('a.nombre', 'LIKE', '%' .$buscar. '%')
                ->groupBy('u.id','u.name','a.nombre')->get();
            }else{
                $datos_usuario_general= Pqrs::select('u.id', 'u.name as usuario','a.nombre as area',db::raw('SUM(p.active) cantidad, CONCAT( ROUND( ( COUNT(*)  / ( SELECT COUNT(*) FROM pqrs LIMIT 1) * 100 ),2 ), "%" ) AS porcentaje'),
                db::raw('SUM((select count(op.id) from observaciones_pqr op where op.id_pqr = p.id)) as rechazado '),
                db::raw('CONCAT( ROUND((( select COUNT(*) from pqrs pq where pq.usuario_asignado  = u.id  and pq.estado =4 )* 100) / ( SELECT COUNT(*) FROM pqrs pqs where pqs.usuario_asignado = u.id  LIMIT 1),2 ), "%" ) as eficacia'),
                db::raw('(SELECT count(*) from pqrs_peticiones_apoyo ppa where ppa.id_user = u.id) as pqr_apoyo'))
                ->from('pqrs as p')
                ->join('users as u', 'u.id', '=', 'p.usuario_asignado')
                ->join('area as a', 'a.id', '=', 'p.area')
                ->groupBy('u.id','u.name','a.nombre')->get();
            }

        } catch (\Exception $e) {
            $datos_usuario_general = $e->getMessage();   
        }
        LogController::guardarLog($modulo,$request,$this->input ,$datos_usuario_general);
        return collect($datos_usuario_general);
    }
}
