<?php

namespace App\Exports;
use App\Http\Controllers\LogController;
use App\Pqrs;
use App\PeticionesApoyo;
use App\ObservacionesPqr;
use App\TpDocumento;
use Carbon\Carbon;
use App\Http\Controllers\PQRController;
use Maatwebsite\Excel\Concerns\FromCollection;
use Maatwebsite\Excel\Concerns\FromQuery;
use Maatwebsite\Excel\Concerns\Exportable;
use Maatwebsite\Excel\Concerns\WithHeadings;
use Maatwebsite\Excel\Events\AfterSheet;
use Maatwebsite\Excel\Concerns\WithEvents;
use Maatwebsite\Excel\Concerns\WithDrawings;
use Maatwebsite\Excel\Concerns\WithCustomStartCell;
use PhpOffice\PhpSpreadsheet\Worksheet\Drawing;


class PostExportEstadisticasHome implements  FromCollection,WithCustomStartCell,WithHeadings, WithEvents,WithDrawings
{
    /**
    * @return \Illuminate\Support\Collection
    */
    use Exportable;
    protected $input;


    function __construct($input) {
        $this->input = $input;
    }
    public function startCell(): string
    {
        return 'A2';
    }
    public function headings(): array{
        return [
            'CANTIDAD EN RADICACION',
            'CANTIDAD ESTUDIO',
            'CANTIDAD GESTION',
            'CANTIDAD PENDIENTE',
            'CANTIDAD ENVIADO',
            'CANTIDAD REPROCESO',
            'TOTAL PQR',
            'TOTAL PQR APOYO',
            'VENCIDOS CON RESPUESTA',
            'VENCIDOS SIN RESPUESTA',
            'PORCENTAJE EN RADICACION',
            'PORCENTAJE ESTUDIO',
            'PORCENTAJE GESTION',
            'PORCENTAJE PENDIENTE',
            'PORCENTAJE ENVIADO',
            'PORCENTAJE TOTAL',
            'EFICACIA GENERAL',
            'EN RADICACION VS RESUELTOS [0 - 100 %]',
            'ENVIADOS / EN RADICACION',
            'REPROCESOS VS EN RADICACION',
        ];
    }

    public function drawings()
    {
        $drawing = new Drawing();
        $drawing->setName('LOGO');
        $drawing->setDescription('REPORTE ESTADISTICO DE PETICIONES PQR');
        $drawing->setPath(public_path('assets/images/xiltrion.png'));
        $drawing->setHeight(20);
        $drawing->setCoordinates('D1');
        return $drawing;
    }
    public function registerEvents(): array {
        
        return [
            AfterSheet::class => function(AfterSheet $event) {
                /** @var Sheet $sheet */
                $sheet = $event->sheet;
                $sheet->mergeCells('B1:T1');
                $sheet->setCellValue('B1', "REPORTE ESTADISTICO DE PETICIONES PQR");
                
                $styleArray = [
                    'alignment' => [
                        'horizontal' => \PhpOffice\PhpSpreadsheet\Style\Alignment::HORIZONTAL_CENTER,
                    ],
                ];
                $sheet->getStyle('A1:T1')->applyFromArray([
                    'font' => [
                        'bold' => true
                    ]
                ]);
                $sheet->getStyle('A2:T2')->applyFromArray([
                    'font' => [
                        'bold' => true
                    ]
                ]);

                
                $cellRange = 'A1:T1'; // All headers
                $cell_header_range = 'A2:T2';
                $event->sheet->getDelegate()->getStyle($cellRange)->applyFromArray($styleArray);
                $event->sheet->getDelegate()->getStyle($cell_header_range)->applyFromArray($styleArray);
            },
        ];
    }


    public function collection()
    {   
        $modulo = 'ExportEstadisticaHome/query';
        $request = "Solicitud de reporte de estadisticas generales";
        $datos = [];
        $vencidos_sin_respuestas = 0;
        $vencidos_con_respuestas = 0;
        $ratio_pqrs = 0;
        $pqrcontroller = new PQRController();
        try{
            $cantidad_ingreso = Pqrs::where('estado', '1')->where("usuario_asignado",Auth()->id())->where("active","1")->get()->count();
            $cantidad_estudio = Pqrs::where('estado', '2')->where("usuario_asignado",Auth()->id())->where("active","1")->get()->count();
            $cantidad_gestion = Pqrs::whereIn('estado', ['6','7'])->where("usuario_asignado",Auth()->id())->where("active","1")->get()->count();
            $cantidad_pendiente = Pqrs::where('estado', '3')->where("usuario_asignado",Auth()->id())->where("active","1")->get()->count();
            $cantidad_enviado = Pqrs::where('estado', '4')->where("usuario_asignado",Auth()->id())->where("active","1")->get()->count();
            $cantidad_rechazados = Pqrs::where('estado', '5')->where("usuario_asignado",Auth()->id())->where("active","1")->get()->count();  
            $total_pqrs = Pqrs::where("active","1")->where("usuario_asignado",Auth()->id())->get()->count();
            $pqr_vencido = Pqrs::where("active",1)->where("usuario_asignado",Auth()->id())->get();
            $pqr_apoyo = PeticionesApoyo::where("active",1)->where("id_user",Auth()->id())->get()->count();
            //LINEA NUEVA
            foreach($pqr_vencido as $doc){
                $fecha = new Carbon($doc->fecha_recepcion);
                $tp_doc = TpDocumento::where("id", $doc->tp_doc)->first();
                $flr = explode(' ', $pqrcontroller->getFiveDays($fecha, $tp_doc->dias_respuesta).'')[0];
                $fecha_frl = new Carbon($flr);
                $fecha_frl  = Carbon::parse($fecha_frl)->format('Y-m-d');
                if($doc->estado ==4){
                    if($doc->fecha_respuesta > $fecha_frl){
                        $vencidos_con_respuestas = $vencidos_con_respuestas +1;
                    }
                }else{
                    if(empty($doc->fecha_respuesta) &&   Carbon::now()->format('Y-m-d') > $fecha_frl ){
                        $vencidos_sin_respuestas = $vencidos_sin_respuestas + 1;
                   }
                }
            }
            
            if($total_pqrs > 0){
                /* CALCULA EL PORCENTAJE POR CADA ESTADO DEL PQRS */
                $porcentaje_ingresado = ($cantidad_ingreso * 100)/ $total_pqrs;
                $porcentaje_estudio = ($cantidad_estudio * 100)/ $total_pqrs;
                $porcentaje_pendiente = ($cantidad_pendiente * 100)/ $total_pqrs;
                $porcentaje_gestion = ($cantidad_gestion * 100)/ $total_pqrs;
                $porcentaje_enviado = ($cantidad_enviado * 100)/ $total_pqrs;
                $resultado_alcanzado_general =  ($cantidad_ingreso  +  $cantidad_estudio +  $cantidad_pendiente + $cantidad_gestion);
                $porcentaje_rechazados = ($cantidad_rechazados * 100)/$total_pqrs;
                $total_porcentaje_pqrs = ($porcentaje_ingresado +  $porcentaje_estudio  +  $porcentaje_gestion  + $porcentaje_pendiente +  $porcentaje_enviado +$porcentaje_rechazados );

                /* CALCULA EL RATIO */
                if($cantidad_ingreso>0 ){
                    $ratio_pqrs_comparacion_general = ($cantidad_enviado / $cantidad_ingreso ) * 100;
                }  else {
                    $ratio_pqrs_comparacion_general = 0;
                }
                /* CALCULA EL RATIO ingresos vs resueltos*/
                if($resultado_alcanzado_general>0 & $cantidad_ingreso>0 ) {
                    $ratio_pqrs = ($cantidad_enviado / $resultado_alcanzado_general ) * 100;
                } else if($resultado_alcanzado_general==0 && $cantidad_enviado >0 ){
                    $ratio_pqrs = ($cantidad_enviado / $cantidad_enviado ) * 100;
                }
                /* CALCULA EL RATIO rechazados vs ingresos  */
                if($cantidad_ingreso>0 ){
                    $ratio_enviado_rechazado = ($cantidad_rechazados /$resultado_alcanzado_general ) * 100;
                }  else {
                    $ratio_enviado_rechazado = 0;
                }
                /* CALCULA LA EFICACIA GENERAL*/
                if($cantidad_enviado >0 && $resultado_alcanzado_general >0 ){
                    $eficacia_general = ($resultado_alcanzado_general * 100) / ($total_pqrs);
                } else if($cantidad_enviado >0 && $resultado_alcanzado_general == 0){
                    $eficacia_general = ($cantidad_enviado * 100) / ($total_pqrs);
                } else{
                    $eficacia_general = 0;
                }
                    $datos = [
                        [
                            'CANTIDAD EN RADICACION' => strval($cantidad_ingreso),
                            'CANTIDAD ESTUDIO' => strval($cantidad_estudio),
                            'CANTIDAD GESTION' => strval($cantidad_gestion),
                            'CANTIDAD PENDIENTE' => strval($cantidad_pendiente),
                            'CANTIDAD ENVIADO' => strval($cantidad_enviado),
                            'CANTIDAD REPROCESO' => strval($cantidad_rechazados) ,
                            'TOTAL PQR' => strval($total_pqrs),
                            'TOTAL PQR APOYO' => strval($pqr_apoyo),
                            'VENCIDOS CON RESPUESTA' => strval($vencidos_con_respuestas),
                            'VENCIDOS SIN RESPUESTA' => strval($vencidos_sin_respuestas),
                            'PORCENTAJE EN RADICACION' => strval(round($porcentaje_ingresado,2)),
                            'PORCENTAJE ESTUDIO' => strval(round($porcentaje_estudio,2)),
                            'PORCENTAJE GESTION' => strval(round($porcentaje_gestion,2)),
                            'PORCENTAJE PENDIENTE' => strval(round($porcentaje_pendiente,2)),
                            'PORCENTAJE ENVIADO' => strval(round($porcentaje_enviado,2)),
                            'PORCENTAJE TOTAL' => strval(round($total_porcentaje_pqrs)),
                            'EFICACIA GENERAL' => strval(round($eficacia_general , 2)),
                            'EN RADICACION VS RESUELTOS [0 - 100 %]' => strval(round($ratio_pqrs,2)),
                            'ENVIADOS / EN RADICACION' => strval(round($ratio_pqrs_comparacion_general,2)),
                            'REPROCESOS VS EN RADICACION' => strval(round($ratio_enviado_rechazado,2))
                        ]
                    ];

                    
            }else {
                $datos = [[
                    'CANTIDAD EN RADICACION' =>"0",
                    'CANTIDAD ESTUDIO' =>"0",
                    'CANTIDAD GESTION' =>"0",
                    'CANTIDAD PENDIENTE' =>"0",
                    'CANTIDAD ENVIADO' =>"0",   
                    'CANTIDAD REPROCESO' =>"0",
                    'TOTAL PQR' =>"0",
                    'TOTAL PQR APOYO' =>"0",
                    'VENCIDOS CON RESPUESTA' =>"0",
                    'VENCIDOS SIN RESPUESTA' =>"0",
                    'PORCENTAJE EN RADICACION' =>"0",
                    'PORCENTAJE ESTUDIO' =>"0",
                    'PORCENTAJE GESTION' =>"0",
                    'PORCENTAJE PENDIENTE' =>"0",
                    'PORCENTAJE ENVIADO' =>"0",
                    'PORCENTAJE TOTAL' =>"0",
                    'EFICACIA GENERAL' =>"0",
                    'EN RADICACION VS RESUELTOS [0 - 100 %]' =>"0",
                    'ENVIADOS / EN RADICACION' =>"0",
                    'REPROCESOS VS EN RADICACION' =>"0"

                ]];
            }
        } catch (\Exception $e) {
            $datos = $e->getMessage();   
        }
        LogController::guardarLog($modulo,$request,$datos);
        return collect($datos);
    }

}
