<?php

namespace App\Exports;

use App\RegistrosCatastro;

use Illuminate\Support\Facades\DB;
    
use Maatwebsite\Excel\Concerns\FromQuery;

use Maatwebsite\Excel\Concerns\Exportable;

use Maatwebsite\Excel\Concerns\WithHeadings;

class PostsExportPersonalizado implements FromQuery, WithHeadings
{
    /**
    * @return \Illuminate\Support\Collection
    */
    
    use Exportable;

    protected $input;
    protected $years_inicio;
    protected $years_fin;

    function __construct($input, $years_inicio, $years_fin) {
        $this->input = $input;
        $this->years_inicio = $years_inicio;
        $this->years_fin = $years_fin;
    }

    public function query() {
        if($this->years_fin == 0){
            $data = RegistrosCatastro::select('predios.numero_predio', 'predios.matricula_inmobiliaria', 'persona.nombre_completo','persona.numero_identificacion','predios.direccion_predio','registros_catastro.vigencia',DB::raw('FORMAT(registros_catastro.avaluo, 2) as avaluo'),'tarifas.valor_tarifa',DB::raw('FORMAT(((registros_catastro.avaluo*tarifas.valor_tarifa)/1000), 2) as vpagar'),DB::raw('(CASE WHEN registros_catastro.pagado = 1 THEN "PAGADO" ELSE "NO PAGADO" END)'))
            ->join('predios', 'registros_catastro.id_predio', '=', 'predios.id')
            ->join('usuarios', 'registros_catastro.id_usuario', '=', 'usuarios.id')
            ->join('persona', 'usuarios.id_persona', '=', 'persona.id')
            ->join('tarifas', 'registros_catastro.id_tarifa', '=', 'tarifas.id')
            ->where('registros_catastro.eliminado', '0')
            ->where('persona.eliminado', '0')
            ->where('registros_catastro.pagado', $this->input)
            ->where('registros_catastro.vigencia', 'LIKE', $this->years_inicio.'%')
            ->orderBy('predios.matricula_inmobiliaria', 'ASC')
            ->orderBy('registros_catastro.vigencia', 'DESC');
        }else{
            $data = RegistrosCatastro::select('predios.numero_predio', 'predios.matricula_inmobiliaria', 'persona.nombre_completo','persona.numero_identificacion','predios.direccion_predio','registros_catastro.vigencia',DB::raw('FORMAT(registros_catastro.avaluo, 2) as avaluo'),'tarifas.valor_tarifa',DB::raw('FORMAT(((registros_catastro.avaluo*tarifas.valor_tarifa)/1000), 2) as vpagar'),DB::raw('(CASE WHEN registros_catastro.pagado = 1 THEN "PAGADO" ELSE "NO PAGADO" END)'))
            ->join('predios', 'registros_catastro.id_predio', '=', 'predios.id')
            ->join('usuarios', 'registros_catastro.id_usuario', '=', 'usuarios.id')
            ->join('persona', 'usuarios.id_persona', '=', 'persona.id')
            ->join('tarifas', 'registros_catastro.id_tarifa', '=', 'tarifas.id')
            ->where('registros_catastro.eliminado', '0')
            ->where('persona.eliminado', '0')
            ->where('registros_catastro.pagado', $this->input)
            ->whereBetween('registros_catastro.vigencia', [$this->years_inicio."-01-01", $this->years_fin."-01-01"])
            ->orderBy('predios.matricula_inmobiliaria', 'ASC')
            ->orderBy('registros_catastro.vigencia', 'DESC');
        }
        
        return $data;
    }
    
    public function headings(): array{
        return [
            'NUMERO_DEL_PREDIO',
            'MATRICULA_INMOBILIARIA',
            'NOMBRE',
            'NUMERO_DOCUMENTO',
            'DIRECCION',
            'VIGENCIA',
            'AVALUO',
            'TARIFA',
            'VALOR A PAGAR',
            'ESTADO'
        ];
    }
}
