<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;

use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Storage;
use League\Csv\Writer;

use Flash;

class ExportCSVController extends Controller
{

    public function export($tableType)
    {
        $locationType = 'barrio';
        $areaType = 'areaterreno';
        $areaType2 = 'areaconstruccion';
        $valueAreaType = 'AREA_TERRENO';
        $valueAreaType2 = 'AREA_CONSTRUCCION';
        $offerValue = 'VALOR_DE_LA_OFERTA';

        if ($tableType === 'ph') {
            $areaType = 'areaconstruida';
            $areaType2 = 'areaprivada';
            $valueAreaType = 'AREA_CONSTRUIDA_M2';
            $valueAreaType2 = 'AREA_PRIVADA_M2';
            $offerValue = 'VALOR_OFERTA_VENTA';
        } elseif ($tableType === 'rural') {
            $locationType = 'vereda';
            $areaType = 'areaconstruida';
            $areaType2 = 'areaterreno';
        }

        // Consulta SQL para obtener datos de la base de datos
        $results = DB::connection('mysql')->table("ofertas{$tableType}s")->get();

        // Verificar si hay datos
        if ($results->isEmpty()) {
            Flash::message('There is no data to export.');
            return redirect(route("ofertas{$tableType}s.index"));
        }

        // Convertir los resultados a formato CSV
        $csv = Writer::createFromString('');

        $csv->insertOne([
            'Id', 'Propiedad1', 'Valor1', 'Propiedad2', 'Valor2', 'GeometriaTipo', 'GeometriaLng1', 'GeometriaLat1',
            'Propiedad3', 'Valor3', 'Propiedad4', 'Valor4', 'Propiedad5', 'Valor5', 'Propiedad6', 'Valor6'
        ]);

        foreach ($results as $index => $row) {
            $rowData = [
                $index + 1,
                strtoupper($locationType),
                $row->NOMBRE_BARRIO,
                'TIPOOFERTA',
                ($row->VALOR_ARRIENDO && is_string($row->VALOR_ARRIENDO)) ? (trim($row->VALOR_ARRIENDO) === '' ? 'VENTA' : 'ARRIENDO') : 'VENTA',
                'PUNTO',
                $row->LONGITUD,
                $row->LATITUD,
                'DIRECCION',
                $row->DIRECCION,
                'VALORVENTA',
                ($row->VALOR_ARRIENDO && is_string($row->VALOR_ARRIENDO)) ? (trim($row->VALOR_ARRIENDO) === '' ? $row->{$offerValue} : $row->VALOR_ARRIENDO) : $row->{$offerValue},
                strtoupper($areaType),
                $row->{$valueAreaType},
                strtoupper($areaType2),
                $row->{$valueAreaType2},
            ];

            $csv->insertOne($rowData);
        }

        // Guardar el CSV en el sistema de archivos de Laravel
        $filePath = "generate{$tableType}.csv";
        Storage::put($filePath, $csv->getContent());

        // Devolver una respuesta de descarga
        return response()->download(storage_path("app/{$filePath}"))->deleteFileAfterSend(true);
    }
}
