<?php
namespace App\Http\Controllers;

use App;
use App\TpDocumento;
use App\Area;
use App\Ciudad;
use App\User;
use App\Departamento;
use App\Juzgados;
use App\FormatosTipoDocs;
use App\Pqrs;
use App\ProyectoresTipoDocs;
use App\Rules\HasNumber;
use App\Entidad;
use App\TipoUser;
use App\AreaNiveles;
use App\ParametrosPqr;
use App\ValorParametrosPqr;
use Illuminate\Support\Facades\DB;
use Illuminate\Pagination\Paginator;
use Illuminate\Support\Facades\Input;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Session;
use Illuminate\Pagination\LengthAwarePaginator;
use Illuminate\Support\Collection;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Validator;
use App\Rules\Mixedcase;
use App\Rules\Symbols;
use PragmaRX\Google2FA\Google2FA;
use Barryvdh\DomPDF\Facade as PDF;
use LynX39\LaraPdfMerger\PdfManage;
use Illuminate\Support\Facades\Cache;

class ParametrizacionController extends Controller
{
    public function listTipoDocumento()
    {
        $perPage = 20;
        $page = Input::get('page') ;
        $pageName = 'page';
        $page = Paginator::resolveCurrentPage($pageName);
        $offSet = ($page * $perPage) - $perPage;
        $documento = TpDocumento::where('active', '1')->offset($offSet)->limit($perPage)->orderBy('orden','ASC')->get();
        $countdocs = TpDocumento::where('active', '1')->get();
        $flag = false;

        if (Input::get('search')) {
            $input = Input::get('search');
            $documento = TpDocumento::where('nombre', 'LIKE', '%'.$input.'%')->where('active', '1')->get();
            $flag = true;
        }

        $array = [];
        $collection = null;
        $total_registros = 1;
        foreach ($documento as $doc) {
            array_push($array, (object)array(
                'id' => $doc->id,
                'nombre' => $doc->nombre,
                'formatoemail' => $doc->formatoemail,
                'active' => $doc->active,
                'dias_respuesta' => $doc->dias_respuesta,
                'sin_respuesta' => $doc->sin_respuesta
            ));

            $total_registros = $total_registros + 1;
        }

        $collection = new Collection($array);

        $posts = new LengthAwarePaginator($collection, count($countdocs), $perPage, $page, [
            'path' => Paginator::resolveCurrentPath(),
            'pageName' => $pageName
        ]);

        return view('parametros.tipodocumento', ['documento' => $posts, 'flag' => $flag])->withPosts($posts);
    }

    public function guardarTipoDocumento(Request $request)
    {
        $modulo = "ParametrizacionController/GuardarTipoDocumento";
        try {
            $last_id = 0;
            $last_orden =0;
            $pqr = new TpDocumento();
            $tpDoc = TpDocumento::all()->last();
            if (is_null($tpDoc)){
                $last_id = 1;
                $last_orden =1;
            }else{
                $last_id = $tpDoc->id + 1;
                $last_orden = $tpDoc->orden + 1;
            }
            if (!is_null( $request->nombre) || !empty( $request->nombre)){
                $pqr->nombre = $request->nombre;
                $pqr->dias_respuesta = $request->dias_respuesta;
                $pqr->ruta = '/PQRS/index/'.$last_id;
                $pqr->orden = $last_orden;
                $pqr->formatoemail = $request->formatoemail;
                $pqr->sin_respuesta = $request->sin_respuesta == null ? 0 : 1;
                $pqr->save();

                Session::put('success', 'Tipo de documento guardado exitosamente!');
                $response = 'Tipo de documento guardado exitosamente!';
            } else {
                Session::put('error', 'Se produjo un error de validación');
                $response = 'Se produjo un error de validación';
            }
        } catch (\Exception $e) {
            Session::put('error', 'Se produjo un error al guardar el documento');
            $response = $e->getMessage();
        }
        LogController::guardarLog($modulo, $request, $request->all(), $response);
        return redirect()->route('parametros.tipodocumento');
    }

    public function actualizarTipoDocumento(Request $request)
    {    
        $modulo = "ParametrizacionController/actualizarTipoDocumento";
        try {
            $pqr = TpDocumento::where('id', $request->id)->first();
            if (!is_null( $request->nombre) || !empty( $request->nombre) || !is_null( $request->active) || !empty($request->active)){
                $pqr->nombre = $request->nombre;
                $pqr->dias_respuesta = $request->dias_respuesta;
                $pqr->formatoemail = $request->formatoemail;
                $pqr->active = $request->active;
                $pqr->sin_respuesta = $request->sin_respuesta;
                $pqr->save();
                Session::put('success', 'Tipo de documento actualizado exitosamente!');
                $response = 'Tipo de documento actualizado exitosamente!';
            } else {
                Session::put('error', 'Se produjo un error de validación');
                $response ='Se produjo un error de validación';
            }
        } catch (\Exception $e) {
            Session::put('error', 'Se produjo un error al actualizar.');
            $response = $e->getMessage();
        }
        LogController::guardarLog($modulo, $request, $request->all(), $response);
        return redirect()->route('parametros.tipodocumento');
    }

    public function listarArea(){
        $perPage = 20;
        $page = Input::get('page');
        $pageName = 'page';
        $page = Paginator::resolveCurrentPage($pageName);
        $offSet = ($page * $perPage) - $perPage;
        $area = Area::offset($offSet)->limit($perPage)->orderBy('nombre','ASC')->get();
        $tipousuarios = TipoUser::where('active', '1')->get();
        $flag = false;

        $cant_users = User::select(DB::raw('count(*) as cant_users'), 'id_area')->where('active', '1')->groupBy('id_area')->get();

        if (Input::get('search')) {
            $input = Input::get('search');
            $area = Area::where('nombre', 'LIKE', '%'.$input.'%')->offset($offSet)->limit($perPage)->orderBy('nombre','ASC')->get();
            $flag = true;
        }

        $array = [];
        $collection = null;
        $total_registros = 1;

        foreach($area as $arr) {
            $usuarios_firma = User::where('id_area', $arr->id)->whereIn('id_tipo_usuario', [1, 2])->get();
            $areaniveles = AreaNiveles::where('id_area', $arr->id)->where('active', '1')->get();

            $count = 0;
            foreach($cant_users as $cant) {
                if ($arr->id == $cant->id_area) {
                    $count = $cant->cant_users;
                }
            }

            $sw = 0;
            foreach($areaniveles as $arrniv) {
                $sw = 1;
            }

            $array_niveles = [];
            if($sw == 1){
                foreach($areaniveles as $arrniv) {
                    array_push($array_niveles, $arrniv->id_tipo_usuario);
                }
            }

            array_push($array,(object)array(
                'id' => $arr->id,
                'id_usuario_firma' => $arr->id_usuario_firma,
                'nombre' => $arr->nombre,
                'active'=> $arr->active,
                'count'=> $count,
                'usuarios_firma' => $usuarios_firma,
                'areaniveles' => $array_niveles
            ));

            $total_registros = $total_registros + 1;
        }

        $collection = new Collection($array);

        $posts = new LengthAwarePaginator($collection,$total_registros, $perPage, $page, [
            'path' => Paginator::resolveCurrentPath(),
            'pageName' => $pageName
        ]);
        
        return view('parametros.area', ['documento' => $posts, 'flag' => $flag, 'tipousuarios' => $tipousuarios])->withPosts($posts);
    }

    public function guardarArea(Request $request){
        $modulo = "ParametrizacionController/guardarArea";
        try{
            $area = new Area();
            $nombre_area = Area::where('nombre', $request->nombre)->get();
            if(count($nombre_area) == 0){
                if (!is_null( $request->nombre) || !empty( $request->nombre)){
                    $area->nombre = $request->nombre;
                    $area->save();

                    if ($request->has('tipousers')) {
                        foreach ($request->get('tipousers') as $tpusers) {
                            $nuevosniveles = new AreaNiveles();
                            $nuevosniveles->id_area = $area->id;
                            $nuevosniveles->id_tipo_usuario = $tpusers;
                            $nuevosniveles->save();
                        }
                    }

                    Session::put('success', 'Área guardada exitosamente! Recuerde que el siguiente paso es parametrizar usuarios según el área registrada.');
                    $response = 'Área guardada exitosamente!';
                
                } else {
                    Session::put('error', 'Se produjo un error de validación');
                    $response = 'Se produjo un error de validación';
                }
            } else{
                Session::put('error', 'ya existe una Área con ese nombre');
                $response = 'ya existe una Área con ese nombre';
            }  
        }catch(\Exception $e){
            Session::put('error', 'Se produjo un error al guardar el area');
            $response = $e->getMessage();
        }
        LogController::guardarLog($modulo, $request, $request->all(), $response);
        return redirect()->route('parametros.area');
    }

    public function actualizarArea(Request $request)
    {      
        $modulo = "ParametrizacionController/actualizarArea";
        try {
            $area = Area::where('id', $request->id)->first();
            if (!is_null( $request->active) || !empty($request->active)){
                $area->active = $request->active;
                $area->save();
                Session::put('success', 'Área actualizada exitosamente!');
                $response = 'Área actualizada exitosamente!';
            } else {
                Session::put('error', 'Se produjo un error de validación');
                $response = 'Se produjo un error de validación';
            }       
        }catch (\Exception $e) {
            Session::put('error', 'Se produjo un error al actualizar.');
            $response = $e->getMessage();
         }
        LogController::guardarLog($modulo, $request, $request->all(), $response);
        return redirect()->route('parametros.area');
    }

    public function editarNivelesArea(Request $request)
    {
        $area = Area::where('id', $request->id)->first();
        $area->nombre = $request->nombre;
        $area->save();

        if ($request->has('tipousersedit')) {
            $tpniveles = DB::table('area_niveles')->where('id_area', '=', $request->id)->delete();
            foreach ($request->get('tipousersedit') as $tpusers) {
                $nuevosniveles = new AreaNiveles();
                $nuevosniveles->id_area = $area->id;
                $nuevosniveles->id_tipo_usuario = $tpusers;
                $nuevosniveles->save();
            }
        }else{
            $tpniveles = DB::table('area_niveles')->where('id_area', '=', $request->id)->delete();
        }

        Session::put('success', 'Área actualizada exitosamente!');
        return redirect()->route('parametros.area');
    }

    public function EditartipoDocFormatos($tipodocs, Request $request){
        $formatos = FormatosTipoDocs::where('id_tipodoc', $tipodocs)->where('active', '1')->get();
        $tipodoc = TpDocumento::where('id', $tipodocs)->where('active', '1')->first();
        $entidad = DB::table('entidad')->first();
        $flag = false;
        $nombre_formato = '';
        $header = '';
        $body = '';
        $footer = '';
        
        if($request->tipoforms != 0){
            $formato = FormatosTipoDocs::where('id', $request->tipoforms)->first();

            $nombre_formato = $formato->nombre;
            $header = $formato->header;
            $body = $formato->body;
            $footer = $formato->footer;
            $flag = true;
        }

        return view('parametros.editartipodocumento', [
            'formatos' => $formatos, 
            'id_tipodoc' => $tipodocs,
            'imgHeader' => asset($entidad->imagen_header),
            'imgFooter' => asset($entidad->imagen_footer),
            'nombrEntidad' => $entidad->nombre,
            'flag' => $flag,
            'id_tipoforms' => $request->tipoforms,
            'nombre_formato' => $nombre_formato,
            'header' => $header,
            'body' => $body,
            'footer' => $footer,
            'nombretipodoc' => $tipodoc->nombre
        ]);
    }

    public function GuardartipoDocFormatos(Request $request){
        if($request->id_tipoforms == 0){
            $formatos = new FormatosTipoDocs();
            $formatos->id_tipodoc = $request->id_tipodoc;
            $formatos->nombre = $request->nombre_formato;
            $formatos->header = $this->resolveURLimg($request->header);
            $formatos->body = $request->body;
            $formatos->footer = $this->resolveURLimg($request->footer);
            $formatos->save();
    
            \Session::flash('status', 'Formato de respuesta registrado correctamente.');
        }else{
            $formatos = FormatosTipoDocs::findOrFail($request->id_tipoforms);
            $formatos->nombre = $request->nombre_formato;
            $formatos->header = $this->resolveURLimg($request->header);
            $formatos->body = $request->body;
            $formatos->footer = $this->resolveURLimg($request->footer);
            $formatos->save();
    
            \Session::flash('status', 'Formato de respuesta actualizado correctamente.');
        }

        return redirect()->route('parametros.editartipoDocFormatos', $request->id_tipodoc);
    }

    public function AsignarClave(Request $request){
        // $municipio = MunicipioSabanalarga::first();
        // $clave_ = str_replace(" ", "",$request->clave_firma);
        // $new_hash = password_hash($clave_, PASSWORD_BCRYPT, ['cost' => 4]);
        // $municipio->clave_firma = $new_hash;
        // $municipio->cambiado = 1;
        // $municipio->save();

        return view('formularioingreso.respuesta');
    }

    public function listarJuzgados()
    {
        $perPage = 15;
        $page = Input::get('page') ;
        $pageName = 'page';
        $page = Paginator::resolveCurrentPage($pageName);
        $offSet = ($page * $perPage) - $perPage;
        $documento = Juzgados::offset($offSet)->limit($perPage)->orderBy('id','ASC')->get();
        $juzgados = Juzgados::where('active',1)->get();
        $countjuzgado = Juzgados::get();
        $departamentos = Departamento::where('active','1')->get();
        $ciudades = Ciudad::where('active','1')->get();
        $flag = false;

        if (Input::get('search')) {
            $input = Input::get('search');
            $documento = Juzgados::where('nombre', 'LIKE', '%' . $input . '%')->where('active','1')->get();
            $flag = true;
        }

        $array = [];
        $collection = null;
        $total_registros = 1;

        foreach ($documento as $doc) {
            $ciudad = Ciudad::where('id',$doc->id_ciudad)->first();
            if($ciudad != null){
                $id_departamento = $ciudad->id_departamento;
                $id_ciudad = $ciudad->id;
            }else{
                $id_departamento = 0;
                $id_ciudad = 0;
            }

            array_push($array, (object)array(
                'id' => $doc->id,
                'nombre' => mb_strtoupper($doc->nombre),
                'email' => $doc->email,
                'active' => $doc->active,
                'departamento' => $id_departamento,
                'ciudad' => $id_ciudad
            ));

            $total_registros = $total_registros + 1;
        }

       $collection = new Collection($array);
       $posts = new LengthAwarePaginator($collection, count($countjuzgado), $perPage, $page, [
            'path' => Paginator::resolveCurrentPath(),
            'pageName' => $pageName
        ]);

        return view('parametros.juzgados',
        [  'documento' => $posts,
            'flag' => $flag,
            'departamentos' => $departamentos,
            'ciudades' => $ciudades,
            'juzgados_all' => $juzgados
        ])->withPosts($posts);
    }

    public function modalEditarJuzgados($id)
    {
        $departamentos = Departamento::where('active','1')->get();
        $flag = false;
        $ciudad = "";
        $departamento = "";
        if(!empty($id) || !is_null($id)){
            $documento = Juzgados::where('id',$id)->first();
            if(!empty($documento->id_ciudad) || !is_null($documento->id_ciudad)){
                $ciudad = Ciudad::where('id',$documento->id_ciudad)->first();
                $departamento = Departamento::where('id',$ciudad->id_departamento)->first();
            }
            $id = $documento->id;
            $nombre = $documento->nombre;
            $ciudad = $ciudad;
            $departamento = $departamento;
            $flag = true;
        }else {
            $id = '';
            $nombre = '';
            $ciudad = '';
            $departamento = '';
            $flag = false;
        }
        return view('parametros.modaleditarjuzgados',
        [   
            'id' => $id,
            'nombre' => $nombre,
            'ciudad' => $ciudad,
            'departamento' => $departamento,
            'departamentos' => $departamentos,
            'flag' => $flag
        ]);
    }

    public function guardarJuzgados(request $request){
        $modulo = "ParametrizacionController/guardarJuzgados";
        try{
            $juzgados = new Juzgados();
            if (!empty( $request->nombre) || !is_null($request->ciudad_juzgado) || !empty($request->ciudad_juzgado) ){
                $juzgados_reg = Juzgados::where('nombre', $request->nombre)->first();
                if($juzgados_reg == null){
                    $juzgados->nombre = $request->nombre;
                    $juzgados->id_ciudad = $request->ciudad_juzgado;
                    $juzgados->email = $request->email_juzgado;
                    $juzgados->save();
                    Session::put('success', 'Juzgado guardado exitosamente!');
                    $response = 'Juzgado guardado exitosamente!';
                }else{
                    Session::put('error', 'Juzgado ya existe!');
                    $response = 'Juzgado ya existe!';
                }            
            } else {
                Session::put('error', 'Se produjo un error de validación');
                $response = 'Se produjo un error de validación';
            }
          
        }catch(\Exception $e){
            Session::put('error', 'Se produjo un error al guardar el juzgado');
            $response = $e->getMessage();
        }
        LogController::guardarLog($modulo, $request, $request->all(), $response);
        if(isset($request->ventutela)) {
            if($request->ventutela == 1) {
                return redirect()->route('pqrs');
            } 
        }
        return redirect()->route('parametros.juzgados');
    }

    public function actualizarJuzgados(Request $request)
    {
        $modulo = "ParametrizacionController/actualizarJuzgado";
        try {

            if (!is_null( $request->nombre_modal) || !empty( $request->nombre_modal) || !is_null($request->ciudad_juzgado_edit) || !empty($request->ciudad_juzgado_edit) ){
                $juzgados = Juzgados::where('id', $request->id_juzgado)->first();
                $juzgados->nombre = $request->nombre;
                $juzgados->id_ciudad = $request->ciudad_juzgado_edit;
                $juzgados->email = $request->email_juzgado;
                $juzgados->save();
                Session::put('success', 'Juzgado actualizado exitosamente!');
                $response = 'Juzgado actualizado exitosamente!';
            } else {
                Session::put('error', 'Se produjo un error de validación');
                $response = 'Se produjo un error de validación';
            }
        }catch (\Exception $e) {
            if($e->getCode() == '23000') {
                Session::put('error', 'El nit que intenta registrar ya existe');
                $response = $e->getMessage(); 
            }else{
                Session::put('error', 'se produjo un error al actualizar el juzgado');
                $response = $e->getMessage(); 
            }
         }
         
        LogController::guardarLog($modulo, $request, $request->all(), $response);
        return redirect()->route('parametros.juzgados');
    }
    
    public function eliminarJuzgados(Request $request)
    {      
        $modulo = "ParametrizacionController/eliminarJuzgado";
        try {
            if (!is_null( $request->id)){
                $juzgados = Juzgados::where('id', $request->id)->first();
                $juzgados->active = 0;
                $juzgados->save();
                $response = 'Juzgado '.$request->id.', eliminado exitosamente!';
                $data = ['status'=>'200' , 'msj' => $response];
            } else {
                $response = 'Se produjo un error de validación';
                $data = ['status'=>'500' , 'msj' => $response];
            }
        }catch (\Exception $e) {
            Session::put('error', 'Se produjo un error al actualizar.');
            $response = $e->getMessage();
         }
        LogController::guardarLog($modulo, $request, $request->all(), $response);
        echo json_encode($data);
    }

    public function AjustesPerfilUser()
    {
        $secretKey = $this->generateKey();
        $firmaKey = $this->generateKeyFirma();
        $user = User::find(Auth::id());
       
        return view('__partials.ajustes',[
            'secretKey' => $secretKey,
            'user' => $user,
            'companyName' => 'Xiltrion',
            'google2fa' => (new \PragmaRX\Google2FAQRCode\Google2FA()),
            'FirmaName' => 'Xiltrion Firma',
            'firmaKey' => $firmaKey
        ]);
    }

    public function ActualizarPerfilUser(Request $request)
    {
        $usuario = User::findOrFail(Auth::id());
        Validator::make($request->all(),[
            'pass_before' => [
                'required',
                function($attribute, $value, $fail){
                    $usuario = User::find(Auth::id());
                    if(!password_verify($value, $usuario->password)){
                        $fail('Contraseña Actual incorrecta');
                    }
                }
            ],
            'pass_ingresada' => [
                'required',
                'min:8',
                'different:pass_before',
                 new Mixedcase,
                 new HasNumber,
                 new Symbols
            ],
            'confirmation' => [
                'required',
                'same:pass_ingresada'
            ]
        ],[
            'pass_before.required' => 'Por favor debe ingresar su contraseña actual',
            'pass_ingresada.min' => 'Su Nueva Contraeña debe contener minimo 8 caracteres',
            'pass_ingresada.different' => 'Su nueva contraseña debe ser diferente a su contraseña Actual',
            'pass_ingresada.required' => 'El campo de Nueva Contraseña es requerido',
            'confirmation.same' => 'Los campos de confirmación y Nueva Contraseña deben coincidir',
            'confirmation.required' => 'El campo de Confirmar Contraseña es requerido'
        ])->validate();

        $usuario->password = password_hash($request->pass_ingresada, PASSWORD_BCRYPT, ['cost' => 4]);
        $usuario->save();

        Session::put('ok', 'Los datos han sido actualizados correctamente');

        return redirect()->back();
    }

    private function generateKey()
    {
        $User = User::find(Auth::id());

        if($User->token_login){
            $key = $User->token_login;
        }else{
            $Google2FA = new Google2FA();
            $key = $Google2FA->generateSecretKey();
            $User->token_login = $key;
            $User->save();
        }
        
        return $key;
    }

    public function settingTowFa(Request $request)
    {
        $User = User::find(Auth::id());

        $User->towfa_active = $request->factor;
        $User->save();

        return response()->json([
            'Factor' => $request->factor == 0 ? 'Desactivo' : 'Activo'
        ]);
    }

    public function generateKeyFirma()
    {
        $User = User::find(Auth::id());

        if($User->key_firma){
            $key = $User->key_firma;
        }else{
            $Google2FA = new Google2FA();
            $key = $Google2FA->generateSecretKey();
            $User->key_firma = $key;
            $User->save();
        }
        
        return $key;
    }

    private function resolveURLimg($txt)
    {
        return preg_replace(
            '/\/\w*\/\w*\/\w*\/\w*\/\w*\/.*[g]/',
            'http://'.$_SERVER['HTTP_HOST'].'$0',
            $txt
        );
    }

    public function UsersTipoDocs(){
        $usuarios = User::select('users.id','users.name','users.email','users.active','users.role','area.nombre as area_nombre','tipo_usuario.nombre as tipo_usuario_nombre')
        ->join('area', 'users.id_area', '=', 'area.id')
        ->leftjoin('tipo_usuario', 'users.id_tipo_usuario', '=', 'tipo_usuario.id')
        ->orderBy('users.name', 'ASC')->get();

        $tiposdocs = TpDocumento::where('active', '1')->orderBy('orden', 'asc')->get();

        $array = [];
        $collection = null;

        foreach ($usuarios as $user) {
            $tpdoc = ProyectoresTipoDocs::select('pqrs_tipo_documentos.id','pqrs_tipo_documentos.nombre')
            ->where('tipo_documentos_proyectores.id_user', $user->id)
            ->join('pqrs_tipo_documentos', 'tipo_documentos_proyectores.id_tipodoc', '=', 'pqrs_tipo_documentos.id')
            ->get();

            array_push($array, (object)array(
                'id' => $user->id,
                'name' => $user->name,
                'email' => $user->email,
                'tpdoc' => $tpdoc,
                'role' => $user->role,
                'area_nombre' => $user->area_nombre,
                'tipo_usuario_nombre' => $user->tipo_usuario_nombre == null ? 'SIN ASIGNAR' : $user->tipo_usuario_nombre
            ));
        }

        $collection = new Collection($array);

        return view('parametros.userstipodocs', ['items' => $collection, 'tiposdocs' => $tiposdocs]);
    }

    public function EditUsersTipoDocs($id_user){
        $tiposdocs = TpDocumento::where('active', '1')->orderBy('orden', 'asc')->get();
        $array = [];
        $tpdoc = ProyectoresTipoDocs::where('id_user', $id_user)->get();

        foreach($tpdoc as $utpd){
            array_push($array, $utpd->id_tipodoc);
        }

        return view('parametros.edituserstipodocs', ['tiposdocs' => $tiposdocs, 'tpdoc' => $array, 'id_user' => $id_user]);
    }

    public function ActualizarUserTipoDoc(Request $request){
        if ($request->has('tiposdocs')) {
            $tpdoc = DB::table('tipo_documentos_proyectores')->where('id_user', '=', $request->id_user)->delete();
            foreach ($request->get('tiposdocs') as $tpds) {
                $nuevodoc = new ProyectoresTipoDocs();
                $nuevodoc->id_user = $request->id_user;
                $nuevodoc->id_tipodoc = $tpds;
                $nuevodoc->save();
            }
        }else{
            $tpdoc = DB::table('tipo_documentos_proyectores')->where('id_user', '=', $request->id_user)->delete();
        }

        \Session::flash('status', 'Se han actualizado los tipos documentos correctamente. El usuario solo podrá ver reflejadas las peticiones que sean ingresadas con los tipos seleccionados.');
        return \Redirect::route('parametros.userstipodocs');
    }

    public function IndexEntidad(){
        $entidad = DB::table('entidad')->get();

        $array = [];
        foreach ($entidad as $ent) {
            array_push($array, (object)array(
                'id' => $ent->id,
                'nombre' => $ent->nombre,
                'url_entidad' => $ent->url_entidad,
                'imagen_logo' => $ent->imagen_logo,
                'nombre_header' => $ent->nombre_header,
                'nombre_footer' => $ent->nombre_footer
            ));
        }

        $collection = new Collection($array);

        return view('parametros.entidad', ['entidad' => $collection]);
    }

    public function editarEntidad(){
        $entidad = DB::table('entidad')->first();
        return view('parametros.editar_entidad', ['entidad' => $entidad]);
    }

    function actualizarEntidad(Request $request, $id_entidad){
        $entidad = Entidad::where('id', $id_entidad)->first();
        $file = $request->imagen_logo;
        $file2 = $request->nombre_header;
        $file3 = $request->nombre_footer;

        if($file != null){
            $imagen_logo = str_replace(" ", "_",$file->getclientoriginalname());

            $destinationPath = public_path('assets/images/banner_formatos/');
            $fileData = $imagen_logo;

            $entidad->imagen_logo = $imagen_logo;
            $entidad->ruta_logo = 'assets/images/banner_formatos/'.$fileData;
            $entidad->save();
            
            $file->move($destinationPath, $fileData);
        }

        if($file2 != null){
            $nombre_header = str_replace(" ", "_",$file2->getclientoriginalname());

            $destinationPath2 = public_path('assets/images/banner_formatos/');
            $fileData2 = $nombre_header;

            $entidad->nombre_header = $nombre_header;
            $entidad->imagen_header = 'assets/images/banner_formatos/'.$fileData2;
            $entidad->save();
            
            $file2->move($destinationPath2, $fileData2);
        }

        if($file3 != null){
            $nombre_footer = str_replace(" ", "_",$file3->getclientoriginalname());

            $destinationPath3 = public_path('assets/images/banner_formatos/');
            $fileData3 = $nombre_footer;

            $entidad->nombre_footer = $nombre_footer;
            $entidad->imagen_footer = 'assets/images/banner_formatos/'.$fileData3;
            $entidad->save();

            $file3->move($destinationPath3, $fileData3);
        }

        $entidad->nombre = $request->nombre;
        $entidad->save();

        Session::flash('status', 'Entidad actualizada correctamente.');

        return redirect()->route('parametros.entidad');
    }

    public function DescargarImagenEntidad($nombre_imagen){
        $destinationPath = public_path('assets/images/banner_formatos/'.$nombre_imagen);
        return \Response::download($destinationPath);
    }

    public function ScreenMembrete(){
        $pdf = App::make('dompdf.wrapper');
        $entidad = Entidad::get();

        $array = [];
        $collection = null;
        foreach ($entidad as $ent) {
            array_push($array, (object)array(
                'imagen_header' => public_path($ent->imagen_header),
                'imagen_footer' => public_path($ent->imagen_footer)
            ));
        }

        $collection = new Collection($array);

        $pdf->loadView('parametros.pdfmembrete', ['entidad' => $collection]);

        return $pdf->stream();
    }

    public function indexTipoTramite(){
        $perPage = 20;
        $page = Input::get('page');
        $pageName = 'page';
        $page = Paginator::resolveCurrentPage($pageName);
        $offSet = ($page * $perPage) - $perPage;
        $documento = ParametrosPqr::offset($offSet)->limit($perPage)->orderBy('orden','ASC')->get();
        $countdocs = ParametrosPqr::all();
        $flag = false;

        if (Input::get('search')) {
            $input = Input::get('search');
            $documento = ParametrosPqr::where('nombre', 'LIKE', '%'.$input.'%')->get();
            $flag = true;
        }

        $array = [];
        $collection = null;
        $total_registros = 1;
        foreach ($documento as $doc) {
            array_push($array, (object)array(
                'id' => $doc->id,
                'nombre' => $doc->nombre,
                'active' => $doc->active
            ));

            $total_registros = $total_registros + 1;
        }

        $collection = new Collection($array);

        $posts = new LengthAwarePaginator($collection, count($countdocs), $perPage, $page, [
            'path' => Paginator::resolveCurrentPath(),
            'pageName' => $pageName
        ]);

        return view('parametros.tipotramites', ['documento' => $posts, 'flag' => $flag])->withPosts($posts);
    }

    public function indexValorTipoTramite($id){
        $paginacion = 20;
        $valor_parametro = "";
        $parametro = ParametrosPqr::where("active",1)->orderBy('nombre','ASC')->get();
        $flag = false;
        $nombre_parametro ="";
        if(!empty($id) || !is_null($id)){
            $valor_parametro = ValorParametrosPqr::where('id_parametro',$id)->orderBy('nombre','ASC')->paginate($paginacion);
            $nombre_parametro = ParametrosPqr::where("active",1)->where("id",$id)->first();
            if (Input::get('search')) {
                $valor_parametro = ValorParametrosPqr::where('nombre', 'LIKE', '%'.Input::get('search').'%')->where("id_parametro",$id)->orderBy('nombre','ASC')->paginate($paginacion);
                $flag = true;
            }
        }else {
            Session::put('error', 'Se produjo un error de validación');
            return redirect()->route('parametros.tipostramite');
        }

        return view('parametros.valortptramite',
        [
            'id' => $id, 
            'documento' => $valor_parametro,
            'nombre_parametro' => $nombre_parametro,
            'parametro' => $parametro,
            'flag' => $flag
        ]);
    }

    public function actualizartipotramite(Request $request){
        $modulo = "ParametrizacionController/actualizaactualizartipotramiterParametro";
        try {
            if (!is_null( $request->nombre) || !empty( $request->nombre) || !is_null( $request->active) || !empty($request->active)){
                $parametros = Parametros::where('id', $request->id)->first();
                $parametros->nombre = $request->nombre;
                $parametros->active = $request->active;
                $parametros->save();
                Session::put('success', 'Parámetro actualizado exitosamente!');
                $response = 'Parametro actualizado exitosamente!';
            } else {
                Session::put('error', 'Se Produjo un error de validación');
                $response = 'Se Produjo un error de validación';
            }
        }catch (\Exception $e) {
            Session::put('error', 'Se produjo un error al actualizar: '. $e->getMessage());
            $response = $e->getMessage();
        }

        LogController::guardarLog($modulo, $request,$request->all(), $response);
        return redirect()->route('parametros.tipotramites');
    }

    public function setEditarFormatoResolucion(Request $req, $id){
        DB::connection('mysql3')->table('formato_resolucion')->where('id', $id)->update(['cuerpo' => $req->cuerpo]);
        return redirect()->route('parametros.formatoresolucionEditar');
    }

    public function previewTipoFormato(){
        $entidad = Entidad::first();
        $pdf = App::make('dompdf.wrapper');

        $content = Cache::store('file')->get('preview' . Auth::id());
        $leyenda = FormatosTipoDocs::first()->leyenda;

        $pdf->loadview('pqrs.respuestapdf', [
            'formato' => (object)[
                'header' => $entidad->imagen_header,
                'footer' => $entidad->imagen_footer,
                'body' => $content,
                'leyenda' => $leyenda
            ],
            'clave' => false,
            'fecha_respuesta' => '2023-03-10 20:00:00',
            'elaborado' => 'Pedro Perez',
            'fecha_aprobado' => '2023-03-10 20:00:00',
            'user_aprobado' => 'Carlos Sanchez',
            'fechaFirma' => '2023-03-10 20:00:00',
            'user_firma' => 'Carlos Sanchez'
        ]);

        return $pdf->stream();
    }

    public function setPreviewTipoFormato(Request $req) {

        Cache::store('file')->put('preview' . Auth::id(), $req->content, 10);

        return response('saved', 200);
    }
}