<?php

namespace App\Http\Controllers;

use App\Perfil;
use App\Menu;
use Illuminate\Http\Request;

class PerfilesController extends Controller
{
    function index(){
        $perfiles = Perfil::all();
        return view('perfiles.index', ['perfiles' => $perfiles]);
    }

    function crear(){
        $permisos = Menu::where('active', 1)->whereNull('padre')->orderBy('nombre')->get();
        return view('perfiles.crear', ['permisos' => $permisos]);
    }

    function guardar(Request $request){
        $perfil = new Perfil();
        $perfil->nombre = $request->nombre;
        $perfil->descripcion = $request->descripcion;
        $perfil->save();

        if($request->has('permisos')){
            foreach ($request->get('permisos') as $permiso) {
                $perfil->permisos()->attach($permiso);
            }
        }

        return \Redirect::route('parametros.perfiles');
    }

    function editar(Perfil $perfil)
    {
        $permisos = Menu::where('active', 1)->whereNull('padre')->orderBy('nombre')->get();
        return view('perfiles.editar', ['perfil' => $perfil, 'permisos' => $permisos]);
    }

    function actualizar(Request $request, Perfil $perfil)
    {
        $perfil->nombre = $request->nombre;
        $perfil->descripcion = $request->descripcion;
        $perfil->save();

        if ($request->has('permisos')) {
            $perfil->permisos()->detach();

            foreach ($request->get('permisos') as $permiso) {
                $perfil->permisos()->attach($permiso);
            }
        }

        \Session::flash('alert_text', 'Perfil actualizado correctamente.');


        return \Redirect::route('parametros.perfiles');
    }

    function activar(Perfil $perfil){
        $perfil->active = true;
        $perfil->save();

        \Session::flash('alert_text', 'Perfil activado correctamente.');

        return \Redirect::back();
    }

    function desactivar(Perfil $perfil)
    {
        $perfil->active = false;
        $perfil->save();

        \Session::flash('alert_text', 'Perfil desactivado correctamente.');

        return \Redirect::back();
    }
}
