<?php

namespace App\Http\Controllers;

use App\Perfil;
use App\User;
use App\Area;
use App\TipoUser;
use App\UsuarioPerfil;
use Illuminate\Http\Request;
use Illuminate\Support\Collection;
use PHPGangsta_GoogleAuthenticator;

class UsuariosController extends Controller
{
    function perfil(){
        return view('usuarios.perfil', ['usuario' => \Auth::user()]);
    }

    function index(){
        $usuarios = User::select('users.id','users.name','users.email','users.active','users.role','area.nombre as area_nombre')
        ->leftjoin('area', 'users.id_area', '=', 'area.id')
        ->orderBy('users.name', 'ASC')->get();

        $array = [];
        $collection = null;

        foreach ($usuarios as $user) {
            array_push($array, (object)array(
                'id' => $user->id,
                'name' => $user->name,
                'email' => $user->email,
                'active' => $user->active,
                'role' => $user->role,
                'area_nombre' => $user->area_nombre
            ));
        }

        $collection = new Collection($array);

        return view('usuarios.index', ['items' => $collection]);
    }

    function create(){
        $perfiles = Perfil::all();
        $areas = Area::where('active', '1')->orderBy('nombre','ASC')->get();
        $roles = TipoUser::where('active', '1')->get();
        return view('usuarios.create', ['perfiles' => $perfiles, 'areas' => $areas, 'roles' => $roles]);
    }

    function save(Request $request){
        $authenticator = new PHPGangsta_GoogleAuthenticator();
        $secreto = $authenticator->createSecret();

        $usuario = new User();
        $usuario->id_organismo = \Auth::user()->organismo->id;
        $usuario->name = $request->get('nombre');
        $usuario->email = $request->get('email');
        $usuario->role = $request->get('role');
        $usuario->secreto = $secreto;
        $usuario->password = \Hash::make($request->get('password'));
        $usuario->id_area = $request->get('area');
        $usuario->id_tipo_usuario = $request->get('rol_pqr');
        $usuario->save();

        if($request->has('perfiles')){
            foreach( $request->get('perfiles') as $perfil){
                $usuario->perfiles()->attach($perfil);
            }
        }

        \Session::flash('status', 'Usuario creado correctamente.');

        return \Redirect::route('parametros.users');
    }

    function editar(User $usuario, Request $req)
    {
        $perfiles = Perfil::all();
        $areas = Area::where('active', '1')->orderBy('nombre','ASC')->get();
        $roles = TipoUser::where('active', '1')->get();
        $array = [];
        $perfiles_user = UsuarioPerfil::where('id_usuario', $usuario->id)->get();
        foreach($perfiles_user as $perf){
            array_push($array, $perf->id_perfil);
        }

        $valido = $req->valido ?? 0;

        return view('usuarios.editar', ['perfiles' => $perfiles, 'usuario' => $usuario, 'areas' => $areas, 'roles' => $roles, 'perfiles_user' => $array, 'valido' => $valido]);
    }

    function actualizar(Request $request, User $usuario){
        if($request->get('password')){
            $usuario->password = \Hash::make($request->password);
        }

        $usuario_area = User::where('id_area', $request->get('area'))->where('id_tipo_usuario', 2)->first();

        if($usuario_area == null && $request->get('rol_pqr') == 3){
            return \Redirect::route('usuarios.editar', ['usuario' => $usuario, 'valido' => 1]);
        }else{
            $usuario->name = $request->get('nombre');
            $usuario->id_area = $request->get('area');
            $usuario->id_tipo_usuario = $request->get('rol_pqr');

            if ($request->has('perfiles')) {
                $usuario->perfiles()->detach();

                foreach ($request->get('perfiles') as $perfil) {
                    $usuario->perfiles()->attach($perfil);
                }
            }

            // if(!$usuario->secreto){
                $authenticator = new \PHPGangsta_GoogleAuthenticator();
                $secreto = $authenticator->createSecret();
                $usuario->secreto = $secreto;
            //}

            $usuario->save();
            \Session::flash('status', 'Usuario actualizado correctamente.');

            return \Redirect::route('parametros.users');
        }
    }

    function activate(User $usuario){
        $usuario->active = true;
        $usuario->save();

        \Session::flash('status', 'Usuario activado correctamente.');

        return \Redirect::back();
    }

    function deactivate(User $usuario)
    {
        $usuario->active = false;
        $usuario->save();

        \Session::flash('status', 'Usuario desactivado correctamente.');

        return \Redirect::back();
    }
    public static function getUser($id){
        $user = User::where('id', $id)->get();
        return $user;
    }
}
