<?php namespace App\Http\Controllers;

use App\Http\Requests;
use App\Http\Requests\CreateofertasnphRequest;
use Illuminate\Http\Request;
use App\Libraries\Repositories\ofertasnphRepository;
use Mitul\Controller\AppBaseController;
use Response;
use Flash;

class ofertasnphController extends AppBaseController
{

	/** @var  ofertasnphRepository */
	private $ofertasnphRepository;

	function __construct(ofertasnphRepository $ofertasnphRepo)
	{
		$this->ofertasnphRepository = $ofertasnphRepo;
	}

	/**
	 * Display a listing of the ofertasnph.
	 *
	 * @param Request $request
	 *
	 * @return Response
	 */
	public function index(Request $request)
	{
	    $input = $request->all();

		$result = $this->ofertasnphRepository->search($input);

		$ofertasnphs = $result[0];

		$attributes = $result[1];

		return view('ofertasnphs.index')
		    ->with('ofertasnphs', $ofertasnphs)
		    ->with('attributes', $attributes);;
	}

	/**
	 * Show the form for creating a new ofertasnph.
	 *
	 * @return Response
	 */
	public function create()
	{
		return view('ofertasnphs.create');
	}

	/**
	 * Store a newly created ofertasnph in storage.
	 *
	 * @param CreateofertasnphRequest $request
	 *
	 * @return Response
	 */
	public function store(Request $request)
	{
        $input = $request->all();

		$ofertasnph = $this->ofertasnphRepository->store($input);

		Flash::message('ofertasnph saved successfully.');

		return redirect(route('ofertasnphs.index'));
	}

	/**
	 * Display the specified ofertasnph.
	 *
	 * @param  int $id
	 *
	 * @return Response
	 */
	public function show($id)
	{
		$ofertasnph = $this->ofertasnphRepository->findofertasnphById($id);

		if(empty($ofertasnph))
		{
			Flash::error('ofertasnph not found');
			return redirect(route('ofertasnphs.index'));
		}

		return view('ofertasnphs.show')->with('ofertasnph', $ofertasnph);
	}

	/**
	 * Show the form for editing the specified ofertasnph.
	 *
	 * @param  int  $id
	 * @return Response
	 */
	public function edit($id)
	{
		$ofertasnph = $this->ofertasnphRepository->findofertasnphById($id);

		if(empty($ofertasnph))
		{
			Flash::error('ofertasnph not found');
			return redirect(route('ofertasnphs.index'));
		}

		return view('ofertasnphs.edit')->with('ofertasnph', $ofertasnph);
	}

	/**
	 * Update the specified ofertasnph in storage.
	 *
	 * @param  int    $id
	 * @param CreateofertasnphRequest $request
	 *
	 * @return Response
	 */
	public function update($id, Request $request)
	{
		$ofertasnph = $this->ofertasnphRepository->findofertasnphById($id);

		if(empty($ofertasnph))
		{
			Flash::error('ofertasnph not found');
			return redirect(route('ofertasnphs.index'));
		}

		$ofertasnph = $this->ofertasnphRepository->update($ofertasnph, $request->all());

		Flash::message('ofertasnph updated successfully.');

		return redirect(route('ofertasnphs.index'));
	}

	/**
	 * Remove the specified ofertasnph from storage.
	 *
	 * @param  int $id
	 *
	 * @return Response
	 */
	public function destroy($id)
	{
		$ofertasnph = $this->ofertasnphRepository->findofertasnphById($id);

		if(empty($ofertasnph))
		{
			Flash::error('ofertasnph not found');
			return redirect(route('ofertasnphs.index'));
		}

		$ofertasnph->delete();

		Flash::message('ofertasnph deleted successfully.');

		return redirect(route('ofertasnphs.index'));
	}

}
