<?php namespace App\Http\Controllers;

use App\Http\Requests;
use App\Http\Requests\CreateofertasphRequest;
use Illuminate\Http\Request;
use App\Libraries\Repositories\ofertasphRepository;
use Mitul\Controller\AppBaseController;
use Response;
use Flash;

class ofertasphController extends AppBaseController
{

	/** @var  ofertasphRepository */
	private $ofertasphRepository;

	function __construct(ofertasphRepository $ofertasphRepo)
	{
		$this->ofertasphRepository = $ofertasphRepo;
	}

	/**
	 * Display a listing of the ofertasph.
	 *
	 * @param Request $request
	 *
	 * @return Response
	 */
	public function index(Request $request)
	{
	    $input = $request->all();
		
		$result = $this->ofertasphRepository->search($input);

		$ofertasphs = $result[0];

		$attributes = $result[1];

		return view('ofertasphs.index')
		    ->with('ofertasphs', $ofertasphs)
		    ->with('attributes', $attributes);;
	}

	/**
	 * Show the form for creating a new ofertasph.
	 *
	 * @return Response
	 */
	public function create()
	{
		return view('ofertasphs.create');
	}

	/**
	 * Store a newly created ofertasph in storage.
	 *
	 * @param CreateofertasphRequest $request
	 *
	 * @return Response
	 */
	public function store(Request $request)
	{
        $input = $request->all();

		$ofertasph = $this->ofertasphRepository->store($input);

		Flash::message('ofertasph saved successfully.');

		return redirect(route('ofertasphs.index'));
	}

	/**
	 * Display the specified ofertasph.
	 *
	 * @param  int $id
	 *
	 * @return Response
	 */
	public function show($id)
	{
		$ofertasph = $this->ofertasphRepository->findofertasphById($id);

		if(empty($ofertasph))
		{
			Flash::error('ofertasph not found');
			return redirect(route('ofertasphs.index'));
		}

		return view('ofertasphs.show')->with('ofertasph', $ofertasph);
	}

	/**
	 * Show the form for editing the specified ofertasph.
	 *
	 * @param  int  $id
	 * @return Response
	 */
	public function edit($id)
	{
		$ofertasph = $this->ofertasphRepository->findofertasphById($id);

		if(empty($ofertasph))
		{
			Flash::error('ofertasph not found');
			return redirect(route('ofertasphs.index'));
		}

		return view('ofertasphs.edit')->with('ofertasph', $ofertasph);
	}

	/**
	 * Update the specified ofertasph in storage.
	 *
	 * @param  int    $id
	 * @param CreateofertasphRequest $request
	 *
	 * @return Response
	 */
	public function update($id, Request $request)
	{
		$ofertasph = $this->ofertasphRepository->findofertasphById($id);

		if(empty($ofertasph))
		{
			Flash::error('ofertasph not found');
			return redirect(route('ofertasphs.index'));
		}

		$ofertasph = $this->ofertasphRepository->update($ofertasph, $request->all());

		Flash::message('ofertasph updated successfully.');

		return redirect(route('ofertasphs.index'));
	}

	/**
	 * Remove the specified ofertasph from storage.
	 *
	 * @param  int $id
	 *
	 * @return Response
	 */
	public function destroy($id)
	{
		$ofertasph = $this->ofertasphRepository->findofertasphById($id);

		if(empty($ofertasph))
		{
			Flash::error('ofertasph not found');
			return redirect(route('ofertasphs.index'));
		}

		$ofertasph->delete();

		Flash::message('ofertasph deleted successfully.');

		return redirect(route('ofertasphs.index'));
	}

}
