tinymce.init({
  selector: "div.editor",
  language: "es",
  placeholder: "Click aquí para dar una respuesta",
  branding: false,
  inline: true,
});

async function initLabels() {
  await fetch($("#labelsRoute").val(), {
    method: "GET",
  })
    .then((response) => response.json())
    .then((json) => {
      $(".Labels").empty();
      $.each(json, (key, value) => {
        $("<button>", {
          class: "btn btn-xs btn-primary m-1",
          type: "button",
        })
          .text(key)
          .on("click", (e) => {
            const textarea = $("#body");
            tinymce.get(textarea.attr("id")).selection.setContent(value);
          })
          .data("key", key)
          .appendTo(".Labels");
      });
    });
}

const fileContainer = $(".owl-carousel");

fileContainer.owlCarousel({
  items: 4,
  margin: 5,
  nav: true,
});

$(".Labels").sticky({ topSpacing: 80 });

initLabels();

const deleteFileUploaded = (id, button) => {
  fileContainer.trigger(
    "remove.owl.carousel",
    $(button).parent().parent().index()
  );

  if(!id) return;

  const payload = new FormData();
  const xhr = new XMLHttpRequest();

  xhr.open('POST', $('#DeleteRoute').val())
  xhr.setRequestHeader(
    "X-CSRF-Token",
    $('meta[name="csrf-token"]').attr("content")
  );

  payload.append('id', id);

  xhr.onload = () => {
    if(xhr.status === 200){
      response = JSON.parse(xhr.response);
      const li = $("<li>").html(`<b>${response.fileName}</b> ha sido eliminado.`);
        li.appendTo("#rejected");
        setTimeout(() => li.hide("fast", () => li.remove()), 3000);
    }
  }

  xhr.send(payload);

}

$("#adjuntos").on("change", function () {
  $.each(this.files, function (i, e) {
    const payload = new FormData();
    payload.append("adjunto", e, e.name);

    const xhr = new XMLHttpRequest();
    xhr.open("POST", $("#uploadRoute").val());
    xhr.setRequestHeader(
      "X-CSRF-Token",
      $('meta[name="csrf-token"]').attr("content")
    );

    const divFile = $("<div>", {
      "class": "file-card text-light d-flex flex-column justify-content-center",
      "title": e.name
    });

    const btn = $("<div>", {"class": "d-flex justify-content-end"});

    const btnDelete = $("<button>", { "type": "button", "class": "text-light btnDelete" })
    .append('<i class="fa fa-times-circle" aria-hidden="true"></i>')
    .on("click",  () => deleteFileUploaded($(btn).data('id'), btnDelete))
      
    const icon = $("<div>", { class: "file-spinner" })
      .append('<i class="fa fa-spinner" aria-hidden="true"></i>');
    const fileName = $("<div>", { class: "file-title text-truncate" })
      .html(e.name);
    const fileProgress = $("<div>", { class: "file-progress" });

    
    btn.append(btnDelete);

    divFile.append(icon);
    divFile.append(fileName);
    divFile.append(fileProgress);

    fileContainer.trigger("add.owl.carousel", divFile);
    fileContainer.trigger("refresh.owl.carousel");
    xhr.upload.onprogress = (el) => {
      progress = Math.trunc((el.loaded / el.total) * 100);
      fileProgress.html(`${progress}%`);
    };

    xhr.onload = () => {
      if (xhr.status === 400) {
        response = JSON.parse(xhr.response);
        const li = $("<li>").html(response.message);
        fileContainer.trigger("remove.owl.carousel", divFile.parent().index());
        li.appendTo("#rejected");
        setTimeout(() => li.hide("fast", () => li.remove()), 10000);
      }

      if (xhr.status === 413) {
        const li = $("<li>").html(
          `El archivo <b>${e.name}</b> es demasiado pesado`
        );
        fileContainer.trigger("remove.owl.carousel", divFile.parent().index());
        li.appendTo("#rejected");
        setTimeout(() => li.hide("fast", () => li.remove()), 10000);
      }

      if (xhr.status === 200) {
        response = JSON.parse(xhr.response);
        fileProgress.remove();
        icon.html('<i class="fa-solid fa-file-pdf"></i>');
        $(btn).data('id', response.id)
        btn.prependTo(divFile);
      }

      if(xhr.status >= 500) {
        const li = $("<li>").html(
          `Ha ocurrido algo inesperado al cargar el archivo <b>${e.name}</b>`
        );
        fileContainer.trigger("remove.owl.carousel", divFile.parent().index());
        li.appendTo("#rejected");
        setTimeout(() => li.hide("fast", () => li.remove()), 10000);
      }
    };

    xhr.send(payload);
  });
});

const getFileUpload = async () => {
  
  const adjuntos = await fetch($('#getAdjuntos').val()).then(res => res.json());

  $.each(adjuntos, (_key, item) => {
    const divFile = $("<div>", {
      "class": "file-card text-light d-flex flex-column justify-content-center",
      "title": item.nombre
    });
  
    const btn = $("<div>", {"class": "d-flex justify-content-end"}).data('id', item.id);

    const btnDelete = $("<button>", { "type": "button", "class": "text-light btnDelete" })
    .append('<i class="fa fa-times-circle" aria-hidden="true"></i>')
    .on("click",  () => deleteFileUploaded($(btn).data('id'), btnDelete)) 

    const icon = $("<div>", { class: "file-spinner" })
      .append('<i class="fa-solid fa-file-pdf"></i>');

    const fileName = $("<div>", { class: "file-title text-truncate" })
      .html(item.nombre);

    btn.append(btnDelete);
    divFile.append(btn);
    divFile.append(icon);
    divFile.append(fileName);

    fileContainer.trigger("add.owl.carousel", divFile);
    fileContainer.trigger("refresh.owl.carousel");
  });
}

getFileUpload();

function VisCC(){
  $("#email_cc").css('display', 'block')
  $("#noaddcc").css('display', 'block')
  $("#siaddcc").css('display', 'none')
  $("#div_margin").css('margin-bottom', '3%')
  $("#email_cc").val('')
}

function NoVisCC(){
  $("#email_cc").css('display', 'none')
  $("#noaddcc").css('display', 'none')
  $("#siaddcc").css('display', 'block')
  $("#div_margin").css('margin-bottom', '0%')
  $("#email_cc").val('')
}

function respuestaenviada(){
  var email = $("#email_cc").val()

  var validEmail = /^\w+([.-_+]?\w+)*@\w+([.-]?\w+)*(\.\w{2,10})+$/;

  if(email != ''){
    if(validEmail.test(email)){
      document.getElementById('formRespuesta').submit()
    }else{
      alert('Incluye un signo "@" en la dirección de correo electrónico. La dirección "'+email+'" no es válida.');
    }
  }else{
    document.getElementById('formRespuesta').submit()
  }
}
