<div id="miModal" class="Modal">
    <div class="Modal-Content">
        <span class="close" id="closeModalBtn">&times;</span>
        <div class="d-flex">
            <div class="input-group" style="width: 100vh">
                <input type="text" class="form-control" id="inputDepartment" placeholder="Enter location.."
                    autocomplete="on">
                <input type="button" class="btn btn-primary mx-3" id="inputSubmit">
                <input type="button" class="btn btn-secondary" id="inputClear">
            </div>
        </div>
        <div id="map" class="my-3"></div>
        <div class="d-flex justify-content-end">
            <input type="button" class="btn btn-success" id="inputSend">
        </div>
    </div>
</div>

<style>
    body {
        font-family: Arial, sans-serif;
    }

    #map {
        height: 60vh;
        width: auto;
    }

    .pac-container {
        z-index: 9999 !important;
        /* Ajusta este valor según sea necesario */
    }

    .Modal {
        display: none;
        position: fixed;
        top: 0;
        left: 0;
        width: 100%;
        height: 100%;
        background-color: rgba(0, 0, 0, 0.7);
        z-index: 9888;
    }

    .Modal-Content {
        background-color: #ffffff;
        margin: 5% auto;
        padding: 20px;
        border: 1px solid #888;
        width: 80%;
        box-shadow: 0 4px 8px rgba(0, 0, 0, 0.1);
    }

    .close {
        color: #aaa;
        float: right;
        font-size: 28px;
        font-weight: bold;
    }

    .close:hover,
    .close:focus {
        color: black;
        text-decoration: none;
        cursor: pointer;
    }
</style>
<script>
    let map;
    let marker;
    let geocoder;
    let dataLocation;

    function initMap() {
        map = new google.maps.Map(document.getElementById("map"), {
            zoom: 5,
            center: {
                lat: 4.60971,
                lng: -74.08175
            },
            mapTypeControl: false,
        });

        geocoder = new google.maps.Geocoder();

        inputSearch = initializeAutocomplete("inputDepartment");

        const submitButton = document.getElementById("inputSubmit");
        const clearButton = document.getElementById("inputClear");
        const sendButton = document.getElementById("inputSend");

        submitButton.type = "button";
        submitButton.value = "Search";
        clearButton.type = "button";
        clearButton.value = "Clear";
        sendButton.type = "button";
        sendButton.value = "Send";

        marker = new google.maps.Marker({
            map,
        });

        map.addListener('click', (event) => {
            placeMarker(event.latLng);
        });

        submitButton.addEventListener("click", () => {
            const department = inputSearch.value;
            geocode(department);
        });

        clearButton.addEventListener("click", () => {
            clear();
            inputSearch.value = "";
        });

        sendButton.addEventListener("click", () => {
            const inputLatitud = document.getElementById("inputLatitud");
            const inputLongitud = document.getElementById("inputLongitud");
            const inputAddress = document.getElementById("inputAddress");
            const inputDepartment = document.getElementById("inputDepartament");
            const inputMunicipality = document.getElementById("inputMunicipality");
            const inputNeighborhood = document.getElementById("inputNeighborhood");

            const position = marker.getPosition();
            if (position) {
                const latitude = position.lat();
                const longitude = position.lng();
                inputLatitud.value = latitude
                inputLongitud.value = longitude
                const latLng = new google.maps.LatLng(latitude, longitude);

                geocoder.geocode({
                    'location': latLng
                }, (results, status) => {
                    if (status === 'OK') {
                        if (results[0]) {
                            // Obtener la información del departamento, municipio y barrio
                            let department = "";
                            let municipality = "";
                            let neighborhood = "";
                            let foundNeighborhood = false;
                            let secondPart = "";

                            console.log(results)

                            for (const component of results[5].address_components) {
                                const types = component.types;

                                if (types.includes("administrative_area_level_1")) {
                                    department = component.long_name;
                                } else if (types.includes("administrative_area_level_2")) {
                                    municipality = component.long_name;
                                } else if (types.includes("neighborhood")) {
                                    neighborhood = component.long_name;
                                    foundNeighborhood = true;
                                } else if (!foundNeighborhood && types.includes("sublocality")) {
                                    neighborhood = component.long_name;
                                }

                            }

                            if (!foundNeighborhood && results[6]) {
                                for (const component of results[6].address_components) {
                                    const types = component.types;

                                    if (types.includes("neighborhood")) {
                                        neighborhood = component.long_name;
                                        break; // Si encontramos el barrio, salimos del bucle
                                    } else if (types.includes("sublocality")) {
                                        neighborhood = component.long_name;
                                    }
                                }
                            }

                            const inputValue = inputSearch.value;
                            if (inputValue.includes(dataLocation)) {
                                const separatedValues = inputValue.split(dataLocation);
                                if (separatedValues.some(part => part.trim() !== '')) {
                                    secondPart = separatedValues[1];
                                    inputAddress.value = secondPart
                                } else {
                                    const separatedAddress = inputValue.split(',');

                                    secondPart = separatedAddress[3];
                                }
                            } else {
                                const formattedAddress = results[0].formatted_address
                                const separatedAddress = formattedAddress.split(',');

                                secondPart = separatedAddress[0];
                            }

                            if (!inputDepartment.value.trim()) {
                                inputDepartment.value = department;
                            }

                            if (!inputMunicipality.value.trim()) {
                                inputMunicipality.value = municipality
                            }

                            if (!inputNeighborhood.value.trim()) {
                                inputNeighborhood.value = neighborhood
                            }

                            if (!inputAddress.value.trim()) {
                                inputAddress.value = secondPart
                            }

                            inputSearch.value = "";
                            clear()
                        } else {
                            console.log("No results found for reverse geocoding");
                        }
                    } else {
                        console.log("Reverse geocoding failed due to:", status);
                    }
                });
            } else {
                console.log("No marker position available");
            }
        });

    }

    function placeMarker(location) {
        // Elimina el marcador existente si lo hay
        marker.setMap(null);

        // Establece la nueva posición del marcador
        marker.setPosition(location);
        marker.setMap(map);

        // Centra el mapa en la nueva posición
        map.setCenter(location);
        map.setZoom(15);

        // Puedes realizar acciones adicionales aquí si es necesario
    }

    function initializeAutocomplete(inputId, initialValue) {
        const input = document.getElementById(inputId);

        if (initialValue) {
            input.value = initialValue;
        }

        const autocomplete = new google.maps.places.Autocomplete(input);
        autocomplete.setFields(['address_components', 'geometry', 'name']);

        autocomplete.addListener('place_changed', () => {
            handlePlaceChanged(autocomplete);
        });

        return input;
    }

    function handlePlaceChanged(autocomplete) {
        const place = autocomplete.getPlace();
        if (!place.geometry || !place.geometry.location) {
            alert("No details available for input: '" + place.name + "'");
            return;
        }

        map.setCenter(place.geometry.location);
        map.setZoom(17);
        marker.setPosition(place.geometry.location);
        marker.setMap(map);
    }

    function clear() {
        marker.setMap(null);
        map.setZoom(5);
        map.setCenter({
            lat: 4.60971,
            lng: -74.08175
        });
    }

    function geocode(data) {
        clear();

        geocoder
            .geocode({
                address: data
            })
            .then((result) => {
                const {
                    results
                } = result;
                if (results.length > 0) {
                    const location = results[0].geometry.location;
                    map.setCenter(location);
                    marker.setPosition(location);
                    map.setZoom(17);
                    marker.setMap(map);
                } else {
                    alert("No results found");
                }
            })
            .catch((e) => {
                alert("Geocode was not successful for the following reason: " + e);
            });
    }

    var modal = document.getElementById("btnShowModal");

    const inputDepartment = document.getElementById("inputDepartament");
    const inputMunicipality = document.getElementById("inputMunicipality");
    const inputNeighborhood = document.getElementById("inputNeighborhood");
    const inputAddress = document.getElementById("inputAddress");


    modal.addEventListener('click', () => {

        if (inputDepartment.value || inputMunicipality.value || inputNeighborhood.value || inputAddress.value) {
            const department = inputDepartment.value;
            const municipality = inputMunicipality.value;
            const neighborhood = inputNeighborhood.value;
            const address = inputAddress.value;

            dataLocation = `${department},${municipality},${neighborhood},${address}`;
            initializeAutocomplete("inputDepartment", dataLocation);
            geocode(dataLocation);
        }

    })

    window.initMap = initMap;
</script>
<script
    src="https://maps.googleapis.com/maps/api/js?key=AIzaSyDIAUCYmZiIWPbmTabytupLueRjFNmDHUc&libraries=places&callback=initMap"
    defer></script>
