@extends('layouts.app')

@section('breadcrumbs')
    @include('_includes.breadcrumbs', [
        'data' => [
            ['route' => route('home'), 'name' => 'Inicio'],
            ['route' => '', 'name' => 'Reportes'],
            ['route' => '', 'name' => 'Auditoría']
        ],
        'show_add_button' => false
    ])
@endsection

@section('content')

    <div id="center">
        <div class="filters print-multi">
            <div>
                <form class="ui form" method="GET" action="{{ route('reportes.auditoria') }}">
                    {!! csrf_field() !!}

                    <div class="field">
                        <label>
                            FECHA INICIAL
                        </label>
                        <input
                                name="fecha_inicial"
                                id="fecha_inicial"
                                data-language="es"
                                value="@if(Input::has('fecha_inicial')) {{ Input::get('fecha_inicial') }} @else {{ Carbon\Carbon::now()->format('Y-m-d') }} @endif"
                        >
                    </div>

                    <div class="field">
                        <label>
                            FECHA FINAL
                        </label>
                        <input
                                name="fecha_final"
                                id="fecha_final"
                                data-language="es"
                                value="@if(Input::has('fecha_final')) {{ Input::get('fecha_final') }} @else {{ Carbon\Carbon::now()->format('Y-m-d') }} @endif"
                        >
                    </div>

                    <div class="field">
                        <label>
                            Tipo
                        </label>
                        <select name="etiqueta" class="ui dropdown">
                            <option value=""
                                    @if(!Input::has('etiqueta') || empty(Input::get('etiqueta'))) selected @endif>Todos</option>
                            <option value="ajuste-factura" @if(Input::has('etiqueta') && Input::get('etiqueta') == 'ajuste-factura') selected @endif>Ajuste de Factura</option>
                            <option value="egreso-bancario"
                                    @if(Input::has('etiqueta') && Input::get('etiqueta') == 'egreso-bancario') selected @endif>Egreso Bancario</option>
                        </select>
                    </div>

                    <div class="field">
                        <button class="ui button">CONSULTAR</button>
                    </div>
                </form>
            </div>
            <div>
                @if(!$items->isEmpty())
                <button class="ui basic button print">
                    <i class="fa fa-print"></i>
                    IMPRIMIR
                </button>
                @endif
            </div>
        </div>
        <div class="spacer"></div>
        <div class="spacer"></div>

        @if(!$items->isEmpty())
            <div class="encabezado solo-imprimir">
                <div class="print-multi" style="align-items: center;">
                    <div class="logo">
                        <img style="max-width: 150px; height: auto;"
                             src="{{ asset('images/logo-arjona-avanza-recibo.png') }}">
                    </div>

                    <div class="titulo-reporte">
                        <h1 style="font-weight: 700; font-size: 2em;">Reporte de Auditoría</h1>
                    </div>
                </div>

                <div class="spacer"></div>
                <div class="spacer"></div>
            </div>

            <table class="data">
                <thead>
                    <tr>
                        <th style="width: auto; max-width: none; text-align: left;">Fecha</th>
                        <th>Tipo</th>
                        <th>Responsable</th>
                        <th>Detalle</th>
                    </tr>
                </thead>
                <tbody>
                    @foreach($items as $item)
                        <tr>
                            <td style="text-align: left;">{{ $item->created_at->toDateTimeString() }}</td>
                            <td>{{ $item->titulo }}</td>
                            <td>{{ $item->usuario->name }}</td>
                            <td>{{ $item->descripcion }}</td>
                        </tr>
                    @endforeach
                </tbody>
            </table>

            <div class="pie solo-imprimir">
                <table class="data bottom">
                    <tr>
                        <td style="text-align: center;" align="center">
                            <table cellpadding="0" cellspacing="0">
                                <tr>
                                    <td>
                                        <div class="logo">
                                            <img style="max-width: 130px; height: auto;"
                                                 src="{{ asset('images/logo-ett.png') }}">
                                        </div>
                                    </td>
                                    <td>
                                        Carrera 46 No. 57-39. Arjona - Bolívar.<br>
                                        Teléfonos: 6564412 - 6564413 - 6564414.<br>
                                        tramites@ettbolivar.com
                                    </td>
                                </tr>
                            </table>
                        </td>
                        <td>
                            <div class="logos" style="text-align: right;">
                                <img style="max-width: 300px; height: auto;"
                                     src="{{ asset('images/logos-recibo.png') }}">
                            </div>
                        </td>
                    </tr>
                </table>
                <p style="text-align: center;">Reporte genenerado por {{ Auth::user()->name }}
                    el {{ \Carbon\Carbon::now()->format('Y-m-d') }} a las {{ \Carbon\Carbon::now()->format('H:i') }}</p>
            </div>
        @else
            @if(Input::has('fecha_inicial'))
            <div class="no-data">
                <div class="no-data-icon">
                    <i class="fa fa-exclamation-triangle"></i>
                </div>

                <div class="no-data-message">
                    No se encontraron registros para este rango de fechas.
                </div>
            </div>
            @endif
        @endif

    </div>

@endsection
