@extends('layouts.app')

@section('breadcrumbs')
    @include('_includes.breadcrumbs', [
        'data' => [
            ['route' => route('home'), 'name' => 'Inicio'],
            ['route' => '', 'name' => 'Reportes'],
            ['route' => '', 'name' => 'Movimientos Bancarios']
        ],
        'show_add_button' => false
    ])
@endsection

@section('content')

    <div id="center">
        <div class="filters print-multi">
            <div>
                <form class="ui form" method="GET" action="{{ route('reportes.bancos') }}">
                    {!! csrf_field() !!}

                    <div class="field">
                        <label>
                            FECHA INICIAL
                        </label>
                        <input
                                name="fecha_inicial"
                                id="fecha_inicial"
                                data-language="es"
                                value="@if(Input::has('fecha_inicial')) {{ Input::get('fecha_inicial') }} @else {{ Carbon\Carbon::now()->format('Y-m-d') }} @endif"
                        >
                    </div>

                    <div class="field">
                        <label>
                            FECHA FINAL
                        </label>
                        <input
                                name="fecha_final"
                                id="fecha_final"
                                data-language="es"
                                value="@if(Input::has('fecha_final')) {{ Input::get('fecha_final') }} @else {{ Carbon\Carbon::now()->format('Y-m-d') }} @endif"
                        >
                    </div>

                    <div class="field">
                        <label>
                            CUENTA
                        </label>
                        <select name="id_cuenta" class="ui dropdown" style="width: 260px;">
                            @foreach($cuentas as $cuenta)
                                <option @if($id_cuenta == $cuenta->id) selected @endif value="{{ $cuenta->id }}">{{ ucfirst($cuenta->banco->nombre) }} {{ ucfirst($cuenta->tipo) }} {{ $cuenta->numero }}</option>
                            @endforeach
                        </select>
                    </div>

                    <div class="field">
                        <button class="ui button">CONSULTAR</button>
                    </div>
                </form>
            </div>
            <div>
                @if(!$movimientos->isEmpty())
                <button class="ui basic button print">
                    <i class="fa fa-print"></i>
                    IMPRIMIR
                </button>
                @endif
            </div>
        </div>
        <div class="spacer"></div>
        <div class="spacer"></div>

        @if(!$movimientos->isEmpty())
            <div class="encabezado solo-imprimir">
                <div class="print-multi" style="align-items: center;">
                    <div class="logo">
                        <img style="max-width: 150px; height: auto;"
                             src="{{ asset('images/logo-arjona-avanza-recibo.png') }}">
                    </div>

                    <div class="titulo-reporte">
                        <h1 style="font-weight: 700; font-size: 2em;">Cuentas Bancarias</h1>
                    </div>
                </div>

                <div class="spacer"></div>
                <div class="spacer"></div>
            </div>

            <table class="data">
                <thead>
                    <tr>
                        <th style="width: auto; max-width: none; text-align: left;">Fecha Movimiento</th>
                        <th>Concepto</th>
                        <th>Cuenta</th>
                        <th style="text-align: right;">Valor</th>
                        <th style="text-align: right;">Saldo</th>
                    </tr>
                </thead>
                <tbody>
                    <?php $total = $totalAnterior; ?>
                    @foreach($movimientos as $movimiento)
                        <?php
                        $cuenta = \App\Cuenta::find($movimiento->id_cuenta);
                        $total += $movimiento->valor;
                        ?>
                            <tr>
                                <td style="text-align: left;">{{ \Carbon\Carbon::createFromFormat("Y-m-d H:i:s", $movimiento->created_at)->toDateTimeString() }}</td>
                                <td>{{ ucfirst($movimiento->concepto) }}</td>
                                <td>{{ ucfirst($cuenta->banco->nombre) }} {{ ucfirst($cuenta->tipo) }} No. {{ ucfirst($cuenta->numero) }}</td>

                                @if($movimiento->valor < 0)
                                    <td style="text-align: right;" class="texto-rojo">
                                        - ${{ number_format($movimiento->valor * -1, 0, '.', '.') }}
                                    </td>
                                @else
                                    <td style="text-align: right;" class="texto-verde">
                                        ${{ number_format($movimiento->valor, 0, '.', '.') }}
                                    </td>
                                @endif

                                @if($total < 0)
                                    <td style="text-align: right;" class="texto-rojo">
                                        - ${{ number_format($total * -1, 0, '.', '.') }}
                                    </td>
                                @else
                                    <td style="text-align: right;" class="texto-verde">
                                        ${{ number_format($total, 0, '.', '.') }}
                                    </td>
                                @endif
                            </tr>
                    @endforeach
                </tbody>
                <tfoot>
                    <tr>
                        <td colspan="3" style="text-align: right;">Total</td>
                        <td style="text-align: right;">${{ number_format($totalMovimientos, 0, '.', '.') }}</td>
                        <td style="text-align: right;">${{ number_format($total, 0, '.', '.') }}</td>
                    </tr>
                </tfoot>
            </table>

            <div class="pie solo-imprimir">
                <table class="data bottom">
                    <tr>
                        <td style="text-align: center;" align="center">
                            <table cellpadding="0" cellspacing="0">
                                <tr>
                                    <td>
                                        <div class="logo">
                                            <img style="max-width: 130px; height: auto;"
                                                 src="{{ asset('images/logo-ett.png') }}">
                                        </div>
                                    </td>
                                    <td>
                                        Carrera 46 No. 57-39. Arjona - Bolívar.<br>
                                        Teléfonos: 6564412 - 6564413 - 6564414.<br>
                                        tramites@ettbolivar.com
                                    </td>
                                </tr>
                            </table>
                        </td>
                        <td>
                            <div class="logos" style="text-align: right;">
                                <img style="max-width: 300px; height: auto;"
                                     src="{{ asset('images/logos-recibo.png') }}">
                            </div>
                        </td>
                    </tr>
                </table>
                <p style="text-align: center;">Reporte genenerado por {{ Auth::user()->name }}
                    el {{ \Carbon\Carbon::now()->format('Y-m-d') }} a las {{ \Carbon\Carbon::now()->format('H:i') }}</p>
            </div>
        @else
            @if(Input::has('fecha_inicial'))
            <div class="no-data">
                <div class="no-data-icon">
                    <i class="fa fa-exclamation-triangle"></i>
                </div>

                <div class="no-data-message">
                    No se encontraron registros para este rango de fechas.
                </div>
            </div>
            @endif
        @endif

    </div>

@endsection
