@extends('layouts.app')

@section('breadcrumbs')
    @include('_includes.breadcrumbs', [
        'data' => [
            ['route' => route('home'), 'name' => 'Inicio'],
            ['route' => '', 'name' => 'Reportes'],
            ['route' => '', 'name' => 'Cartera Morosa']
        ],
        'show_add_button' => false
    ])
@endsection

@section('content')

    <div id="center">
        <div class="filters">
            <div>
                <form target="_blank" class="ui form" method="POST" action="{{ route('reportes.cartera') }}">
                    {!! csrf_field() !!}

                    <div class="field">
                        <label>
                            Año
                        </label>
                        <select name="ano" id="">
                            <option value="0" selected>Todo</option>

                            @for($i=2007; $i<=$anoActual; $i++)
                                <option value="{{ $i }}">{{ $i }}</option>
                            @endfor
                        </select>
                    </div>

                    <div class="field">
                        <button class="ui button">DESCARGAR</button>
                    </div>
                </form>
            </div>
        </div>
        <div class="spacer"></div>
        <div class="spacer"></div>

        @if($items && !$items->isEmpty())
            <div class="encabezado solo-imprimir">
                <div class="print-multi" style="align-items: center;">
                    <div class="logo">
                        <img style="max-width: 150px; height: auto;"
                             src="{{ asset('images/logo-arjona-avanza-recibo.png') }}">
                    </div>

                    <div class="titulo-reporte">
                        <h1 style="font-weight: 700; font-size: 2em;">Reporte de Cartera Morosa Derechos de Tránsito</h1>
                    </div>
                </div>

                <div class="spacer"></div>
                <div class="spacer"></div>
            </div>

            <table class="data">
                <thead>
                    <tr>
                        <th style="width: auto; max-width: none; text-align: left;">Fecha</th>
                        <th>Tipo</th>
                        <th>Responsable</th>
                        <th>Detalle</th>
                    </tr>
                </thead>
                <tbody>
                    @foreach($items as $item)
                        <tr>
                            <td style="text-align: left;">{{ $item->created_at->toDateTimeString() }}</td>
                            <td>{{ $item->titulo }}</td>
                            <td>{{ $item->usuario->name }}</td>
                            <td>{{ $item->descripcion }}</td>
                        </tr>
                    @endforeach
                </tbody>
            </table>

            <div class="pie solo-imprimir">
                <table class="data bottom">
                    <tr>
                        <td style="text-align: center;" align="center">
                            <table cellpadding="0" cellspacing="0">
                                <tr>
                                    <td>
                                        <div class="logo">
                                            <img style="max-width: 130px; height: auto;"
                                                 src="{{ asset('images/logo-ett.png') }}">
                                        </div>
                                    </td>
                                    <td>
                                        Carrera 46 No. 57-39. Arjona - Bolívar.<br>
                                        Teléfonos: 6564412 - 6564413 - 6564414.<br>
                                        tramites@ettbolivar.com
                                    </td>
                                </tr>
                            </table>
                        </td>
                        <td>
                            <div class="logos" style="text-align: right;">
                                <img style="max-width: 300px; height: auto;"
                                     src="{{ asset('images/logos-recibo.png') }}">
                            </div>
                        </td>
                    </tr>
                </table>
                <p style="text-align: center;">Reporte genenerado por {{ Auth::user()->name }}
                    el {{ \Carbon\Carbon::now()->format('Y-m-d') }} a las {{ \Carbon\Carbon::now()->format('H:i') }}</p>
            </div>
        @else
            @if(Input::has('fecha_inicial'))
            <div class="no-data">
                <div class="no-data-icon">
                    <i class="fa fa-exclamation-triangle"></i>
                </div>

                <div class="no-data-message">
                    No se encontraron registros para este rango de fechas.
                </div>
            </div>
            @endif
        @endif

    </div>

@endsection
