@extends('layouts.app')

@section('breadcrumbs')
    @include('_includes.breadcrumbs', [
        'data' => [
            ['route' => route('home'), 'name' => 'Inicio'],
            ['route' => '', 'name' => 'Reportes'],
            ['route' => '', 'name' => 'Movimientos de Caja']
        ],
        'show_add_button' => false
    ])
@endsection

@section('content')

    <div id="center">
        <div class="filters print-multi">
            <div>
                <form class="ui form" method="GET" action="{{ route('reportes.movimientos') }}">
                    {!! csrf_field() !!}

                    <div class="field">
                        <label>
                            FECHA INICIAL
                        </label>
                        <input
                                name="fecha_inicial"
                                id="fecha_inicial"
                                data-language="es"
                                value="@if(Input::has('fecha_inicial')) {{ Input::get('fecha_inicial') }} @else {{ Carbon\Carbon::now()->format('Y-m-d') }} @endif"
                        >
                    </div>

                    <div class="field">
                        <label>
                            FECHA FINAL
                        </label>
                        <input
                                name="fecha_final"
                                id="fecha_final"
                                data-language="es"
                                value="@if(Input::has('fecha_final')) {{ Input::get('fecha_final') }} @else {{ Carbon\Carbon::now()->format('Y-m-d') }} @endif"
                        >
                    </div>

                    <div class="field">
                        <button class="ui button">CONSULTAR</button>
                    </div>
                </form>
            </div>
            <div>
                @if(!$movimientos->isEmpty())
                <button class="ui basic button print">
                    <i class="fa fa-print"></i>
                    IMPRIMIR
                </button>
                @endif
            </div>
        </div>
        <div class="spacer"></div>
        <div class="spacer"></div>

        @if(!$movimientos->isEmpty())
            <div class="encabezado solo-imprimir">
                <div class="print-multi" style="align-items: center;">
                    <div class="logo">
                        <img style="max-width: 150px; height: auto;"
                             src="{{ asset('images/logo-arjona-avanza-recibo.png') }}">
                    </div>

                    <div class="titulo-reporte">
                        <h1 style="font-weight: 700; font-size: 2em;">Movimientos de Caja</h1>
                    </div>
                </div>

                <div class="spacer"></div>
                <div class="spacer"></div>
            </div>

            <table class="data">
                <thead>
                    <tr>
                        <th style="width: auto; max-width: none; text-align: left;">Fecha</th>
                        <th>Concepto</th>
                        <th style="text-align: right;">Valor</th>
                        <th class="solo-imprimir-celda">Factura #</th>
                        <th class="ocultar-imprimir">&nbsp;</th>
                    </tr>
                </thead>
                <tbody>
                    @foreach($movimientos as $movimiento)
                        @if($movimiento->etiqueta == 'cierre-caja')
                            <tr class="cierre">
                                <td style="text-align: left;">{{ $movimiento->created_at->toDateTimeString() }}</td>
                                <td style="font-weight: 700; font-size: 1.15em;">{{ $movimiento->descripcion }}</td>
                                <td colspan="2">
                                    <?php
                                    foreach(App\Cuenta::all() as $cuenta){
                                        $total = App\Destino::where('id_cuenta', $cuenta->id)
                                        ->where('id_cierre', $movimiento->id)
                                        ->sum('valor');
                                        $cuentas[$cuenta->id]['cuenta'] = $cuenta;
                                        $cuentas[$cuenta->id]['total'] = $total;
                                    }
                                    ?>
                                    <div class="cuentas">
                                        <h3>Consignar a cuentas</h3>
                                        @foreach($cuentas as $cuenta)
                                            <?php
                                            ?>
                                            <div style="font-size: 1.25em; line-height: 1.35em;">
                                                {{ $cuenta['cuenta']->banco->nombre }}
                                                {{ ucfirst($cuenta['cuenta']->tipo) }}
                                                No. {{ $cuenta['cuenta']->numero }}: <span
                                                        style="font-weight: 700;">${{ number_format($cuenta['total'], 0, '.', '.') }}</span>
                                            </div>
                                        @endforeach
                                    </div>
                                </td>
                            </tr>
                        @else
                            <tr>
                                <td style="text-align: left;">{{ $movimiento->created_at->toDateTimeString() }}</td>
                                <td>{{ $movimiento->descripcion }}</td>
                                <td style="text-align: right;"
                                    class="@if($movimiento->valor >= 0) texto-verde @else texto-rojo @endif">
                                    ${{ number_format($movimiento->valor, 0, '.', '.') }}</td>
                                <td class="solo-imprimir-celda">
                                    @if($movimiento->etiqueta == 'pago-impuesto')
                                        {{ $movimiento->numeracionFactura->numeracion->prefijo }}
                                        -{{ str_pad($movimiento->numeracionFactura->numero, strlen($movimiento->numeracionFactura->numeracion->final), '0', STR_PAD_LEFT) }}
                                    @else
                                        &nbsp;
                                    @endif
                                </td>
                                <td class="ocultar-imprimir" style="text-align: center;">
                                    @if($movimiento->etiqueta == 'pago-impuesto')
                                        <a class="ui button small" target="_blank"
                                           href="{{ route('caja.impuestos.verFactura', $movimiento->id) }}">
                                            FACTURA {{ $movimiento->numeracionFactura->numeracion->prefijo }}
                                            -{{ str_pad($movimiento->numeracionFactura->numero, strlen($movimiento->numeracionFactura->numeracion->final), '0', STR_PAD_LEFT) }}
                                        </a>
                                    @else
                                        <a class="ui button small" target="_blank"
                                           href="{{ route('caja.impuestos.verTx', $movimiento->id) }}">RECIBO</a>
                                    @endif
                                </td>
                            </tr>
                        @endif
                    @endforeach
                </tbody>
                <tfoot>
                    <tr>
                        <td colspan="2" style="text-align: right;">Total</td>
                        <td style="text-align: right;">${{ number_format($totalMovimientos, 0, '.', '.') }}</td>
                        <td>&nbsp;</td>
                    </tr>
                </tfoot>
            </table>

            <div class="pie solo-imprimir">
                <table class="data bottom">
                    <tr>
                        <td style="text-align: center;" align="center">
                            <table cellpadding="0" cellspacing="0">
                                <tr>
                                    <td>
                                        <div class="logo">
                                            <img style="max-width: 130px; height: auto;"
                                                 src="{{ asset('images/logo-ett.png') }}">
                                        </div>
                                    </td>
                                    <td>
                                        Carrera 46 No. 57-39. Arjona - Bolívar.<br>
                                        Teléfonos: 6564412 - 6564413 - 6564414.<br>
                                        tramites@ettbolivar.com
                                    </td>
                                </tr>
                            </table>
                        </td>
                        <td>
                            <div class="logos" style="text-align: right;">
                                <img style="max-width: 300px; height: auto;"
                                     src="{{ asset('images/logos-recibo.png') }}">
                            </div>
                        </td>
                    </tr>
                </table>
                <p style="text-align: center;">Reporte genenerado por {{ Auth::user()->name }}
                    el {{ \Carbon\Carbon::now()->format('Y-m-d') }} a las {{ \Carbon\Carbon::now()->format('H:i') }}</p>
            </div>
        @else
            @if(Input::has('fecha_inicial'))
            <div class="no-data">
                <div class="no-data-icon">
                    <i class="fa fa-exclamation-triangle"></i>
                </div>

                <div class="no-data-message">
                    No se encontraron registros para este rango de fechas.
                </div>
            </div>
            @endif
        @endif

    </div>

@endsection
