@extends('layouts.app')

@section('breadcrumbs')
    @include('_includes.breadcrumbs', [
        'data' => [
            ['route' => route('home'), 'name' => 'Inicio'],
            ['route' => '', 'name' => 'Reportes'],
            ['route' => '', 'name' => 'Conciliacion Bancaria']
        ],
        'show_add_button' => false
    ])
@endsection

@section('content')

    <div id="center">
        <div class="filters print-multi">
            <div>
                <form class="ui form" method="GET" action="{{ route('reportes.conciliacion') }}">
                    {!! csrf_field() !!}

                    <div class="field">
                        <label>Tipo</label>
                        <select name="tipo" class="ui dropdown">
                            <option value="" @if(!$tipo || empty($tipo)) selected @endif>Todos</option>
                            <option value="derechos" @if($tipo == 'derechos') selected @endif>Derechos de Tránsito</option>
                            <option value="comparendos" @if($tipo == 'comparendos') selected @endif>Comparendos</option>
                            <option value="tramites" @if($tipo == 'tramites') selected @endif>Tramites</option>                            
                        </select>
                    </div>

                    <div class="field">
                        <label>
                            FECHA INICIAL
                        </label>
                        <input
                                name="fecha_inicial"
                                id="fecha_inicial"
                                data-language="es"
 value="@if(Input::has('fecha_inicial')) {{ Input::get('fecha_inicial') }} @else {{ Carbon\Carbon::now()->format('Y-m-d') }} @endif"
                        >
                    </div>

                    <div class="field">
                        <label>
                            FECHA FINAL
                        </label>
                        <input
                                name="fecha_final"
                                id="fecha_final"
                                data-language="es"
 value="@if(Input::has('fecha_final')) {{ Input::get('fecha_final') }} @else {{ Carbon\Carbon::now()->format('Y-m-d') }} @endif"
                        >
                    </div>

                    <div class="field">
                        <button class="ui button">CONSULTAR</button>
                    </div>
                </form>
            </div>

            <div>
                @if(!$movimientos->isEmpty())
                    <button class="ui basic button print">
                        <i class="fa fa-print"></i>
                        IMPRIMIR
                    </button>
                @endif
            </div>
        </div>

        @if(!$movimientos->isEmpty())

            <div class="encabezado solo-imprimir">
                <div class="print-multi" style="align-items: center;">
                    <div class="logo">
                        <img style="max-width: 150px; height: auto;"
                             src="{{ asset('images/logo-arjona-avanza-recibo.png') }}">
                    </div>

                    <div class="titulo-reporte">
                        <h1 style="font-weight: 700; font-size: 2em;">Recaudo de Derechos de Tránsito</h1>
                    </div>
                </div>

                <div class="spacer"></div>
                <div class="spacer"></div>
            </div>


            <div class="spacer"></div>
            <div class="spacer"></div>

            <table class="data">
                <thead>
                    <tr>
                        <th style="width: auto; max-width: none; text-align: left;">Fecha</th>
                        <th>Tipo</th>
                        <th>Año</th>
                        <th>Comparendo</th>
                        <th>Placa</th>
                        <th style="text-align: right;">Recaudo</th>
                    </tr>
                </thead>
                <tbody>
                    @foreach($movimientos as $movimiento)
                        @if($movimiento->etiqueta == "pago-impuesto")
                            @foreach($movimiento->pagos as $pago)
                                <tr>
                                    <td style="text-align: left;">
                                        <div>
                                            {{ $movimiento->created_at->format('Y-m-d') }}
                                        </div>
                                        <div style="font-size: 0.9em;">
                                            {{ $movimiento->created_at->format('H:i') }}
                                        </div>
                                    </td>
                                    <td>Derecho</td>
                                    <td>{{ $pago->ano }}</td>
                                    <td>-</td>
                                    <td>{{ strtoupper($pago->vehiculo->placa) }}</td>

                                    <td style="text-align: right; font-weight: 700;">
                                        ${{ number_format($movimiento->valor, 0, '.', '.') }}
                                    </td>

                                </tr>
                            @endforeach
                        @endif    
                        @if($movimiento->etiqueta == "pago-comparendo")
                            @foreach($movimiento->obtenerComparendosObj() as $comparendo)
                            <?php
							$factura = json_decode($movimiento->factura, true);
							/*$total=$transaccion->valor - $factura['intereses'] - $factura['honorarios'] 
							+ $factura['campana_calculados']
		                    - $factura['sistematizacion']/1.19   - (($factura['sistematizacion']/1.19)*0.19);
								if( $comparendo->descuento )
								{
								$total=$total + $comparendo->descuento->total_descuento + $comparendo->descuento->total_cia;	
								}*/
							?>
                            <tr>
                                <td style="text-align: left;">
                                    <div>
                                        {{ $movimiento->created_at->format('Y-m-d') }}
                                    </div>
                                    <div style="font-size: 0.9em;">
                                        {{ $movimiento->created_at->format('H:i') }}
                                    </div>
                                </td>
                                <td>Comparendo</td>
                                <td>-</td>
                                <td>{{ $comparendo->numero_corto }}</td>
                                <td>{{ $comparendo->vehiculo_placa }}</td>

                                <td style="text-align: right; font-weight: bold;">
                                    ${{ number_format($movimiento->valor, 0, '.', '.') }}
                                </td>

                            </tr>
                            @endforeach
                        @endif
                        
                       @if($movimiento->etiqueta == "pago-tramite")
                            @foreach($movimiento->pagos as $pago)
                                <tr>
                                    <td style="text-align: left;">
                                        <div>
                                            {{ $movimiento->created_at->format('Y-m-d') }}
                                        </div>
                                        <div style="font-size: 0.9em;">
                                            {{ $movimiento->created_at->format('H:i') }}
                                        </div>
                                    </td>
                                    <td>Derecho</td>
                                    <td>{{ $pago->ano }}</td>
                                    <td>-</td>
                                    <td>{{ strtoupper($pago->vehiculo->placa) }}</td>

                                    <td style="text-align: right; font-weight: 700;">
                                       ${{ number_format($movimiento->valor, 0, '.', '.') }}
                                    </td>
                                    <td class="ocultar-imprimir" style="text-align: center;">
                                        <a class="ui button small" target="_blank"
                                           href="{{ route('caja.tramitesrna.verFactura', $movimiento->id) }}">
                                            <i class="fa fa-list"></i>
                                        </a>
                                    </td>
                                </tr>
                            @endforeach
                        @endif  
                        
						                       
                        
                    @endforeach
                </tbody>
                <tfoot>
                    <tr>
                        <td colspan="5">&nbsp;</td>
                          <td style="text-align: right;">${{ number_format($totalMovimientos, 0, '.', '.') }}</td>
                        <td class="ocultar-imprimir">&nbsp;</td>
                    </tr>
                </tfoot>
            </table>

            <div class="pie solo-imprimir">
                <table class="data bottom">
                    <tr>
                        <td style="text-align: center;" align="center">
                            <table cellpadding="0" cellspacing="0">
                                <tr>
                                    <td>
                                        <div class="logo">
                                            <img style="max-width: 130px; height: auto;" src="{{ asset('images/logo-ett.png') }}">
                                        </div>
                                    </td>
                                    <td>
 							Dir. {{ mb_strtoupper(Auth::user()->organismo->direccion) }} <br>
                            Tel. {{ mb_strtoupper(Auth::user()->organismo->telefonos) }} <br>
                            {{ mb_strtoupper(Auth::user()->organismo->sitio_web) }} <br>
                            {{ mb_strtoupper(Auth::user()->organismo->email) }}
                                    </td>
                                </tr>
                            </table>
                        </td>
                        <td>
                            <div class="logos" style="text-align: right;">
                                <img style="max-width: 300px; height: auto;" src="{{ asset('images/logos-recibo.png') }}">
                            </div>
                        </td>
                    </tr>
                </table>
                <p style="text-align: center;">Reporte generado por {{ Auth::user()->name }} el {{ \Carbon\Carbon::now()->format('Y-m-d') }} a las {{ \Carbon\Carbon::now()->format('H:i') }}</p>
            </div>
        @else
            @if(Input::has('fecha_inicial'))
            <div class="no-data">
                <div class="no-data-icon">
                    <i class="fa fa-exclamation-triangle"></i>
                </div>

                <div class="no-data-message">
                    No se encontraron registros para este rango de fechas.
                </div>
            </div>
            @endif
        @endif

    </div>

@endsection
