<?php

use \Illuminate\Support\Facades\Auth;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/
Auth::routes();

Route::post('export/{tableType}', 'ExportCSVController@export')->name('export');

Route::group(['middleware' => 'shareViews'], function () {
    Route::group(['middleware' => ['auth']], function () {

        Route::get('/', function () {
            if (isset(\Illuminate\Support\Facades\Auth::user()->id)) {
                return view('home');
            } else {
                return view('auth.login');
            }
        });

        Route::get('/home', 'HomeController@index')->name('home');
        Route::get('/PQR/index', 'PQRController@index')->name('pqr');
        Route::post('/PQR/doc/upload', 'PQRController@uploadDocs')->name('pqr.doc.upload');
        Route::get('/PQR/respuestas', 'PQRController@respuestas')->name('pqr.respuestas');
        Route::get('/PQR/pendientes', 'PQRController@pendientes')->name('pqr.pendientes');
        Route::get('/PQR/respuestas_envio', 'PQRController@envios')->name('pqr.respuestas_envio');
        Route::get('/PQR/pendientes_envio', 'PQRController@pendientesenvios')->name('pqr.pendientes_envio');        
        Route::post('/PQR/respuestas/upload', 'PQRController@uploadRespuesta')->name('pqr.respuestas.upload');
        Route::post('/PQR/respuestas/upload2', 'PQRController@uploadRespuesta2')->name('pqr.respuestas.upload2');
        Route::post('/PQR/respuestas/upload3', 'PQRController@uploadRespuesta3')->name('pqr.respuestas.upload3');
        Route::post('/PQR/respuestas/respuestasactualizar', 'PQRController@respuestasActualizar')->name('pqr.respuestas.actualizar_direccion');        

        Route::post('/PQR/tipoactualizar', 'PQRController@tipoActualizar')->name('pqr.tipoactualizar'); 

        Route::post('/PQR/respuestas/uploadrespuestaenvio', 'PQRController@uploadRespuestaEnvio')->name('pqr.respuestas.uploadrespuestaenvio');      
        Route::get('/PQR/getDays/{p1}/{p2}', 'PQRController@getFiveDays')->name('pqr.getDays');

        Route::get('/PQR/consultas', 'PQRController@consultas')->name('pqr.consultas');
        Route::get('/PQR/rastreo', 'PQRController@rastreo')->name('pqr.rastreo');
        Route::get('/PQR/reclasificacion', 'PQRController@reclasificacion')->name('pqr.reclasificacion');

        Route::get('/reportes', 'PQRController@consultas')->name('reportes');
        Route::get('/reportes/recaudo', 'ReportesController@recaudoImpuestos')->name('reporte.recaudo');
        Route::get('/reportes/recaudoexterno', 'ReportesController@recaudoExterno')->name('reporte.recaudoexterno');
        Route::get('/reportes/recaudosimitpolca',
            'ReportesController@recaudoSimit')->name('reporte.recaudosimitpolca');
        Route::get('/reportes/recaudofiducia',
            'ReportesController@recaudoFiducia')->name('reporte.recaudofiducia');

        Route::get('/exportusers', 'ExcelController@exportUsers')->name('reporte.users');
        Route::get('/exportpolca', 'ExcelController@exportPolca')->name('reporte.polca');
        Route::get('/exportfiducia', 'ExcelController@exportFiducia')->name('reporte.fiducia');

        Route::get('/parametros/dias',
            'DiasController@index')->name('parametros.dias');



    Route::get('/PQR/tutela/{id}', [
        'as' => 'tutela',
        'uses' => 'PQRController@tutela'
    ]);

    Route::get('/PQR/comparendo/{id}', [
        'as' => 'comparendo',
        'uses' => 'PQRController@comparendo'
    ]);

    Route::get('/PQR/oficio/{id}', [
        'as' => 'oficio',
        'uses' => 'PQRController@oficio'
    ]);

     Route::post('/PQR/oficio/{id}', [
        'as' => 'oficio.buscar',
        'uses' => 'PQRController@oficio'
    ]);   
    
         Route::get('/parametros/users',
            'UsuariosController@index')->name('parametros.users');       

    Route::get('/usuarios/crear', [
        'as' => 'usuarios.crear',
        'uses' => 'UsuariosController@create'
    ]);

    Route::post('/usuarios', [
        'as' => 'usuarios.guardar',
        'uses' => 'UsuariosController@save'
    ]);

    Route::get('/usuarios/{usuario}', [
        'as' => 'usuarios.editar',
        'uses' => 'UsuariosController@editar'
    ]);

    Route::post('/usuarios/{usuario}', [
        'as' => 'usuarios.actualizar',
        'uses' => 'UsuariosController@actualizar'
    ]);

    Route::get('/usuarios/{usuario}/activar', [
        'as' => 'usuarios.activar',
        'uses' => 'UsuariosController@activate'
    ]);

    Route::get('/usuarios/{usuario}/desactivar', [
        'as' => 'usuarios.desactivar',
        'uses' => 'UsuariosController@deactivate'
    ]);

    Route::get('/parametros/perfil', [
        'as' => 'parametros.perfil',
        'uses' => 'UsuariosController@perfil'
    ]);


    /*PERFILES*/
    Route::get('/parametros/perfiles', [
        'as' => 'parametros.perfiles',
        'uses' => 'PerfilesController@index'
    ]);

    Route::get('/perfiles/crear', [
        'as' => 'perfiles.crear',
        'uses' => 'PerfilesController@crear'
    ]);

    Route::post('/perfiles/guardar', [
        'as' => 'perfiles.guardar',
        'uses' => 'PerfilesController@guardar'
    ]);

    Route::get('/perfiles/{perfil}', [
        'as' => 'perfiles.editar',
        'uses' => 'PerfilesController@editar'
    ]);

    Route::post('/perfiles/{perfil}', [
        'as' => 'perfiles.actualizar',
        'uses' => 'PerfilesController@actualizar'
    ]);




    Route::get('/dias/crear', [
        'as' => 'dias.crear',
        'uses' => 'DiasController@create'
    ]);
    Route::get('/dias/{id}', [
        'as' => 'dias.editar',
        'uses' => 'DiasController@edit'
    ]);

   Route::get('/importar/base', 'ExcelController@importarBase')->name('importar.base');
    Route::post('/importar/cargarPost', [
        'as' => 'importar.cargarPost',
        'uses' => 'ExcelController@cargarPost'
    ]);

        /*impresiones sancion*/
        Route::get('/impresion/rs',
            'ImpresionesController@indexSanciones')->name('impresion.rs');

        Route::get('/impresion/rs/descargaredirect/{id}', [
          'as' => 'impresion.rs.descargaredirect',
          'uses' => 'ImpresionesController@redireccionarPaqueteSancion'
        ]);

        Route::get('/impresion/rs/descarga/{id}', [
          'as' => 'impresion.rs.descarga',
          'uses' => 'ImpresionesController@descargarPaqueteSancion'
        ]);

        /*impresiones mandamientos*/
        Route::get('/impresion/rmp',
            'ImpresionesController@indexMandamiento')->name('impresion.rmp');

        Route::get('/impresion/rmp/descargaredirect/{id}', [
          'as' => 'impresion.rmp.descargaredirect',
          'uses' => 'ImpresionesController@redireccionarPaqueteMandamiento'
        ]);

        Route::get('/impresion/rmp/descarga/{id}', [
          'as' => 'impresion.rmp.descarga',
          'uses' => 'ImpresionesController@descargarPaqueteMandamiento'
        ]);

        /*impresiones embargos*/
        Route::get('/impresion/emb',
            'ImpresionesController@indexEmbargo')->name('impresion.emb');

        Route::get('/impresion/emb/descargaredirect/{id}', [
          'as' => 'impresion.emb.descargaredirect',
          'uses' => 'ImpresionesController@redireccionarPaqueteEmbargo'
        ]);

        Route::get('/impresion/emb/descarga/{id}', [
          'as' => 'impresion.emb.descarga',
          'uses' => 'ImpresionesController@descargarPaqueteEmbargo'
        ]);


    Route::get('/getciudadano/{id}', [
        'as' => 'getciudadano',
        'uses' => 'PQRController@getCiudadano'
    ]);    

        Route::get('/getciudad/{id}', [
        'as' => 'getciudad',
        'uses' => 'PQRController@getCiudades'
    ]);  

        Route::get('/getbuscar/{id}', [
        'as' => 'getbuscar',
        'uses' => 'PQRController@getBuscar'
    ]);  
  



        /*impresiones citaciones de mandamientos de pago*/
        Route::get('/impresion/citmp',
            'ImpresionesController@indexCitmp')->name('impresion.citacion');

        Route::get('/impresion/citmp/descargaredirect/{id}', [
          'as' => 'impresion.citmp.descargaredirect',
          'uses' => 'ImpresionesController@redireccionarPaqueteCitmp'
        ]);

        Route::get('/impresion/citmp/descarga/{id}', [
          'as' => 'impresion.citmp.descarga',
          'uses' => 'ImpresionesController@descargarPaqueteCitmp'
        ]);
        

        /*impresiones notificaciones personal de mandamientos de pago*/
        Route::get('/impresion/notificacion',
            'ImpresionesController@indexNotificacion')->name('impresion.notificacion');

        Route::get('/impresion/notificacion/descargaredirect/{id}', [
          'as' => 'impresion.notificacion.descargaredirect',
          'uses' => 'ImpresionesController@redireccionarPaqueteNotificacion'
        ]);

        Route::get('/impresion/notificacion/descarga/{id}', [
          'as' => 'impresion.notificacion.descarga',
          'uses' => 'ImpresionesController@descargarPaqueteNotificacion'
        ]);

        /*avisos*/
        Route::get('/impresion/avisos',
            'ImpresionesController@indexAvisos')->name('impresion.avisos');

        Route::get('/impresion/avisos/descargaredirect/{id}', [
          'as' => 'impresion.avisos.descargaredirect',
          'uses' => 'ImpresionesController@redireccionarPaqueteAvisos'
        ]);

        Route::get('/impresion/avisos/descarga/{id}', [
          'as' => 'impresion.avisos.descarga',
          'uses' => 'ImpresionesController@descargarPaqueteAvisos'
        ]);


        /*historial conductor*/
        Route::get('/historial',
            'HistoriaController@index')->name('historial');

        Route::get('/historial/detalle/{id}',
            'HistoriaController@detalle')->name('historial.detalle');

        Route::get('/historial/descargaresol/{id}',
            'HistoriaController@descargarResolucion')->name('historial.descargaresol');

        Route::get('/historial/consulta/documentos/{id}/{tipo}/{emb}',
            'HistoriaController@consultaDocumentos')->name('historial.consulta.documentos');

        Route::get('/historial/cambiaraudiencia/{id}',
            'HistoriaController@viewCambiarAudiencia')->name('historial.cambiaraudiencia');

        Route::post('/historial/cambiaraudiencia',
            'HistoriaController@cambiarAudiencia')->name('historial.cambiaraudiencia.post');

        Route::get('/historial/crearsentencia/{id}',
            'HistoriaController@crearSentencia')->name('historial.crearsentencia');

        Route::get('/historial/crearcitacionmandamiento/{id}',
            'HistoriaController@crearCitacionMandamiento')->name('historial.crearcitacionmandamiento');

        /*titulos*/
        Route::get('/titulos/devolucion',
            'TitulosController@index')->name('titulos.devolucion');

        Route::get('/titulos/apropiar/{cedula}',
            'TitulosController@apropiar')->name('titulos.apropiar');

        Route::post('/titulos/devolver',
            'TitulosController@devolver')->name('titulos.devolver');

        Route::get('/titulos/revertirapropiacion/{id}/{cedula}',
            'TitulosController@revertirApropiacion')->name('titulos.revertirapropiacion');

        Route::get('/titulos/eliminarapropiacion/{id}/{cedula}',
            'TitulosController@eliminarApropiacion')->name('titulos.eliminarapropiacion');

        Route::get('/titulos/consulta',
            'TitulosController@consulta')->name('titulos.consulta');

        Route::get('/titulos/nuevo',
            'TitulosController@new')->name('titulos.nuevo');

        Route::get('/titulos/editar/{id}',
            'TitulosController@edit')->name('titulos.editar');

        Route::post('/titulos/guardar',
            'TitulosController@save')->name('titulos.guardar');

        Route::get('/titulos/cedula/titulos/{cedula}',
            'TitulosController@consultaCedulaTitulo')->name('titulos.cedula.titulos');

        /*incumplimiento*/
        Route::get('/incumplimiento/index',
            'IncumplimientoController@index')->name('incumplimiento.index');

        Route::post('/incumplimiento/guardar',
            'IncumplimientoController@guardar')->name('incumplimiento.guardar');



    });
});
